@@ -136,24 +136,29 @@ public class GifEncoder extends ImageEncoder {
     Integer ic = (Integer) params.get("transparentColor");
     if (ic == null) {
       ic = (Integer) params.get("backgroundColor");
-      if (ic != null)
+      if (ic != null) 
         backgroundColor = ic.intValue();
     } else {
       backgroundColor = ic.intValue();
       isTransparent = true;
     }
 
+    if (backgroundColor == 0xFF000000) {
+      // fix speckling of text Jmol 14.32.69
+      // must return background to true color
+      for (int i = pixels.length; --i >= 0;)
+          pixels[i] = pixels[i] &~0x040404;
+    }
+
     interlaced = (Boolean.TRUE == params.get("interlaced"));
     if (params.containsKey("captureRootExt") // file0000.gif 
         || !params.containsKey("captureMode")) // animated gif
       return;
     interlaced = false;
     capturing = true;
-    try {
-      byteCount = ((Integer) params.get("captureByteCount")).intValue();
-    } catch (Exception e) {
-      // ignore
-    }
+    Integer c = (Integer) params.get("captureByteCount");
+    if (c != null)
+      byteCount = c.intValue();
     switch ("maec"
         .indexOf(((String) params.get("captureMode")).substring(0, 1))) {
     case 0: //"movie"
