@@ -157,6 +157,8 @@ public class CifDataParser implements GenericCifDataParser {
   private SB fileHeader = new SB(); 
   private boolean isHeader = true;
 
+  private boolean skipToken;
+
 
   /**
    * Set the string value of what is returned for "." and "?"
@@ -788,8 +790,9 @@ public class CifDataParser implements GenericCifDataParser {
         str = str.substring(0, str.length() - 1)
           + '\1' + line.substring(1);
         break;
+      } else if (!skipToken) {
+        str += line + '\n';
       }
-      str += line + '\n';
     }
     return str;
   }
@@ -956,5 +959,14 @@ public class CifDataParser implements GenericCifDataParser {
     return (asObject ? lst : "[" + str + "]");
   }
 
+  @Override
+  public String skipNextToken() throws Exception {
+    skipToken = true;
+    getNextToken();
+    skipToken = false;
+    return "<skipped>";
+  }
+
+
   
 }
\ No newline at end of file
