@@ -1048,7 +1048,7 @@ final public class Measure {
       }
     }
     for (int i = n; --i >= 0;)
-      cpts.removeItemAt(i);
+      cpts.removeItemAt(0);
     return cpts;
   }
 
