@@ -537,6 +537,11 @@ public class ZipTools implements GenericZipTools {
     return bytes;
   }
 
+  @Override
+  public boolean isZipStream(Object br) {
+    return br instanceof ZInputStream;
+  }
+
 
 
 }
