@@ -30,6 +30,8 @@ import java.net.URL;
 import java.util.Hashtable;
 import java.util.Map;
 
+import org.jmol.util.Logger;
+
 import javajs.util.AU;
 import javajs.util.BS;
 import javajs.util.Encoding;
@@ -38,15 +40,8 @@ import javajs.util.OC;
 import javajs.util.P3;
 import javajs.util.PT;
 import javajs.util.SB;
-
-import org.jmol.api.GenericFileInterface;
-import org.jmol.util.Logger;
-
-import jspecview.api.JSVPanel;
 import jspecview.api.JSVZipInterface;
-import jspecview.api.ScriptInterface;
 import jspecview.exception.JSVException;
-import jspecview.source.JDXSource;
 
 public class JSVFileManager {
 
