@@ -244,7 +244,7 @@ public class CifReader extends AtomSetCollectionReader {
     if (isLoop) {
       if (skipping && !isMMCIF) {
         cifParser.getTokenPeeked();
-        cifParser.skipLoop(false);
+        skipLoop(false);
       } else {
         processLoopBlock();
       }
@@ -455,7 +455,7 @@ public class CifReader extends AtomSetCollectionReader {
   private boolean haveGlobalDummy;
   protected void newModel(int modelNo) throws Exception {
     if (modelNo < 0) {
-      if (modelNumber == 1 && asc.ac == 0 && nAtoms == 0 && !haveGlobalDummy) {
+      if (modelNumber == 1 && asc.ac == 0 && nAtoms == 0 && !haveGlobalDummy && !skipping) {
         modelNumber = 0;
         haveModel = false;
         haveGlobalDummy = true;
@@ -480,7 +480,7 @@ public class CifReader extends AtomSetCollectionReader {
         modelNumber--;
         haveModel = false;
         asc.removeCurrentAtomSet();
-      } else {
+      } else if (asc.iSet >= 0) {
         applySymmetryAndSetTrajectory();
       }
  }
@@ -884,7 +884,7 @@ public class CifReader extends AtomSetCollectionReader {
       case 0:
         break;
       case -1:
-        cifParser.skipLoop(false);
+        skipLoop(false);
         //$FALL-THROUGH$
       case 1:
         return;
@@ -909,7 +909,7 @@ public class CifReader extends AtomSetCollectionReader {
         || key.startsWith("_symmetry_ssg_equiv")) {
       if (ignoreFileSymmetryOperators) {
         Logger.warn("ignoring file-based symmetry operators");
-        cifParser.skipLoop(false);
+        skipLoop(false);
       } else {
         processSymmetryOperationsLoopBlock();
       }
@@ -933,7 +933,7 @@ public class CifReader extends AtomSetCollectionReader {
       addMore();
       return;
     }
-    cifParser.skipLoop(false);
+    skipLoop(false);
   }
 
   protected boolean processSubclassLoopBlock() throws Exception {
@@ -1266,7 +1266,7 @@ public class CifReader extends AtomSetCollectionReader {
       // no coordinates, but valuable information
     } else {
       // it is a different kind of _atom_site loop block
-      cifParser.skipLoop(false);
+      skipLoop(false);
       return false;
     }
     int modelField = key2col[MODEL_NO];
@@ -1437,7 +1437,7 @@ public class CifReader extends AtomSetCollectionReader {
         case DISORDER_GROUP:
           if (firstChar == '-' && field.length() > 1) {
             atom.altLoc = field.charAt(1);
-            atom.ignoreSymmetry = true;
+            atom.isNegDisorder = true;
           } else {
             atom.altLoc = firstChar;
           }
@@ -1719,7 +1719,7 @@ public class CifReader extends AtomSetCollectionReader {
         break;
     if (n < 0) {
       Logger.warn("required " + FAMILY_SGOP + " key not found");
-      cifParser.skipLoop(false);
+      skipLoop(false);
       return;
     }
     n = 0;
@@ -1827,7 +1827,7 @@ public class CifReader extends AtomSetCollectionReader {
         && stateScriptVersionInt < 140403);
     parseLoopParameters(geomBondFields);
     if (bondLoopBug || !checkAllFieldsPresent(geomBondFields, 2, true)) {
-      cifParser.skipLoop(false);
+      skipLoop(false);
       return;
     }
     int bondCount = 0;
@@ -2235,5 +2235,9 @@ public class CifReader extends AtomSetCollectionReader {
     return key.equals("\0");
   }
 
+  protected void skipLoop(boolean doReport) throws Exception {
+    if (isLoop)
+      cifParser.skipLoop(doReport);
+  }
 
 }
