@@ -26,6 +26,7 @@ import org.jmol.util.Modulation;
 import org.jmol.util.ModulationSet;
 import org.jmol.util.Tensor;
 import org.jmol.util.Vibration;
+import org.jmol.viewer.JC;
 
 /**
  * generalized modulated structure reader class for CIF and Jana
@@ -217,7 +218,10 @@ public class MSRdr implements MSInterface {
   private int ac;
   private boolean haveAtomMods;
 
-  private boolean modCoord;
+  /**
+   * not used
+   */
+  boolean modCoord; 
 
   private boolean finalized;
 
@@ -331,7 +335,7 @@ public class MSRdr implements MSInterface {
       return;
     if (modDebug)
       Logger.debugging = Logger.debuggingHigh = true;
-    cr.asc.setInfo("someModelsAreModulated", Boolean.TRUE);
+    cr.asc.setInfo(JC.getBoolName(JC.GLOBAL_MODULATED), Boolean.TRUE);
     this.symmetry = symmetry;
     setModulationForStructure(cr.asc.iSet, isPost);
     if (modDebug)
@@ -441,6 +445,8 @@ public class MSRdr implements MSInterface {
     htSubsystems = null;
   }
 
+  private final static String generic = "#*;*";
+
   private void initModForStructure(int iModel) throws Exception {
     String key;
 
@@ -464,7 +470,7 @@ public class MSRdr implements MSInterface {
         cr.appendLoadNote("NOTE!: Not enough cell wave vectors for d=" + modDim);
         return;
       }
-      fixDouble(pt);
+      fixDoubleA(pt);
       cr.appendLoadNote("W_" + (i + 1) + " = " + Escape.e(pt));
       cr.appendUunitCellInfo("q" + (i + 1) + "=" + pt[0] + " " + pt[1] + " "
           + pt[2]);
@@ -479,10 +485,12 @@ public class MSRdr implements MSInterface {
     // F: Jana-type wave vector, referencing W vectors (set pt to coefficients, including harmonics)
     Map<String, double[]> map = new Hashtable<String, double[]>();
     for (Entry<String, double[]> e : htModulation.entrySet()) {
-      if ((key = checkKey(e.getKey(), false)) == null)
+      String k = e.getKey();
+      if ((key = checkKey(k, false)) == null)
         continue;
       pt = e.getValue();
-      switch (key.charAt(0)) {
+      char ch = key.charAt(0);
+      switch (ch) {
       case 'O':
         haveOccupancy = true;
         //$FALL-THROUGH$
@@ -493,8 +501,14 @@ public class MSRdr implements MSInterface {
         if (pt[2] == 1 && key.charAt(2) != 'S' && key.charAt(2) != 'T' && key.charAt(2) != 'L') {
           int ipt = key.indexOf("?");
           if (ipt >= 0) {
-            String s = key.substring(ipt + 1);
-            pt = getMod(key.substring(0, 2) + MSCifParser.SEP + s + "#*;*");
+            k = key.substring(0, 2) + MSCifParser.SEP + key.substring(ipt + 1) + generic;
+            // look for specific parameter from _atom_site_displace_Fourier_cos entry
+            pt = getMod(k);
+            if (pt == null) {
+              // look for generic parameter from displace_Fourier_param block
+              k = key.substring(0, 1) + MSCifParser.SEP + key.substring(ipt + 1) + generic;
+              pt = getMod(k);
+            }
             // may have       Vy1    0.0          0.0   , resulting in null pt here
             if (pt != null)
               addModulation(map, key = key.substring(0, ipt), pt, iModel);
@@ -503,8 +517,8 @@ public class MSRdr implements MSInterface {
             //  --> A cos(2pi(p)) cos(2pi(q.r)) + A sin(-2pi(p)) sin(2pi(q.r))
             double a = pt[0];
             double d = 2 * Math.PI * pt[1];
-            pt[0] = (float) (a * Math.cos(d));
-            pt[1] = (float) (a * Math.sin(-d));
+            pt[0] = (a * Math.cos(d));
+            pt[1] = (a * Math.sin(-d));
             pt[2] = 0;
             Logger.info("msCIF setting " + key + " " + Escape.e(pt));
           }
@@ -554,7 +568,8 @@ public class MSRdr implements MSInterface {
       htAtomMods = new Hashtable<String, Lst<Modulation>>();
     }
     for (Entry<String, double[]> e : htModulation.entrySet()) {
-      if ((key = checkKey(e.getKey(), true)) == null)
+      String k = e.getKey();
+      if ((key = checkKey(k, true)) == null)
         continue;
       double[] params = e.getValue();
       String atomName = key.substring(key.indexOf(";") + 1);
@@ -611,7 +626,7 @@ public class MSRdr implements MSInterface {
         double[] pt1 = htModulation.get(key1);
         if (pt1 == null) {
           Logger.error("Crenel " + key1 + " not found for legendre modulation " + key);
-          pt[2] = Float.NaN;
+          pt[2] = Double.NaN;
         } else {
           htModulation.put(key, new double[] { pt1[0], pt1[1], pt[0], pt[1] });
         }
@@ -619,7 +634,7 @@ public class MSRdr implements MSInterface {
     }
   }
         
-  private void fixDouble(double[] pt) {
+  private void fixDoubleA(double[] pt) {
     if (cr.fixJavaFloat)
       for (int i = pt.length; --i >= 0;)
         pt[i] = PT.fixDouble(pt[i], PT.FRACTIONAL_PRECISION);
@@ -637,9 +652,10 @@ public class MSRdr implements MSInterface {
     }     
     // BH 2020.09.16 the addition of 2018.05.30 puts fn just after f_. 
     // it is not clear that anything puts it after it, but leaving that as an option.
-    double[] p = getMod("F_coefs_" + fn );
-    if (p == null)
-      p = getMod("F_" + fn + "_coefs_");
+    double[] p = getMod("F_" + fn + "_coefs_");
+    if (p == null) {
+      p = getMod("F_coefs_" + fn);
+    }
     return p;
   }
 
@@ -867,7 +883,7 @@ public class MSRdr implements MSInterface {
     if (modLast)
       iop = Math.max((a.bsSymmetry.length() - 1) % nOps, iop);
     if (Logger.debuggingHigh)
-      Logger.debug("\nsetModulation: i=" + a.index + " " + a.atomName + " xyz="
+      Logger.info("\nsetModulation: i=" + a.index + " " + a.atomName + " xyz="
           + a + " occ=" + a.foccupancy);
     if (iop != iopLast) {
       // for each new operator, we need to generate new matrices.
@@ -916,8 +932,8 @@ public class MSRdr implements MSInterface {
                 + a.atomName);
       } else {
         if (Logger.debuggingHigh) {
-          Logger.debug("setModulation Uij(initial)=" + Escape.eAF(a.anisoBorU));
-          Logger.debug("setModulation tensor="
+          Logger.info("setModulation Uij(initial)=" + Escape.eAF(a.anisoBorU));
+          Logger.info("setModulation tensor="
               + Escape.e(((Tensor) a.tensors.get(0)).getInfo("all")));
         }
         for (Entry<String, Float> e : ms.htUij.entrySet())
@@ -929,7 +945,7 @@ public class MSRdr implements MSInterface {
         t.isModulated = true;
         t.id = Escape.e(a.anisoBorU);
         // note that a.bFactor will be modulated value
-        a.bfactor = a.anisoBorU[7] * 100f;
+        a.bfactor = a.anisoBorU[7] * 100;
         // prevent further tensor production
         a.anisoBorU = null;
         if (Logger.debuggingHigh) {
