@@ -343,6 +343,8 @@ public class TopoCifParser implements Parser {
       return false;
     }
     if (ac0 < 0) {
+      // no initial bonding model
+      reader.asc.firstAtomToBond = reader.asc.getAtomSetAtomIndex(reader.asc.iSet);
       ac0 = reader.asc.ac;
       bc0 = reader.asc.bondCount;
     }
@@ -1337,7 +1339,7 @@ public class TopoCifParser implements Parser {
     private String mf;
 
     public TLink() {
-      super();
+      super(0,0,0);
       @SuppressWarnings("unused")
       int i = 0;
     }
