@@ -79,15 +79,13 @@ public class MolReader extends AtomSetCollectionReader {
    * $END MOL
    */
 
-  boolean optimize2D;
   private boolean haveAtomSerials;
   protected boolean allow2D = true;
   private int iatom0;
   private V3000Rdr vr;
   private int atomCount;
   private String[] atomData;
-  boolean is2D;
-  private BS bsDeleted;
+  public BS bsDeleted;
   /**
    * fix charges for RN(=O)(O), =N(O)*, =N
    */
@@ -95,7 +93,6 @@ public class MolReader extends AtomSetCollectionReader {
 
   @Override
   public void initializeReader() throws Exception {
-    optimize2D = checkFilterKey("2D");
     fixN = checkFilterKey("FIXN");
   }
 
@@ -152,8 +149,15 @@ public class MolReader extends AtomSetCollectionReader {
         Bond b = asc.bonds[i];
         if (asc.atoms[b.atomIndex2].elementSymbol.equals("H")
             && b.order != JmolAdapter.ORDER_STEREO_NEAR
-            && b.order != JmolAdapter.ORDER_STEREO_FAR) {
+            && b.order != JmolAdapter.ORDER_STEREO_FAR
+            && asc.atoms[b.atomIndex1].elementSymbol.equals("C")
+            ) {
           asc.bsAtoms.clear(b.atomIndex2);
+        } else if (asc.atoms[b.atomIndex1].elementSymbol.equals("H")
+            && asc.atoms[b.atomIndex2].elementSymbol.equals("C")
+            ) {
+          // includes backward C-H wedge/hash here, which makes no sense.
+          asc.bsAtoms.clear(b.atomIndex1);
         }
       }
 
@@ -216,7 +220,7 @@ public class MolReader extends AtomSetCollectionReader {
     if (rd() == null)
       return;
     if (line.indexOf("V3000") >= 0) {
-      optimize2D = is2D;
+      optimize2D = is2D && !noHydrogens;
       vr = ((V3000Rdr) getInterface("org.jmol.adapter.readers.molxyz.V3000Rdr")).set(this);
       discardLinesUntilContains("COUNTS");
       vr.readAtomsAndBonds(getTokens());
@@ -374,9 +378,7 @@ public class MolReader extends AtomSetCollectionReader {
         if (iso == 17 && sym.equals("C")) {
           atom.elementSymbol = "N";
         } else if (iso == 5 && sym.equals("H")) {
-          if (bsDeleted == null)
-            bsDeleted = new BS();
-          bsDeleted.set(atom.index);
+          deleteAtom(atom);
         } else {
           atom.elementSymbol = "" + iso + sym;
         }
@@ -387,6 +389,12 @@ public class MolReader extends AtomSetCollectionReader {
     rd();
   }
 
+  public void deleteAtom(Atom atom) {
+    if (bsDeleted == null)
+      bsDeleted = new BS();
+    bsDeleted.set(atom.index);
+  }
+
   /**
    * Read the SDF data with name in lower case
    * 
@@ -451,7 +459,7 @@ public class MolReader extends AtomSetCollectionReader {
     }
   }
 
-  public void addMolAtom(int iAtom, int isotope, String elementSymbol,
+  public Atom addMolAtom(int iAtom, int isotope, String elementSymbol,
                          int charge, float x, float y, float z) {
     switch (isotope) {
     case 0:
@@ -481,6 +489,7 @@ public class MolReader extends AtomSetCollectionReader {
       atom.atomSerial = iAtom;
       asc.addAtomWithMappedSerialNumber(atom);
     }
+    return atom;
   }
 
   int fixOrder(int order, int stereo) {
@@ -496,6 +505,9 @@ public class MolReader extends AtomSetCollectionReader {
       case 3: // DOWN, V3000
       case 6: // DOWN
         return JmolAdapter.ORDER_STEREO_FAR;
+      case 2: // either, V3000
+      case 4: // either
+        return JmolAdapter.ORDER_STEREO_EITHER;
       }
       break;
     case 2:
@@ -522,13 +534,12 @@ public class MolReader extends AtomSetCollectionReader {
     return order;
   }
 
-  public void addMolBond(String iAtom1, String iAtom2, int order, int stereo) {
+  public Bond addMolBond(String iAtom1, String iAtom2, int order, int stereo) {
     order = fixOrder(order, stereo);
     if (haveAtomSerials)
-     asc.addNewBondFromNames(iAtom1, iAtom2, order);
-    else
-      asc.addNewBondWithOrder(iatom0 + parseIntStr(iAtom1) - 1, iatom0
-          + parseIntStr(iAtom2) - 1, order);
+      return asc.addNewBondFromNames(iAtom1, iAtom2, order);
+    return asc.addNewBondWithOrder(iatom0 + parseIntStr(iAtom1) - 1,
+        iatom0 + parseIntStr(iAtom2) - 1, order);
   }
 
 }
