@@ -24,27 +24,25 @@
 
 package org.jmol.adapter.readers.pdb;
 
+import java.util.Hashtable;
+import java.util.Map;
+
+import org.jmol.adapter.smarter.Atom;
 import org.jmol.adapter.smarter.AtomSetCollection;
 import org.jmol.adapter.smarter.AtomSetCollectionReader;
-import org.jmol.adapter.smarter.Atom;
 import org.jmol.adapter.smarter.Structure;
 import org.jmol.api.JmolAdapter;
 import org.jmol.api.SymmetryInterface;
 import org.jmol.c.STR;
-import org.jmol.symmetry.Symmetry;
 import org.jmol.util.Escape;
+import org.jmol.util.Logger;
+import org.jmol.viewer.JC;
 
 import javajs.util.Lst;
-import javajs.util.PT;
-import javajs.util.SB;
-
-import org.jmol.util.Logger;
-
 import javajs.util.M4;
 import javajs.util.P3;
-import java.util.Hashtable;
-
-import java.util.Map;
+import javajs.util.PT;
+import javajs.util.SB;
 
 
 /**
@@ -435,7 +433,7 @@ public class PdbReader extends AtomSetCollectionReader {
       }
     }
     if (vTlsModels != null) {
-      symmetry = (Symmetry) getInterface("org.jmol.symmetry.Symmetry");
+      symmetry = (SymmetryInterface) getInterface("org.jmol.symmetry.Symmetry");
       int n = asc.atomSetCount;
       if (n == vTlsModels.size()) {
         for (int i = n; --i >= 0;)
@@ -719,9 +717,10 @@ public class PdbReader extends AtomSetCollectionReader {
           chainlist += ";";
           if (checkFilterKey("BIOMOLECULE " + id + ";")
               || checkFilterKey("BIOMOLECULE=" + id + ";")) {
-            setFilter(filter + chainlist);
+            setFilter(filterCased + chainlist);
             Logger.info("filter set to \"" + filter + "\"");
             thisBiomolecule = info;
+            haveMappedSerials = applySymmetry;
           }
           continue;
         }
@@ -1325,7 +1324,7 @@ public class PdbReader extends AtomSetCollectionReader {
     Structure structure = new Structure(-1, structureType, substructureType,
         structureID, serialID, strandCount, null);
     structure.set(startChainID, startSequenceNumber,
-        startInsertionCode, endChainID, endSequenceNumber, endInsertionCode, Integer.MIN_VALUE, Integer.MAX_VALUE);
+        startInsertionCode, endChainID, endSequenceNumber, endInsertionCode, 0, 0);
     asc.addStructure(structure);
   }
 
@@ -1355,6 +1354,8 @@ public class PdbReader extends AtomSetCollectionReader {
   private String getModelName() {
     if (lineLength < 16)
       return null;
+    if (line.startsWith("ATOM"))
+      return "";
     String name = line.substring(15, lineLength).trim();
     return (name.length() == 0 ? null  : name);
   }
@@ -1364,7 +1365,7 @@ public class PdbReader extends AtomSetCollectionReader {
     if (name == null)
       name = pdbID;
     //not cleaer that this shoudl come irset...    
-    haveMappedSerials = false;
+    haveMappedSerials = (thisBiomolecule != null && applySymmetry);
     sbConect = null;
     asc.newAtomSet();
     asc.setCurrentModelInfo("pdbID", pdbID);
@@ -2061,7 +2062,7 @@ public class PdbReader extends AtomSetCollectionReader {
           new int[] { firstAtom, count, maxSerial }, i);
       if (vConnect != null) {
         asc.setModelInfoForSet("PDB_CONECT_bonds", vConnect, i);
-        asc.setGlobalBoolean(AtomSetCollection.GLOBAL_CONECT);
+        asc.setGlobalBoolean(JC.GLOBAL_CONECT);
       }
       firstAtom += count;
     }
@@ -2088,7 +2089,7 @@ public class PdbReader extends AtomSetCollectionReader {
     int firstAtom = connectNextAtomIndex;
     for (int i = a.atomSetCount; --i >= connectNextAtomSet;) {
       a.setModelInfoForSet("PDB_CONECT_bonds", vConnect, i);
-      a.setGlobalBoolean(AtomSetCollection.GLOBAL_CONECT);
+      a.setGlobalBoolean(JC.GLOBAL_CONECT);
       firstAtom += a.getAtomSetAtomCount(i);
     }
     vConnect = null;
