@@ -24,24 +24,22 @@
 
 package org.jmol.adapter.readers.quantum;
 
-import javajs.util.AU;
-import javajs.util.Lst;
-import javajs.util.PT;
-
 import java.util.Hashtable;
-import java.util.Properties;
-
 import java.util.Map;
 import java.util.Map.Entry;
 
 import org.jmol.adapter.smarter.Atom;
 import org.jmol.adapter.smarter.SmarterJmolAdapter;
 import org.jmol.api.JmolAdapter;
-import javajs.util.BS;
 import org.jmol.quantum.QS;
 import org.jmol.util.Elements;
 import org.jmol.util.Logger;
 
+import javajs.util.AU;
+import javajs.util.BS;
+import javajs.util.Lst;
+import javajs.util.PT;
+
 /**
  * A reader for NWChem 4.6
  * NWChem is a quantum chemistry program developed at
@@ -341,59 +339,59 @@ public class NWChemReader extends MOReader {
     }
   }
 
-  // NWChem Gradients output
-  // The 'atom' is really a Tag (as above)
-  /*
-                           UHF ENERGY GRADIENTS
-
-      atom               coordinates                        gradient
-                   x          y          z           x          y          z
-     1 O       0.000000   0.000000   0.267248    0.000000   0.000000  -0.005967
-     2 H       1.336238   0.000000  -1.068990   -0.064647   0.000000   0.002984
-     3 H      -1.336238   0.000000  -1.068990    0.064647   0.000000   0.002984
-
-  */
-  // NB one could consider removing the previous read structure since that
-  // must have been the input structure for the optimizition?
-  /**
-   * Reads the energy gradients section into a new AtomSet.
-   * 
-   * <p>
-   * One could consider not adding a new AtomSet for this, but just adding the
-   * gradient vectors to the last AtomSet read (if that was indeed the same
-   * nuclear arrangement).
-   * 
-   * @throws Exception
-   *         If an error occurs.
-   **/
-  private void readGradients() throws Exception {
-    readLines(3); // skip blank line, titles and dashes
-    String tokens[];
-    asc.newAtomSet();
-    if (equivalentAtomSets > 1) {
-      Properties p = (Properties) asc.getAtomSetAuxiliaryInfoValue(
-          asc.iSet - 1, "modelProperties");
-      if (p != null)
-        asc.setCurrentModelInfo("modelProperties", p.clone());
-    }
-    asc.setAtomSetModelProperty("vector", "gradient");
-    asc.setAtomSetModelProperty(SmarterJmolAdapter.PATH_KEY, "Task "
-        + taskNumber + SmarterJmolAdapter.PATH_SEPARATOR + "Gradients");
-    float f = ANGSTROMS_PER_BOHR;
-    while (rd() != null && line.length() > 0) {
-      tokens = getTokens(); // get the tokens in the line
-      if (tokens.length < 8)
-        break; // make sure I have enough tokens
-      Atom atom = setAtomCoordScaled(null, tokens, 2, f);
-      atom.atomName = fixTag(tokens[1]);
-
-      // Keep gradients in a.u. (larger value that way)
-      // need to multiply with -1 so the direction is in the direction the
-      // atom needs to move to lower the energy
-      asc.addVibrationVector(atom.index, -parseFloatStr(tokens[5]),
-          -parseFloatStr(tokens[6]), -parseFloatStr(tokens[7]));
-    }
-  }
+//  // NWChem Gradients output
+//  // The 'atom' is really a Tag (as above)
+//  /*
+//                           UHF ENERGY GRADIENTS
+//
+//      atom               coordinates                        gradient
+//                   x          y          z           x          y          z
+//     1 O       0.000000   0.000000   0.267248    0.000000   0.000000  -0.005967
+//     2 H       1.336238   0.000000  -1.068990   -0.064647   0.000000   0.002984
+//     3 H      -1.336238   0.000000  -1.068990    0.064647   0.000000   0.002984
+//
+//  */
+//  // NB one could consider removing the previous read structure since that
+//  // must have been the input structure for the optimizition?
+//  /**
+//   * Reads the energy gradients section into a new AtomSet.
+//   * 
+//   * <p>
+//   * One could consider not adding a new AtomSet for this, but just adding the
+//   * gradient vectors to the last AtomSet read (if that was indeed the same
+//   * nuclear arrangement).
+//   * 
+//   * @throws Exception
+//   *         If an error occurs.
+//   **/
+//  private void readGradients() throws Exception {
+//    readLines(3); // skip blank line, titles and dashes
+//    String tokens[];
+//    asc.newAtomSet();
+//    if (equivalentAtomSets > 1) {
+//      Properties p = (Properties) asc.getAtomSetAuxiliaryInfoValue(
+//          asc.iSet - 1, "modelProperties");
+//      if (p != null)
+//        asc.setCurrentModelInfo("modelProperties", p.clone());
+//    }
+//    asc.setAtomSetModelProperty("vector", "gradient");
+//    asc.setAtomSetModelProperty(SmarterJmolAdapter.PATH_KEY, "Task "
+//        + taskNumber + SmarterJmolAdapter.PATH_SEPARATOR + "Gradients");
+//    float f = ANGSTROMS_PER_BOHR;
+//    while (rd() != null && line.length() > 0) {
+//      tokens = getTokens(); // get the tokens in the line
+//      if (tokens.length < 8)
+//        break; // make sure I have enough tokens
+//      Atom atom = setAtomCoordScaled(null, tokens, 2, f);
+//      atom.atomName = fixTag(tokens[1]);
+//
+//      // Keep gradients in a.u. (larger value that way)
+//      // need to multiply with -1 so the direction is in the direction the
+//      // atom needs to move to lower the energy
+//      asc.addVibrationVector(atom.index, -parseFloatStr(tokens[5]),
+//          -parseFloatStr(tokens[6]), -parseFloatStr(tokens[7]));
+//    }
+//  }
 
   // SAMPLE FREQUENCY OUTPUT
   // First the structure. The atom column has real element names (not the tags)
