@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-06-01 06:55:35 +0200 (Wed, 01 Jun 2022) $
- * $Revision: 22422 $
+ * $Date: 2022-12-11 13:26:30 -0600 (Sun, 11 Dec 2022) $
+ * $Revision: 22490 $
  *
  * Copyright (C) 2003-2005  Miguel, Jmol Development, www.jmol.org
  *
@@ -614,7 +614,11 @@ public class AtomSetCollection {
       }
       return;
     }
-    if (bondCount == bonds.length)
+    addBondNoCheck(bond);
+  }
+  
+  public void addBondNoCheck(Bond bond) {
+     if (bondCount == bonds.length)
       bonds = (Bond[]) AU.arrayCopyObject(bonds, bondCount + 1024);
     bonds[bondCount++] = bond;
     atomSetBondCounts[iSet]++;
@@ -735,6 +739,9 @@ public class AtomSetCollection {
 
   public int vibScale;
 
+  public int firstAtomToBond = -1; // topology dic only
+
+
   public void setInfo(String key, Object value) {
     if (value == null)
       atomSetInfo.remove(key);
