@@ -148,8 +148,8 @@ public abstract class AtomSetCollectionReader implements GenericLineReader {
   public M3 primitiveToCrystal;
 
   public AtomSetCollection asc;
-  protected BufferedReader reader;
-  protected GenericBinaryDocument binaryDoc;
+  public BufferedReader reader;
+  public GenericBinaryDocument binaryDoc;
   protected String readerName;
   public Map<String, Object> htParams;
   public Lst<P3[]> trajectorySteps;
@@ -187,6 +187,10 @@ public abstract class AtomSetCollectionReader implements GenericLineReader {
   protected boolean doCheckUnitCell;
   protected boolean getHeader;
   protected boolean isSequential;
+  public boolean optimize2D;
+  public boolean noHydrogens;
+  public boolean is2D;
+
   public boolean isMolecular; // only for CIF so that it can read multiple unit cells
   protected int templateAtomCount;
   public int modelNumber;
@@ -1072,6 +1076,8 @@ public abstract class AtomSetCollectionReader implements GenericLineReader {
     allow_a_len_1 =checkFilterKey("TOPOS");
     slabXY = checkFilterKey("SLABXY");
     polymerX = !slabXY && checkFilterKey("POLYMERX");
+    noHydrogens = checkFilterKey("NOH");
+    optimize2D = checkFilterKey("2D") && !noHydrogens;
 
     if (filter == null)
       return;
@@ -1243,6 +1249,9 @@ public abstract class AtomSetCollectionReader implements GenericLineReader {
     // MOL and JME - sets for ALL MODELS, but just for ModelLoader.
     // It is quite possible that multiple 2D models cannot be loaded as 3D
     asc.setInfo("is2D", Boolean.TRUE);
+    if (checkFilterKey("NOH"))
+      asc.setInfo("noHydrogen",
+          Boolean.TRUE);
     if (!checkFilterKey("NOMIN"))
       asc.setInfo("doMinimize",
           Boolean.TRUE);
