@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-07-19 09:55:17 +0530 (Tue, 19 Jul 2022) $
- * $Revision: 22431 $
+ * $Date: 2023-01-05 08:42:06 -0600 (Thu, 05 Jan 2023) $
+ * $Revision: 22500 $
  *
  * Copyright (C) 2003-2005  Miguel, Jmol Development, www.jmol.org
  *
@@ -26,6 +26,7 @@ package org.jmol.adapter.smarter;
 
 import java.io.BufferedInputStream;
 import java.io.BufferedReader;
+import java.io.EOFException;
 import java.io.InputStream;
 import java.util.Map;
 import java.util.StringTokenizer;
@@ -47,13 +48,13 @@ public class Resolver {
   private final static String[] readerSets = new String[] {
     "cif.", ";Cif;Cif2;MMCif;MMTF;MagCif",
     "molxyz.", ";Mol3D;Mol;Xyz;",
-    "more.", ";AFLOW;BinaryDcd;Gromacs;Jcampdx;MdCrd;MdTop;Mol2;TlsDataOnly;",
+    "more.", ";AFLOW;BinaryDcd;CDX;Gromacs;Jcampdx;MdCrd;MdTop;Mol2;TlsDataOnly;",
     "quantum.", ";Adf;Csf;Dgrid;GamessUK;GamessUS;Gaussian;GaussianFchk;GaussianWfn;Jaguar;" +
                  "Molden;MopacGraphf;GenNBO;NWChem;Psi;Qchem;QCJSON;" +
-                 "WebMO;MO;", // MO is for XmlMolpro 
+                 "WebMO;Orca;MO;", // MO is for XmlMolpro 
     "pdb.", ";Pdb;Pqr;P2n;JmolData;",
     "pymol.", ";PyMOL;",
-    "simple.", ";Alchemy;Ampac;Cube;FoldingXyz;GhemicalMM;HyperChem;Jme;JSON;Mopac;MopacArchive;Tinker;Input;FAH;Orca;",
+    "simple.", ";Alchemy;Ampac;Cube;FoldingXyz;GhemicalMM;HyperChem;Jme;JSON;Mopac;MopacArchive;Tinker;Input;FAH;",
     "spartan.", ";Spartan;SpartanSmol;Odyssey;",
     "xtal.", ";Abinit;Aims;Bilbao;Castep;Cgd;Crystal;Dmol;Espresso;Gulp;Jana;Magres;Shelx;Siesta;VaspOutcar;" +
              "VaspPoscar;Wien2k;Xcrysden;PWmat;Optimade;",
@@ -145,8 +146,9 @@ public class Resolver {
     htParams.put("ptFile", Integer.valueOf(ptFile));
     if (ptFile <= 0)
       htParams.put("readerName", readerName);
-    if (readerName.indexOf("Xml") == 0)
-      readerName = "Xml";
+// BH removed 2022.01.03 -- no longer necessary
+//    if (readerName.indexOf("Xml") == 0)
+//      readerName = "Xml";
     return getReader(readerName, htParams);
   }
 
@@ -170,6 +172,9 @@ public class Resolver {
   }
 
   private final static String getReaderFromType(String type) {
+    if (type.endsWith("(XML)")) {
+      type = "Xml" + type.substring(0, type.length() - 5);
+    }
     type = ";" + type.toLowerCase() + ";";
     if (";zmatrix;cfi;c;vfi;v;mnd;jag;adf;gms;g;gau;mp;nw;orc;pqs;qc;".indexOf(type) >= 0)
       return "Input";
@@ -254,6 +259,8 @@ public class Resolver {
     LimitedLineReader llr = new LimitedLineReader(rdr, 16384);
 
     String leader = llr.getHeader(LEADER_CHAR_MAX).trim();
+    if (leader.length() == 0)
+      throw new EOFException("File contains no data.");
 
     // Test 1. check magic number for embedded Jmol script or PNGJ
 
@@ -334,8 +341,21 @@ public class Resolver {
   // Test 2. check to see if first few bytes (trimmed) start with any of these strings
   ////////////////////////////////////////////////////////////////
 
+  private static byte[] cdxMagic = new byte[] { 'V', 'j', 'C', 'D' };
+  
   public static String getBinaryType(InputStream inputStream) {
-    return (Rdr.isPickleS(inputStream) ? "PyMOL" : (Rdr.getMagic(inputStream, 1)[0] & 0xDE) == 0xDE ? "MMTF" : null);
+    return (Rdr.isPickleS(inputStream) ? "PyMOL" : (Rdr.getMagic(inputStream, 1)[0] & 0xDE) == 0xDE ? "MMTF" : 
+      bytesMatch(Rdr.getMagic(inputStream, 4), cdxMagic) ? "CDX" : null);
+  }
+
+  private static boolean bytesMatch(byte[] a, byte[] b) {
+    if (b.length > a.length)
+      return false;
+    for (int i = b.length; --i >= 0;) {
+      if (a[i] != b[i])
+        return false;
+    }
+    return true;
   }
 
   private static String checkFileStart(String leader) {
@@ -876,6 +896,9 @@ public class Resolver {
   private final static String[] optimadeContainsRecords = 
   { "Optimade", "\"cartesian_site_positions\":", "\"api_version\":", "optimade"};
 
+  private final static String[] jsonArrayContainsRecords = 
+  { "JSON", "\"atomArray\":[", "\"atomArray\" : ["};
+
   private final static String[] orcaContainsRecords = 
   { "Orca", "* O   R   C   A *" };
 
@@ -908,12 +931,11 @@ public class Resolver {
     espressoContainsRecords, siestaContainsRecords, xcrysDenContainsRecords,
     mopacArchiveContainsRecords,abinitContainsRecords,gaussianFchkContainsRecords,
     inputContainsRecords, aflowContainsRecords, magCifContainsRecords, 
-    qcJsonContainsRecords, optimadeContainsRecords, orcaContainsRecords,
+    qcJsonContainsRecords, optimadeContainsRecords, orcaContainsRecords, jsonArrayContainsRecords
   };
 
   private final static String[][] jsonContainsRecords =
-  { optimadeContainsRecords 
-  };
+  { optimadeContainsRecords };
   
   ////////////////////////////////////////////////////////////////
   // Test 6. check second time for special file types
