@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-04-21 17:38:02 -0500 (Thu, 21 Apr 2022) $
- * $Revision: 22405 $
+ * $Date: 2022-12-11 13:26:30 -0600 (Sun, 11 Dec 2022) $
+ * $Revision: 22490 $
  *
  * Copyright (C) 2003-2005  Miguel, Jmol Development, www.jmol.org
  *
@@ -35,10 +35,12 @@ import org.jmol.api.JmolAdapterBondIterator;
 import org.jmol.api.JmolAdapterStructureIterator;
 import org.jmol.api.JmolFilesReaderInterface;
 import org.jmol.script.SV;
+import org.jmol.util.BSUtil;
 import org.jmol.util.Logger;
 import org.jmol.viewer.Viewer;
 
 import javajs.api.GenericBinaryDocument;
+import javajs.util.BS;
 import javajs.util.Lst;
 import javajs.util.P3;
 import javajs.util.PT;
@@ -430,9 +432,16 @@ public class SmarterJmolAdapter extends JmolAdapter {
 
 
   @Override
-  public int getAtomCount(Object asc) {
-    AtomSetCollection a = (AtomSetCollection)asc; 
-    return (a.bsAtoms == null ? a.ac : a.bsAtoms.cardinality());
+  public int getAtomCount(Object asc, int atomSetIndex) {
+    AtomSetCollection a = (AtomSetCollection)asc;
+    if (atomSetIndex < 0)
+      return (a.bsAtoms == null ? a.ac : a.bsAtoms.cardinality());
+    if (a.bsAtoms == null)
+      return a.getAtomSetAtomCount(atomSetIndex);
+    BS b = BSUtil.copy(a.bsAtoms);
+    int i0 = a.getAtomSetAtomIndex(atomSetIndex);
+    b.and(BSUtil.newBitSet2(i0, i0 + a.getAtomSetAtomCount(atomSetIndex)));
+    return b.cardinality();
   }
 
   @Override
