@@ -1,3 +1,4 @@
+
 /* $RCSfile$
  * $Author: hansonr $
  * $Date: 2014-01-10 09:19:33 -0600 (Fri, 10 Jan 2014) $
@@ -868,6 +869,7 @@ public class XtalSymmetry {
     reset();
   }
 
+  @SuppressWarnings("cast") // DO NOT REMOVE
   private int symmetryAddAtoms(int transX, int transY, int transZ,
                                int baseCount, int pt, int iCellOpPt,
                                P3[] cartesians, MSInterface ms, BS excludedOps,
@@ -907,6 +909,7 @@ public class XtalSymmetry {
     if (checkRangeNoSymmetry)
       baseCount = noSymmetryCount;
     int atomMax = firstAtom + noSymmetryCount;
+    int bondAtomMin = (asc.firstAtomToBond < 0 ? atomMax : asc.firstAtomToBond);
     P3 pttemp = new P3();
     String code = null;
     float d0 = (checkOps ? 0.01f : 0.0001f);
@@ -944,7 +947,7 @@ public class XtalSymmetry {
       
       for (int i = i0; i < atomMax; i++) {
         Atom a = asc.atoms[i];
-        if (a.ignoreSymmetry || bsAtoms != null && !bsAtoms.get(i))
+        if (bsAtoms != null && !bsAtoms.get(i))
           continue;
 
         if (ms == null) {
@@ -1045,6 +1048,19 @@ public class XtalSymmetry {
             sym.getSpaceGroupOperation(iSym).rotate(atom1.vib);
             atom1.vib.scale(spinOp);
           }
+          if (atom1.isNegDisorder) {
+            // special negative disorder group in CifReader
+            if (disorderMap == null)
+              disorderMap = new Hashtable<Integer, Character>();
+            Integer key = Integer.valueOf(iSym *1000 + atom1.altLoc);
+            Character ch = disorderMap.get(key);
+            if (ch == null) {
+              if (disorderMapMax == 0 || disorderMapMax == 'Z')
+                disorderMapMax = (int) '@'; // necessary for legacy java2script JSmol
+              disorderMap.put(key, ch = new Character((char) (++disorderMapMax)));
+            }
+            atom1.altLoc = ch.charValue();
+          }
           atom1.atomSite = atomSite;
           if (code != null)
             atom1.altLoc = subSystemId;
@@ -1088,7 +1104,7 @@ public class XtalSymmetry {
             ia1 = ia2;
             ia2 = i;
           }
-          if (ia1 != ia2 && (ia1 >= atomMax || ia2 >= atomMax)
+          if (ia1 != ia2 && (ia1 >= bondAtomMin || ia2 >= bondAtomMin)
               && bondsFound.indexOf(key = "-" + ia1 + "," + ia2) < 0) {
             bondsFound.append(key);
             asc.addNewBondWithOrder(ia1, ia2, bond.order);//.distance = d;
@@ -1098,6 +1114,9 @@ public class XtalSymmetry {
     }
     return pt;
   }
+  
+  private Map<Integer, Character> disorderMap;
+  private int disorderMapMax;
 
   @SuppressWarnings("unchecked")
   private void duplicateAtomProperties(int nTimes) {
