@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-05-12 10:38:41 -0500 (Thu, 12 May 2022) $
- * $Revision: 22410 $
+ * $Date: 2022-12-11 13:26:30 -0600 (Sun, 11 Dec 2022) $
+ * $Revision: 22490 $
  *
  * Copyright (C) 2003-2005  The Jmol Development Team
  *
@@ -37,6 +37,8 @@ import org.jmol.util.BoxInfo;
 
 import javajs.util.P3;
 import javajs.util.V3;
+
+import org.jmol.viewer.JC;
 import org.jmol.viewer.Viewer;
 
 /**
@@ -283,6 +285,10 @@ abstract public class JmolViewer {
     return Viewer.getJmolVersion();
   }
 
+  static public String getJmolVersionNoDate() {
+    return JC.version;
+  }
+
   /**
    * for POV-Ray 
    * @param params
