@@ -42,7 +42,7 @@ public interface SymmetryInterface {
 
   String fcoord(T3 p);
 
-  Object findSpaceGroup(Viewer vwr, BS atoms, String op, boolean asString);
+  Object findSpaceGroup(Viewer vwr, BS atoms, String xyzList, float[] unitcellParams, boolean asString, boolean isAssign);
 
   Lst<P3> generateCrystalClass(P3 pt0);
 
@@ -98,7 +98,7 @@ public interface SymmetryInterface {
 
   Map<String, Object> getSpaceGroupInfo(ModelSet modelSet, String spaceGroup, int modelIndex, boolean isFull, float[] cellParams);
 
-  Object getSpaceGroupInfoObj(String name, SymmetryInterface cellInfo,
+  Object getSpaceGroupInfoObj(String name, float[] params,
                               boolean isFull, boolean addNonstandard);
 
   String getSpaceGroupName();
@@ -116,8 +116,6 @@ public interface SymmetryInterface {
 
   int getSpaceGroupOperationCount();
   
-  M4 getSpaceGroupOperationRaw(int i);
-  
   String getSpaceGroupXyz(int i, boolean doNormalize);
 
   float getSpinOp(int op);
@@ -195,7 +193,7 @@ public interface SymmetryInterface {
   BS notInCentroid(ModelSet modelSet, BS bsAtoms,
                           int[] minmax);
 
-  BS removeDuplicates(ModelSet ms, BS bs);
+  BS removeDuplicates(ModelSet ms, BS bs, boolean highPrec);
 
   V3[] rotateAxes(int iop, V3[] axes, P3 ptTemp, M3 mTemp);
 
@@ -220,7 +218,7 @@ public interface SymmetryInterface {
                                      T3 center, T3[] atomset,
                                      BS bsAtoms,
                                      boolean haveVibration,
-                                     float distanceTolerance, float linearTolerance, boolean localEnvOnly);
+                                     float distanceTolerance, float linearTolerance, int maxAtoms, boolean localEnvOnly);
 
   void setSpaceGroup(boolean doNormalize);
 
@@ -259,4 +257,8 @@ public interface SymmetryInterface {
 
   void unitize(T3 ptFrac);
 
+  boolean isWithinUnitCell(P3 pt, float x, float y, float z);
+
+  boolean checkPeriodic(P3 pt);
+
 }
