@@ -122,8 +122,7 @@ public class DSSR1 extends AnnotationParser {
       info = vwr.ms.getModelAuxiliaryInfo(modelIndex);
       if (info.containsKey("dssr"))
         break;
-      BS bs = vwr.getModelUndeletedAtomsBitSet(modelIndex);
-      bs.and(vwr.ms.getAtoms(T.nucleic, null));
+      BS bs = vwr.restrictToModel(vwr.ms.getAtoms(T.nucleic, null), modelIndex);
       if (bs.nextClearBit(0) < 0) {
         info = null;
         break;
@@ -376,8 +375,8 @@ public class DSSR1 extends AnnotationParser {
       }
       if (n != Integer.MIN_VALUE && dbObj instanceof Lst) {
         if (n <= 0)
-          n += ((Lst) dbObj).size();
-        dbObj = ((Lst) dbObj).get(n - 1);        
+          n += ((Lst<?>) dbObj).size();
+        dbObj = ((Lst<?>) dbObj).get(n - 1);        
       }
       bs.or(vwr.ms.getAtoms(T.sequence, dbObj.toString()));
       bs.and(bsModel);
