@@ -25,12 +25,6 @@ package org.jmol.export;
 
 import java.util.Map;
 
-import javajs.util.M3;
-import javajs.util.M4;
-import javajs.util.P3;
-import javajs.util.P3i;
-import javajs.util.T3;
-
 import org.jmol.api.Interface;
 import org.jmol.api.JmolRendererInterface;
 import org.jmol.g3d.HermiteRenderer;
@@ -41,6 +35,12 @@ import org.jmol.util.GData;
 import org.jmol.util.MeshSurface;
 import org.jmol.viewer.Viewer;
 
+import javajs.util.M3;
+import javajs.util.M4;
+import javajs.util.P3;
+import javajs.util.P3i;
+import javajs.util.T3;
+
 public class Export3D implements JmolRendererInterface {
 
   protected ___Exporter exporter;
@@ -826,4 +826,9 @@ public class Export3D implements JmolRendererInterface {
     gdata.renderAllStrings(this);
   }
 
+  @Override
+  public void drawLinePixels(P3i sA, P3i sB, int z, int zslab) {
+    return;
+  }
+
 }
