@@ -1,7 +1,7 @@
 /* $RCSfile$
  *  * $Author: hansonr $
- * $Date: 2019-11-17 22:49:25 -0600 (Sun, 17 Nov 2019) $
- * $Revision: 22002 $
+ * $Date: 2022-07-24 20:37:43 +0530 (Sun, 24 Jul 2022) $
+ * $Revision: 22433 $
  *
  * Copyright (C) 2003-2006  Miguel, Jmol Development, www.jmol.org
  *
@@ -1030,6 +1030,8 @@ final public class Graphics3D extends GData implements JmolRendererInterface {
     if (y + heightFill > height)
       heightFill = height - y;
     int c = argbCurrent;
+    if (isAntialiased())
+      c = fixTextImageRGB(c);
     int[] zb = zbuf;
     Pixelator p = pixel;
     while (--heightFill >= 0)
@@ -1206,11 +1208,6 @@ final public class Graphics3D extends GData implements JmolRendererInterface {
     }
   }
 
-  @Override
-  public void setFontFid(byte fid) {
-    currentFont = Font.getFont3D(fid);
-  }
-
   @Override
   public void setFont(Font font3d) {
     currentFont = font3d;
@@ -1282,18 +1279,22 @@ final public class Graphics3D extends GData implements JmolRendererInterface {
     }
     setScreeni(pointA, sA);
     setScreeni(pointB, sB);
-    line3d.plotLineBits(argbCurrent, argbCurrent, sA, sB, run, rise, true);
-    if (isAntialiased()) {
-      if (Math.abs(pointA.x - pointB.x) < Math.abs(pointA.y - pointB.y)) {
+    drawLineABBits(run, rise, true);
+  }
+
+  public void drawLineABBits(int run, int rise, boolean andClip) {
+    line3d.plotLineBits(argbCurrent, argbCurrent, sA, sB, run, rise, andClip);
+//    if (true || isAntialiased()) {
+      if (Math.abs(sA.x - sB.x) < Math.abs(sA.y - sB.y)) {
         sA.x += 1;
         sB.x += 1;
-        line3d.plotLineBits(argbCurrent, argbCurrent, sA, sB, run, rise, true);        
+        line3d.plotLineBits(argbCurrent, argbCurrent, sA, sB, run, rise, andClip);
       } else {
         sA.y += 1;
         sB.y += 1;
-        line3d.plotLineBits(argbCurrent, argbCurrent, sA, sB, run, rise, true);
+        line3d.plotLineBits(argbCurrent, argbCurrent, sA, sB, run, rise, andClip);
       }
-    }
+//    }
   }
 
   private void setScreeni(P3 pt, P3i p) {
@@ -1336,6 +1337,19 @@ final public class Graphics3D extends GData implements JmolRendererInterface {
     }
   }
 
+  @Override
+  public void drawLinePixels(P3i a, P3i b, int z, int zslab) {
+    sA.setT(a);
+    sB.setT(b);
+    sA.z = sB.z = z;//(zslab == Integer.MIN_VALUE ? 2 : zslab);
+    int slab0 = slab;
+    if (zslab == Integer.MIN_VALUE)
+      slab = 0;
+    drawLineABBits(0,  0,  false);
+    slab = slab0;
+  }
+  
+
   @Override
   public void drawLineAB(P3 pointA, P3 pointB) {
     // draw quadrilateral and hermite
@@ -2083,4 +2097,12 @@ final public class Graphics3D extends GData implements JmolRendererInterface {
     return false;
   }
 
+  public static int fixTextImageRGB(int argb) {
+    // an interesting problem with antialiasing occurs if 
+    // the label is black or almost black.
+    // specifically, I think, argb < 0x00000004
+    // such is also the case for a black scale on a white background
+    return ((argb & 0xC0C0C0) == 0 ? argb | 0x040404 : argb);
+  }
+
 }
