@@ -45,6 +45,7 @@ import javajs.util.BS;
 import javajs.util.Lst;
 import javajs.util.P3;
 import javajs.util.PT;
+import net.sf.jniinchi.INCHI_BOND_STEREO;
 import net.sf.jniinchi.INCHI_BOND_TYPE;
 import net.sf.jniinchi.INCHI_PARITY;
 import net.sf.jniinchi.INCHI_STEREOTYPE;
@@ -169,10 +170,30 @@ public class InChIJNI implements JmolInChI {
     Bond[] bonds = vwr.ms.bo;
     for (int i = bsBonds.nextSetBit(0); i >= 0; i = bsBonds.nextSetBit(i + 1)) {
       Bond bond = bonds[i];
-      INCHI_BOND_TYPE order = getOrder(bond.getCovalentOrder());
-      if (order != null)
-        mol.addBond(new JniInchiBond(atoms[map[bond.getAtomIndex1()]],
-            atoms[map[bond.getAtomIndex2()]], order));
+      // partial bonds (as in ferrocene) become at least 1
+      // but oddly still do not get generated, probably because the carbons are then too strange?
+      INCHI_BOND_TYPE order = getOrder(Math.max(bond.isPartial() ? 1 : 0, bond.getCovalentOrder()));
+      if (order != null) {
+        INCHI_BOND_STEREO stereo;
+        switch (bond.getBondType()) {
+        case Edge.BOND_STEREO_FAR:
+          stereo = INCHI_BOND_STEREO.SINGLE_1DOWN;
+          break;
+        case Edge.BOND_STEREO_NEAR:
+          stereo = INCHI_BOND_STEREO.SINGLE_1UP;
+          break;
+        case Edge.BOND_STEREO_EITHER:
+          // this will generate a stereo ?
+          stereo = INCHI_BOND_STEREO.SINGLE_1EITHER;
+          break;
+        default:
+            stereo = INCHI_BOND_STEREO.NONE;
+            break;
+        }
+        JniInchiBond b = new JniInchiBond(atoms[map[bond.getAtomIndex1()]],
+            atoms[map[bond.getAtomIndex2()]], order, stereo);
+        mol.addBond(b);
+      }
     }
     return mol;
   }
