@@ -174,6 +174,11 @@ public class JvxlXmlReader extends VolumeFileReader {
    cJvxlEdgeNaN = (char) (edgeFractionBase + edgeFractionRange);
   }
 
+  @Override
+  protected float getJVXLCutoff() {
+    return params.cutoff;
+  }
+
   protected void readVector(int voxelVectorIndex) throws Exception {
     String data = xr.getXmlData("jvxlVolumeVector", tempDataXml, true, true);
     tempDataXml = tempDataXml.substring(tempDataXml.indexOf(data) + data.length());
@@ -206,12 +211,19 @@ public class JvxlXmlReader extends VolumeFileReader {
   }
 
   protected void jvxlReadSurfaceInfo() throws Exception {
-    String s;
     String data = xr.getXmlData("jvxlSurfaceInfo", null, true, true);
     isXLowToHigh = XmlReader.getXmlAttrib(data, "isXLowToHigh").equals("true");
-    jvxlCutoff = parseFloatStr(XmlReader.getXmlAttrib(data, "cutoff"));
-    if (!Float.isNaN(jvxlCutoff))
-      Logger.info("JVXL read: cutoff " + jvxlCutoff);
+    String s = XmlReader.getXmlAttrib(data, "cutoff");
+    if (s.indexOf(" ") < 0) {
+      jvxlCutoff = parseFloatStr(s);
+      if (!Double.isNaN(jvxlCutoff))
+        Logger.info("JVXL read: cutoff " + jvxlCutoff);
+    } else {
+      jvxlCutoffRange = parseFloatArrayStr(s);
+      jvxlCutoff = jvxlCutoffRange[0];
+      Logger.info("JVXL read: cutoff " + Escape.eAF(jvxlCutoffRange));
+    }
+    params.cutoff = jvxlCutoff;
     int nContourData = parseIntStr(XmlReader.getXmlAttrib(data, "nContourData"));
     haveContourData = (nContourData > 0);
     params.isContoured = jvxlData.isModelConnected = XmlReader.getXmlAttrib(data, "contoured").equals("true");
