@@ -323,6 +323,7 @@ public class SurfaceGenerator {
       // not all readers will take this, so we assign
       // cutoff to the value as well.
       params.cutoff = params.sigma = ((Float) value).floatValue();
+      params.cutoffRange = null;
       //params.isPositiveOnly = false;
       params.cutoffAutomatic = false;
       return true;
@@ -330,10 +331,28 @@ public class SurfaceGenerator {
 
     if ("cutoff" == propertyName) {
       params.cutoff = ((Float) value).floatValue();
+      params.cutoffRange = null;
       params.isPositiveOnly = false;
       params.cutoffAutomatic = false;
       return true;
     }
+    
+    if ("cutoffPositive" == propertyName) {
+      params.cutoff = ((Float) value).floatValue();
+      params.cutoffRange = null;
+      params.isPositiveOnly = true;
+      params.isCutoffAbsolute = false;
+      params.cutoffAutomatic = false;
+      return true;
+    }
+
+    if ("cutoffRange" == propertyName) {
+        params.cutoffRange = (float[]) value;
+        params.cutoff = params.cutoffRange[0];
+        params.isPositiveOnly = false;
+        params.cutoffAutomatic = false;
+        return true;
+    }
 
     if ("parameters" == propertyName) {
       params.parameters = AU.ensureLengthA((float[]) value, 2);
@@ -342,13 +361,6 @@ public class SurfaceGenerator {
       return true;
     }
 
-    if ("cutoffPositive" == propertyName) {
-      params.cutoff = ((Float) value).floatValue();
-      params.isPositiveOnly = true;
-      params.isCutoffAbsolute = false;
-      return true;
-    }
-
     if ("cap" == propertyName || "slab" == propertyName) {
       if (value != null)
         params.addSlabInfo((Object[]) value);
@@ -1033,6 +1045,7 @@ public class SurfaceGenerator {
     if (!surfaceReader.createIsosurface(false)) {
       Logger.error("Could not create isosurface");
       params.cutoff = Float.NaN;
+      params.cutoffRange = null;
       surfaceReader.closeReader();
       return;
     }
@@ -1103,6 +1116,7 @@ public class SurfaceGenerator {
       boolean isSquared = params.isSquared;
       params.isSquared = false;
       params.cutoff = 0;
+      params.cutoffRange = null;
       surfaceReader.volumeData.setMappingPlane(params.thePlane);
       surfaceReader.createIsosurface(!params.isPeriodic);//but don't read volume data yet
       surfaceReader.volumeData.setMappingPlane(null);
@@ -1188,8 +1202,10 @@ public class SurfaceGenerator {
       // [BufferedFileReader[], float[]] -> [VolumeFileReader[], float[]]
       Object[] a = (Object[]) ((Object[]) value)[0];
       VolumeFileReader[] b = new VolumeFileReader[a.length];
-      for (int i = 0; i < a.length; i++)
+      for (int i = 0; i < a.length; i++) {
+        this.fileType = fileType;
         b[i] = (VolumeFileReader) setFileData(vwr, a[i]);
+      }
       ((Object[]) value)[0] = b;
       readerData = value;
       return newReader("IsoIntersectGridReader");
