@@ -394,7 +394,7 @@ public class Minimizer {
         i1 = i2;
         i2 = ii;
       }
-      int bondOrder = bond.getCovalentOrder();
+      int bondOrder = (bond.isPartial() ? 0 : bond.getCovalentOrder());
       switch (bondOrder) {
       case 0:
         // hydrogen bond
