@@ -54,13 +54,13 @@ public class ModelKitPopupResourceBundle extends PopupResource {
     { MENU_NAME, "atomMenu bondMenu xtalMenu optionsMenu" },
     { "optionsMenu", "new center addh minimize hmin " +
         " - undo redo - SIGNEDsaveFile SIGNEDsaveState exit!Persist" },
-    { ModelKitPopup.ATOM_MENU , "assignAtom_XP!RD assignAtom_XxP!RD dragAtomP!RD dragMinimizeP!RD dragMoleculeP!RD dragMinimizeMoleculeP!RD " +
-        "invertStereoP!RD - assignAtom_CP!RD assignAtom_HP!RD assignAtom_NP!RD assignAtom_OP!RD assignAtom_FP!RD assignAtom_ClP!RD assignAtom_BrP!RD " +
+    { ModelKit.ATOM_MODE , "assignAtom_XxP!RD dragAtomP!RD dragMinimizeP!RD dragMoleculeP!RD dragMinimizeMoleculeP!RD " +
+        "invertStereoP!RD -  assignAtom_XP!RD assignAtom_CP!RD assignAtom_HP!RD assignAtom_NP!RD assignAtom_OP!RD assignAtom_FP!RD assignAtom_ClP!RD assignAtom_BrP!RD " +
         "_??P!RD _??P!RD _??P!RD " +
-        "moreAtomMenu - assignAtom_plP!RD assignAtom_miP!RD" },
-    { "moreAtomMenu", "clearQPersist - _??P!RD _??P!RD _??P!RD _??P!RD _??P!RD _??P!RD " },
-    { ModelKitPopup.BOND_MENU, "assignBond_0P!RD assignBond_1P!RD assignBond_2P!RD assignBond_3P!RD assignBond_pP!RD assignBond_mP!RD rotateBondP!RD" },
-    { ModelKitPopup.XTAL_MENU, "xtalModePersistMenu xtalSelPersistMenu xtalSelOpPersistMenu operator xtalPackingPersistMenu xtalEditOptPersistMenu xtalOptionsPersistMenu" },
+        "moreAtomMenu assignAtom_plP!RD assignAtom_miP!RD" },
+    { "moreAtomMenu", "clearQPersist , _??P!RD _??P!RD _??P!RD _??P!RD _??P!RD _??P!RD " },
+    { ModelKit.BOND_MODE, "assignBond_0P!RD assignBond_1P!RD assignBond_2P!RD assignBond_3P!RD assignBond_pP!RD assignBond_mP!RD rotateBondP!RD" },
+    { ModelKit.XTAL_MODE, "xtalModePersistMenu xtalSelPersistMenu xtalSelOpPersistMenu operator xtalPackingPersistMenu xtalEditOptPersistMenu xtalOptionsPersistMenu" },
     { "xtalModePersistMenu", "mkmode_molecular mkmode_view mkmode_edit" }, 
     { "xtalSelPersistMenu", "mksel_atom mksel_position" },    
     { "xtalSelOpPersistMenu", "xtalOp!PersistMenu mkselop_atom2 mkselop_addOffset" },
@@ -91,12 +91,12 @@ public class ModelKitPopupResourceBundle extends PopupResource {
     
     boolean wasTranslating = GT.setDoTranslate(true);
     String[] words = new String[] {
-        ModelKitPopup.ATOM_MENU, "<atoms.png>",//GT.$("atoms"),
+        ModelKit.ATOM_MODE, "<atoms.png>",//GT.$("atoms"),
         "moreAtomMenu", "<dotdotdot.png>",//GT.$("more..."),
-        ModelKitPopup.BOND_MENU, "<bonds.png>",//GT.$("bonds"),
+        ModelKit.BOND_MODE, "<bonds.png>",//GT.$("bonds"),
         "optionsMenu", "<dotdotdot.png>",//GT.$("atoms"),
         "operator", "(no operator selected)",
-        ModelKitPopup.XTAL_MENU, "<xtal.png>",
+        ModelKit.XTAL_MODE, "<xtal.png>",
         "xtalModePersistMenu","mode",
         "xtalSelPersistMenu","select atom or position",
         "xtalSelOpPersistMenu","select operator", 
@@ -133,13 +133,13 @@ public class ModelKitPopupResourceBundle extends PopupResource {
         "clearQPersist", GT.$("clear"),
         "SIGNEDsaveFile", GT.$("save file"),
         "SIGNEDsaveState", GT.$("save state"),
-        "invertStereoP!RD", GT.$("invert ring stereochemistry"),
-        "assignAtom_XP!RD" , GT.$("delete atom"),
-        "assignAtom_XxP!RD" , GT.$("drag to bond"),
-        "dragAtomP!RD" , GT.$("drag atom"),
-        "dragMinimizeP!RD" , GT.$("drag atom (and minimize)"),
-        "dragMoleculeP!RD" , GT.$("drag molecule (ALT to rotate)"),
-        "dragMinimizeMoleculeP!RD" , GT.$("drag and minimize molecule (docking)"),
+        "invertStereoP!RD", ModelKit.getText("invStereo"),
+        "assignAtom_XP!RD" , ModelKit.getText("delAtom"),
+        "assignAtom_XxP!RD" , ModelKit.getText("dragBond"),
+        "dragAtomP!RD" , ModelKit.getText("dragAtom"),
+        "dragMinimizeP!RD" , ModelKit.getText("dragMinimize"),
+        "dragMoleculeP!RD" , ModelKit.getText("dragMolecule"),
+        "dragMinimizeMoleculeP!RD" , ModelKit.getText("dragMMol"),
         "assignAtom_CP!RD" , "C",
         "assignAtom_HP!RD" , "H",
         "assignAtom_NP!RD" , "N",
@@ -148,15 +148,15 @@ public class ModelKitPopupResourceBundle extends PopupResource {
         "assignAtom_ClP!RD" , "Cl",
         "assignAtom_BrP!RD" , "Br",
         "_??P!RD", "??",
-        "assignAtom_plP!RD", GT.$("increase charge"),
-        "assignAtom_miP!RD", GT.$("decrease charge"),
-        "assignBond_0P!RD" , GT.$("delete bond"),
-        "assignBond_1P!RD", GT.$("single"),
-        "assignBond_2P!RD", GT.$("double"),
-        "assignBond_3P!RD", GT.$("triple"),
-        "assignBond_pP!RD", GT.$("increase order"),
-        "assignBond_mP!RD", GT.$("decrease order"),
-        "rotateBondP!RD", GT.$("rotate bond"),
+        "assignAtom_plP!RD", ModelKit.getText("incCharge"),
+        "assignAtom_miP!RD", ModelKit.getText("decCharge"),
+        "assignBond_0P!RD" , ModelKit.getText("bondTo0"),
+        "assignBond_1P!RD", ModelKit.getText("bondTo1"),
+        "assignBond_2P!RD", ModelKit.getText("bondTo2"),
+        "assignBond_3P!RD", ModelKit.getText("bondTo3"),
+        "assignBond_pP!RD", ModelKit.getText("incBond"),
+        "assignBond_mP!RD", ModelKit.getText("decBond"),
+        "rotateBondP!RD", ModelKit.getText("rotBond"),
         "exit!Persist", GT.$("exit modelkit mode"),
     };
  
