@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-03-11 11:09:21 -0600 (Fri, 11 Mar 2022) $
- * $Revision: 22365 $
+ * $Date: 2023-01-07 08:24:29 -0600 (Sat, 07 Jan 2023) $
+ * $Revision: 22501 $
 
  *
  * Copyright (C) 2003-2005  The Jmol Development Team
@@ -435,9 +435,16 @@ public class Atom extends Point3fi implements Node {
     if (isDeleted())
       return -1;
     int n = valence;
-    if (n == 0 && bonds != null)
-      for (int i = bonds.length; --i >= 0;)
+    if (n == 0 && bonds != null) {
+      int npartial = 0;
+      for (int i = bonds.length; --i >= 0;) {
         n += bonds[i].getValence();
+        if (bonds[i].is(Edge.BOND_AROMATIC))
+          npartial++;
+      }
+      if (n > 0 && n < 3 && npartial != 0)
+        n++;
+    }
     return n;
   }
 
@@ -446,11 +453,25 @@ public class Atom extends Point3fi implements Node {
     if (bonds == null)
       return 0;
     int n = 0;
-    Bond b;
-    for (int i = bonds.length; --i >= 0; )
-      if (((b = bonds[i]).order & Edge.BOND_COVALENT_MASK) != 0
+    for (int i = bonds.length; --i >= 0; ) {
+      Bond b = bonds[i];
+      if (b.isCovalentNotPartial0() 
           && !b.getOtherAtom(this).isDeleted())
         ++n;
+    }
+    return n;
+  }
+
+  public int getCovalentOrPartialBondCount() {
+    if (bonds == null)
+      return 0;
+    int n = 0;
+    for (int i = bonds.length; --i >= 0; ) {
+      Bond b = bonds[i];
+      if (b.isCovalent() 
+          && !b.getOtherAtom(this).isDeleted())
+        ++n;
+    }
     return n;
   }
 
@@ -460,12 +481,13 @@ public class Atom extends Point3fi implements Node {
       return 0;
     int n = 0;
     for (int i = bonds.length; --i >= 0; ) {
-      if ((bonds[i].order & Edge.BOND_COVALENT_MASK) == 0)
-        continue;
+      Bond b = bonds[i];
+      if (b.isCovalentNotPartial0()) {
       Atom a = bonds[i].getOtherAtom(this);
       if (a.valence >= 0 && a.getElementNumber() == 1)
         ++n;
     }
+    }
     return n;
   }
 
@@ -1275,12 +1297,8 @@ public class Atom extends Point3fi implements Node {
         case T.psi:
           return getFractionalCoord(!vwr.g.legacyJavaFloat, 'Y', false, ptTemp);
         case T.omega:
-          if (group.chain.model.isJmolDataFrame
-              && group.chain.model.jmolFrameType
-                  .equals("plot ramachandran")) {
-            float omega = getFractionalCoord(!vwr.g.legacyJavaFloat, 'Z', false, ptTemp) - 180;
-            return (omega < -180 ? 360 + omega : omega);
-          }
+          float omega = getFractionalCoord(!vwr.g.legacyJavaFloat, 'Z', false, ptTemp) - 180;
+          return (omega < -180 ? 360 + omega : omega);
         }
       }
       return group.getGroupParameter(tokWhat);
