@@ -389,10 +389,14 @@ public class LabelToken {
         ++ich;
       }
       if (ich < cch && PT.isDigit(ch = strFormat.charAt(ich))) {
+        ++ich;
         lt.precision = ch - '0';
+        if (ich < cch && PT.isDigit(ch = strFormat.charAt(ich))) {
+          ++ich;
+          lt.precision = lt.precision * 10 + (ch - '0');
+        }
         if (isNegative)
           lt.precision = -1 - lt.precision;
-        ++ich;
       }
     }
     if (ich < cch && htValues != null)
@@ -603,7 +607,7 @@ public class LabelToken {
         strT = atom.atomPropertyString(vwr, t.tok);
         break;
       case T.w:
-        strT = atom.getIdentityXYZ(false, ptTemp);
+        strT = atom.getIdentityXYZ(ptTemp, Atom.ID_U);
         break;
         
       // characters only
