@@ -146,7 +146,7 @@ public final class ModelLoader {
   public boolean isTrajectory; 
   private boolean isPyMOLsession;
   private boolean doMinimize;
-  private boolean doAddHydrogens;
+  private boolean doAddPDBHydrogens;
 
   private String fileHeader;
   private BioResolver jbr;
@@ -154,6 +154,7 @@ public final class ModelLoader {
   private int groupCount;
   private P3 modulationTUV;
   private boolean isSupercell;
+  private boolean noH;
   
 
   @SuppressWarnings("unchecked")
@@ -176,7 +177,7 @@ public final class ModelLoader {
     if (isTrajectory)
       ms.trajectory = newTrajectory(ms, steps);
     isPyMOLsession = ms.getMSInfoB("isPyMOL");
-    doAddHydrogens = (jbr != null && !isTrajectory && !isPyMOLsession
+    doAddPDBHydrogens = (jbr != null && !isTrajectory && !isPyMOLsession
         && !ms.getMSInfoB("pdbNoHydrogens") && (ms
         .getMSInfoB("pdbAddHydrogens") || vwr.getBoolean(T.pdbaddhydrogens)));
     if (info != null) {
@@ -197,8 +198,9 @@ public final class ModelLoader {
       modulationTUV = (mod == Boolean.TRUE ? null : (P3) mod);
     }
     noAutoBond = ms.getMSInfoB("noAutoBond");
+    noH = ms.getMSInfoB("noHydrogen");
     is2D = ms.getMSInfoB("is2D");
-    doMinimize = (is2D || ms.getMSInfoB("minimize3D")) && ms.getMSInfoB("doMinimize");
+    doMinimize = (is2D && !noH || ms.getMSInfoB("minimize3D")) && ms.getMSInfoB("doMinimize");
     adapterTrajectoryCount = (isTrajectory ? ms.trajectory.steps.size() : 0);
     ms.someModelsHaveSymmetry = ms.getMSInfoB(JC.getBoolName(JC.GLOBAL_SYMMETRY));
     someModelsHaveUnitcells = ms.getMSInfoB(JC.getBoolName(JC.GLOBAL_UNITCELLS));
@@ -280,17 +282,16 @@ public final class ModelLoader {
     return ms.ac;
   }
 
-  private void createModelSet(JmolAdapter adapter, Object asc, BS bsNew) {
-    int nAtoms = (adapter == null ? 0 : adapter.getAtomCount(asc));
+  private void createModelSet(JmolAdapter adapter, Object asc, BS bs2D) {
+    int nAtoms = (adapter == null ? 0 : adapter.getAtomCount(asc, -1));
     if (nAtoms > 0)
       Logger.info("reading " + nAtoms + " atoms");
-    adapterModelCount = (adapter == null ? 1 : adapter.getAtomSetCount(asc));
+    adapterModelCount = (adapter == null ? 1 : adapter
+        .getAtomSetCount(asc));
     // cannot append a trajectory into a previous model
-    appendToModelIndex = (ms.msInfo == null ? null
-        : ((Integer) ms.msInfo.get("appendToModelIndex")));
-    appendNew = !isMutate
-        && (!merging || adapter == null || adapterModelCount > 1 || isTrajectory
-            || vwr.getBoolean(T.appendnew) && appendToModelIndex == null);
+    appendToModelIndex = (ms.msInfo == null ? null : ((Integer) ms.msInfo.get("appendToModelIndex")));
+    appendNew = !isMutate && (!merging || adapter == null || adapterModelCount > 1
+        || isTrajectory || vwr.getBoolean(T.appendnew) && appendToModelIndex == null);
     htAtomMap.clear();
     chainOf = new Chain[defaultGroupCount];
     group3Of = new String[defaultGroupCount];
@@ -305,8 +306,9 @@ public final class ModelLoader {
     if (merging)
       mergeTrajAndVib(modelSet0, ms);
     initializeAtomBondModelCounts(nAtoms);
-    if (bsNew != null && (doMinimize || is2D)) {
-      bsNew.setBits(baseAtomIndex, baseAtomIndex + nAtoms);
+    if (!noH && bs2D != null && (doMinimize || is2D)) {
+      // 2D minimization is ONLY for first model
+      bs2D.setBits(baseAtomIndex, baseAtomIndex + adapter.getAtomCount(asc, 0));
     }
     if (adapter == null) {
       setModelNameNumberProperties(0, -1, "", 1, null, null, null);
@@ -354,7 +356,7 @@ public final class ModelLoader {
       applyStereochemistry();
     }
 
-    if (doAddHydrogens)
+    if (doAddPDBHydrogens)
       jbr.finalizeHydrogens();
 
     if (adapter != null) {
@@ -468,7 +470,7 @@ public final class ModelLoader {
         Object value = entry.getValue();
         // no deletions yet...
         BS bs = ms.getModelAtomBitSetIncludingDeleted(i, true);
-        if (doAddHydrogens) {
+        if (doAddPDBHydrogens) {
           boolean isGroup = (groupList != null && PT.isOneOf(key,  groupList));
           value = jbr.fixPropertyValue(bs, value, isGroup);
         }
@@ -509,7 +511,7 @@ public final class ModelLoader {
       ms.at = new Atom[nAtoms];
       ms.bo = new Bond[250 + nAtoms]; // was "2 *" -- WAY overkill.
     }
-    if (doAddHydrogens)
+    if (doAddPDBHydrogens)
       jbr.initializeHydrogenAddition();
     if (trajectoryCount > 1)
       ms.mc += trajectoryCount - 1;
@@ -525,7 +527,7 @@ public final class ModelLoader {
   }
 
   private void mergeGroups() {
-    Map<String, Object> info = modelSet0.getAuxiliaryInfo(null);
+    Map<String, Object> info = modelSet0.getModelSetAuxiliaryInfo(null);
     String[] mergeGroup3Lists = (String[]) info.get("group3Lists");
     int[][] mergeGroup3Counts = (int[][]) info.get("group3Counts");
     if (mergeGroup3Lists != null) {
@@ -788,12 +790,13 @@ public final class ModelLoader {
     // atom is created, but not all methods are safe, because it
     // has no group -- this is only an issue for debugging
     int iLast = -1;
+    int siteBase = 0;
     boolean isPdbThisModel = false;
     boolean addH = false;
     boolean isLegacyHAddition = false;//vwr.getBoolean(T.legacyhaddition);
     JmolAdapterAtomIterator iterAtom = adapter.getAtomIterator(asc);
-    int nAtoms = adapter.getAtomCount(asc);
-    ms.setCapacity(adapter.getAtomCount(asc));
+    int nAtoms = adapter.getAtomCount(asc, -1);
+    ms.setCapacity(adapter.getAtomCount(asc, -1));
     int nRead = 0;
     Model[] models = ms.am;
     if (ms.mc > 0)
@@ -806,15 +809,19 @@ public final class ModelLoader {
         iChain = 0;
         iModel = modelIndex;
         model = models[modelIndex];
+        BS mbs = model.bsAtoms;
+        if (merging && !appendNew && vwr.getOperativeSymmetry() != null) {
+          siteBase = getAtomSiteBase(mbs);
+        }
         currentChainID = Integer.MAX_VALUE;
         isNewChain = true;
         // set the internal array for model.bsAtoms to be large enough
-        model.bsAtoms.set(ms.ac + nAtoms);
-        model.bsAtoms.clearAll();
+        mbs.set(ms.ac + nAtoms);
+        mbs.clearAll();
         model.isOrderly = (appendToModelIndex == null);
         isPdbThisModel = model.isBioModel;
         iLast = modelIndex;
-        addH = isPdbThisModel && doAddHydrogens;
+        addH = isPdbThisModel && doAddPDBHydrogens;
         if (jbr != null)
           jbr.setHaveHsAlready(false);
       }
@@ -829,7 +836,7 @@ public final class ModelLoader {
       int charge = (addH ? getPdbCharge(group3, name) : iterAtom.getFormalCharge());
       
       Atom atom = addAtom(isPdbThisModel, iterAtom.getSymmetry(),
-          iterAtom.getAtomSite(),
+          iterAtom.getAtomSite() + siteBase,
           isotope,
           name,
           charge, 
@@ -875,6 +882,17 @@ public final class ModelLoader {
     Logger.info(nRead + " atoms created");
   }
 
+  private int getAtomSiteBase(BS mbs) {
+    int base = 0;
+      for (int i = mbs.nextSetBit(0); i >= 0; i = mbs.nextSetBit(i + 1)) {
+        Atom a = ms.at[i];
+        if (!AtomCollection.isDeleted(a) && a.atomSite > base) {
+          base = a.atomSite;
+        }
+      }
+    return base;
+  }
+
   private void addJmolDataProperties(Model m,
                                      Map<String, float[]> jmolDataProperties) {
     if (jmolDataProperties == null)
@@ -1039,6 +1057,7 @@ public final class ModelLoader {
   
   private int lastModel = -1;
   
+  
   private Bond bondAtoms(Object atomUid1, Object atomUid2, short order) {
     Atom atom1 = htAtomMap.get(atomUid1);
     if (atom1 == null) {
@@ -1064,19 +1083,25 @@ public final class ModelLoader {
         Map<String, Object> info = ms.getModelAuxiliaryInfo(m);
         isMOL2D = (info != null && "2D".equals(info.get("dimension")));
       }
-      bond = ms.bondMutually(atom1, atom2, (isMOL2D ? order : 1), ms.getDefaultMadFromOrder(1), 0);
-      if (vStereo == null) {
-        vStereo = new  Lst<Bond>();
+      bond = ms.bondMutually(atom1, atom2,
+          (isMOL2D ? order : Edge.BOND_AROMATIC_SINGLE),
+          ms.getDefaultMadFromOrder(1), 0);
+      if (isMOL2D) {
+        if (vStereo == null) {
+          vStereo = new Lst<Bond>();
+        }
+        vStereo.addLast(bond);
       }
-      vStereo.addLast(bond);
     } else {
-      bond = ms.bondMutually(atom1, atom2, order, ms.getDefaultMadFromOrder(order), 0);
+      bond = ms.bondMutually(atom1, atom2, order,
+          ms.getDefaultMadFromOrder(order), 0);
       if (bond.isAromatic()) {
         ms.someModelsHaveAromaticBonds = true;
       }
     }
     if (ms.bondCount == ms.bo.length) {
-      ms.bo = (Bond[]) AU.arrayCopyObject(ms.bo, ms.bondCount + BondCollection.BOND_GROWTH_INCREMENT);
+      ms.bo = (Bond[]) AU.arrayCopyObject(ms.bo,
+          ms.bondCount + BondCollection.BOND_GROWTH_INCREMENT);
     }
     ms.setBond(ms.bondCount++, bond);
     return bond;
@@ -1229,7 +1254,7 @@ public final class ModelLoader {
       ms.setModulation(null, true, modulationTUV, false);
     if (autoBonding) {
       ms.autoBondBs4(bs, bs, bsExclude, null, ms.defaultCovalentMad,
-          vwr.getBoolean(T.legacyautobonding));
+          vwr.getBoolean(T.legacyautobonding), null);
       Logger.info(
           "ModelSet: autobonding; use  autobond=false  to not generate bonds automatically");
     } else {
@@ -1401,8 +1426,10 @@ public final class ModelLoader {
 
   private void applyStereochemistry() {
 
+    int atomCount = ms.ac;//ms.am[ms.at[0].mi].bsAtoms.cardinality();
+    
     // 1) initialize average bond lengths
-    set2DLengths(baseAtomIndex, ms.ac);
+    set2DLengths(baseAtomIndex, atomCount);
     
     V3 v = new V3();
     
@@ -1431,18 +1458,18 @@ public final class ModelLoader {
     
     // 2) implicit stereochemistry 
     
-    set2dZ(baseAtomIndex, ms.ac, v);
+    set2dZ(baseAtomIndex, atomCount, v);
 
     // 3) explicit stereochemistry
     
     if (vStereo != null) {
       BS bsToTest = new BS();
-      bsToTest.setBits(baseAtomIndex, ms.ac);
+      bsToTest.setBits(baseAtomIndex, atomCount);
       for (int i = vStereo.size(); --i >= 0;) {
         Bond b = vStereo.get(i);
         float dz2 = (b.order == Edge.BOND_STEREO_NEAR ? 3 : -3);
         b.order = 1;
-        if (b.atom2.z != b.atom1.z && (dz2 < 0) == (b.atom2.z < b.atom1.z))
+        if (b.atom1.getBondCount() < 6 && b.atom2.z != b.atom1.z && (dz2 < 0) == (b.atom2.z < b.atom1.z))
           dz2 /= 3;
         //float dz1 = dz2/3;
         //b.atom1.z += dz1;
