@@ -110,7 +110,7 @@ public final class BioResolver implements Comparator<String[]> {
       ms = modelLoader.ms;
       vwr = modelLoader.ms.vwr;
       modelLoader.specialAtomIndexes = new int[ATOMID_MAX];
-      hasCONECT = (ms.getInfoM("someModelsHaveCONECT") == Boolean.TRUE);
+      hasCONECT = (ms.getInfoM(JC.getBoolName(JC.GLOBAL_CONECT)) == Boolean.TRUE);
     }
     return this;
   }
@@ -297,7 +297,7 @@ public final class BioResolver implements Comparator<String[]> {
     if (htGroupBonds.get(group3) != null)
       return;
     String[][] bondInfo = (model == null ? getPdbBondInfo(group3,
-        vwr.g.legacyHAddition) : getLigandBondInfo(adapter, model, group3));
+        vwr.getBoolean(T.legacyhaddition)) : getLigandBondInfo(adapter, model, group3));
     if (bondInfo == null)
       return;
     htGroupBonds.put(group3, Boolean.TRUE);
@@ -847,7 +847,7 @@ public final class BioResolver implements Comparator<String[]> {
       for (int i = m0, t0; i <= m1; i++)
         if ((m = models[i]) instanceof BioModel)
           for (int j = 0; j < 5; j++)
-            if ((bs = bsAll[t0 = mytypes[j]]) != null)
+            if ((bs = bsAll[t0 = mytypes[j]]) != null && !bs.isEmpty())
               ((BioModel) m).addStructureByBS(0, t0, types[j], bs);
       return;
     }
@@ -1704,6 +1704,12 @@ cpk on; select atomno>100; label %i; color chain; select selected & hetero; cpk
     return null;
   }
 
+  public BioModelSet getBioModelSet(ModelSet modelSet) {
+    if (modelSet.bioModelset == null)
+      modelSet.bioModelset = new BioModelSet().set(vwr, modelSet);
+    return modelSet.bioModelset;
+  }
+
 }
 
 
