@@ -1,9 +1,10 @@
 /* $RCSfile$
- * $Author: hansonr $
- * $Date: 2019-11-23 22:17:53 -0600 (Sat, 23 Nov 2019) $
- * $Revision: 22005 $
+ * $Author: aherraez $
+ * $Date: 2022-02-08 13:55:30 -0600 (Tue, 08 Feb 2022) $
+ * $Revision: 22334 $
+ * AH 2022-02-08, one more term passed to GT localization
  *
- * Copyright (C) 2000-2005  The Jmol Development Team
+ * Copyright (C) 2000-2022  The Jmol Development Team
  *
  * Contact: jmol-developers@lists.sf.net
  *
@@ -670,7 +671,7 @@ public class MainPopupResourceBundle extends PopupResource {
         "s50",null,
         "zoom50", "50%",
         "zoom800", "800%",
-        "JSConsole", "JavaScript Console",
+        "JSConsole", GT.$("JavaScript Console"),
         "jmolMenu", "Jmol",
         "date" , JC.date,
         "version", JC.version,
