@@ -29,12 +29,15 @@
 package org.jmol.quantum;
 
 
-//import java.text.NumberFormat;
+import java.io.BufferedReader;
+import java.io.File;
+import java.io.FileReader;
+import java.io.IOException;
+import java.text.NumberFormat;
 import java.util.Hashtable;
 import java.util.Map;
 
 import javajs.util.BS;
-import javajs.util.DF;
 import javajs.util.Lst;
 
 import org.jmol.modelset.Atom;
@@ -87,21 +90,21 @@ import org.jmol.viewer.Viewer;
  */
 public class NMRNoeMatrix {
   
-  static int id = 0;
+  static int staticid = 0;
   
   public static class NOEParams {
 
-    private boolean noesy;
+    boolean noesy;
 
     
     /**
      * the correlation time in seconds. typical value would be 80E-12
      */
-    private double tau;
-    private double freq;
-    private double tMix;
-    private double cutoff;
-    private double rhoStar;
+    double tau;
+    double freq;
+    double tMix;
+    double cutoff;
+    double rhoStar;
     {
       freq = 400 * 2 * Math.PI * 1E6; // freq (entered as MHz)
       tau = 80E-12; //sec (entered as ps)
@@ -237,14 +240,14 @@ public class NMRNoeMatrix {
   double[][] distanceMatrix;
   NOEAtom[] atoms;
   int nHAtoms, atomCounter, i, j, k, m, n, p, q;
-  private int[] atomMap;
+  int[] atomMap;
 
   /**
    * first index for this frame
    * 
    */
-  private int baseIndex = 0;
-  private final NOEParams params;
+  int baseIndex = 0;
+  final NOEParams params;
 
   private NMRNoeMatrix() {
     params = new NOEParams();
@@ -341,7 +344,7 @@ public class NMRNoeMatrix {
 
   private NMRNoeMatrix(NOEParams params) {
     this.params = params;
-    params.id = ++id;
+    params.id = ++staticid;
   }
 
   /**
@@ -363,16 +366,16 @@ public class NMRNoeMatrix {
     if (nHAtoms != atomCounter) {
       throw new Exception("Not all atoms have been read in yet!");
     }
-    boolean isNew = false;
+//    boolean isNew = false;
     if (params.tainted) {
       calcRelaxMatrix();
       Diagonalise();
-      isNew = true;
+//      isNew = true;
     }
     if (params.tainted || params.mixingChanged) {
       calcNoeMatrix();
       params.mixingChanged = false;
-      isNew = true;
+//      isNew = true;
     }
     params.tainted = false;
 //    if (isNew)
@@ -613,11 +616,11 @@ public class NMRNoeMatrix {
     }
   }
 
-//  static NumberFormat nf = NumberFormat.getInstance();
-//  static {
-//    nf.setMinimumFractionDigits(4);
-//    nf.setMaximumFractionDigits(4);
-//  }
+  static NumberFormat nf = NumberFormat.getInstance();
+  static {
+    nf.setMinimumFractionDigits(4);
+    nf.setMaximumFractionDigits(4);
+  }
   
   @Override
   public String toString() {
@@ -625,7 +628,7 @@ public class NMRNoeMatrix {
     sb = new StringBuffer();
     for (i = 0; i < nHAtoms; i++) {
       for (j = 0; j < nHAtoms; j++) {
-        sb.append(DF.formatDecimalDbl(noeM[i][j], 4) + "\t");
+        sb.append(nf.format(noeM[i][j]) + "\t");
 
       }
       sb.append("\n");
@@ -636,14 +639,14 @@ public class NMRNoeMatrix {
 
   public String toStringNormRow() {
     StringBuffer sb;
-//    NumberFormat nf = NumberFormat.getInstance();
-//    nf.setMinimumFractionDigits(4);
-//    nf.setMaximumFractionDigits(4);
+    NumberFormat nf = NumberFormat.getInstance();
+    nf.setMinimumFractionDigits(4);
+    nf.setMaximumFractionDigits(4);
     sb = new StringBuffer();
     for (i = 0; i < nHAtoms; i++) {
       for (j = 0; j < nHAtoms; j++) {
         double val = noeM[i][j] / noeM[i][i];
-        sb.append(DF.formatDecimalDbl(val, 4) + "\t");
+        sb.append(nf.format(val) + "\t");
 
       }
       sb.append("\n");
@@ -751,77 +754,77 @@ public class NMRNoeMatrix {
     }
   }
 
-//  private void doItAll(File file) {
-//
-//    System.out.println("starting");
-//    readAtomsFromFile(file);
-//    relaxMatrix = new double[nHAtoms][nHAtoms];
-//    eigenValues = new double[nHAtoms][nHAtoms];
-//    eigenVectors = new double[nHAtoms][nHAtoms];
-//    noeM = new double[nHAtoms][nHAtoms];
-//    System.out.println("read atoms: " + Integer.toString(nHAtoms));
-//    calcRelaxMatrix();
-//    System.out.println("built matrix");
-//    System.out.println("total iterations = " + Integer.toString(Diagonalise()));
-//    System.out.println("diagonalised matrix");
-//    calcNoeMatrix();
-//    System.out.println("calculated NOE matrix");
-//    System.out.println(toString());
-//    System.out.println("");
-//    System.out.println(toStringNormRow());
-//    try {
-//      calcNOEs();
-//    } catch (Exception e) {
-//      System.out.println(e.toString());
-//    }
-//    //    System.out.println(params.getNMRfreqMHz());
-//    //    System.out.println(params.getCorrelationTimeTauPS());
-//  }
-//
-//  private void readAtomsFromFile(File file) {
-//    atoms = new NOEAtom[200];
-//    nHAtoms = 0;
-//    BufferedReader br = null;
-//    try {
-//      br = new BufferedReader(new FileReader(file));
-//      br.readLine();
-//      System.out.println("found file");
-//      while (true) {
-//        //br.readLine();
-//        String[] linetokens = br.readLine().split("\\s+");
-//        // DAE changed to match particular H atom types in mm files with no atom names
-//        if (linetokens[1].matches("41") || linetokens[1].matches("44")) {
-//          atoms[nHAtoms] = new NOEAtom();
-//          atoms[nHAtoms].x = Double.valueOf(linetokens[14]).doubleValue();
-//          atoms[nHAtoms].y = Double.valueOf(linetokens[15]).doubleValue();
-//          atoms[nHAtoms].z = Double.valueOf(linetokens[16]).doubleValue();
-//          atoms[nHAtoms].methyl = false;
-//          nHAtoms++;
-//        }
-//      }
-//    } catch (Exception e) {
-//      System.out.println(e.toString());
-//    } finally {
-//      if (br != null)
-//        try {
-//          br.close();
-//        } catch (IOException e) {
-//        }
-//    }
-//
-//  }
-//
-//  public static void main(String args[]) {
-//    NOEParams params = new NOEParams();
-//    params.setNMRfreqMHz(500);
-//    params.setCorrelationTimeTauPS(80.0);
-//    params.setMixingTimeSec(0.5);
-//    params.setCutoffAng(10.0);
-//    params.setRhoStar(0.1);
-//    params.setNoesy(true);
-//    new NMRNoeMatrix(params).doItAll(new File(args[0]));
-//  }
-//
+  private void doItAll(File file) {
+
+    System.out.println("starting");
+    readAtomsFromFile(file);
+    relaxMatrix = new double[nHAtoms][nHAtoms];
+    eigenValues = new double[nHAtoms][nHAtoms];
+    eigenVectors = new double[nHAtoms][nHAtoms];
+    noeM = new double[nHAtoms][nHAtoms];
+    System.out.println("read atoms: " + Integer.toString(nHAtoms));
+    calcRelaxMatrix();
+    System.out.println("built matrix");
+    System.out.println("total iterations = " + Integer.toString(Diagonalise()));
+    System.out.println("diagonalised matrix");
+    calcNoeMatrix();
+    System.out.println("calculated NOE matrix");
+    System.out.println(toString());
+    System.out.println("");
+    System.out.println(toStringNormRow());
+    try {
+      calcNOEs();
+    } catch (Exception e) {
+      System.out.println(e.toString());
+    }
+    //    System.out.println(params.getNMRfreqMHz());
+    //    System.out.println(params.getCorrelationTimeTauPS());
+  }
+
+  private void readAtomsFromFile(File file) {
+    atoms = new NOEAtom[200];
+    nHAtoms = 0;
+    BufferedReader br = null;
+    try {
+      br = new BufferedReader(new FileReader(file));
+      br.readLine();
+      System.out.println("found file");
+      while (true) {
+        //br.readLine();
+        String[] linetokens = br.readLine().split("\\s+");
+        // DAE changed to match particular H atom types in mm files with no atom names
+        if (linetokens[1].matches("41") || linetokens[1].matches("44")) {
+          atoms[nHAtoms] = new NOEAtom();
+          atoms[nHAtoms].x = Double.valueOf(linetokens[14]).doubleValue();
+          atoms[nHAtoms].y = Double.valueOf(linetokens[15]).doubleValue();
+          atoms[nHAtoms].z = Double.valueOf(linetokens[16]).doubleValue();
+          atoms[nHAtoms].methyl = false;
+          nHAtoms++;
+        }
+      }
+    } catch (Exception e) {
+      System.out.println(e.toString());
+    } finally {
+      if (br != null)
+        try {
+          br.close();
+        } catch (IOException e) {
+        }
+    }
+
+  }
+
+  public static void main(String args[]) {
+    NOEParams params = new NOEParams();
+    params.setNMRfreqMHz(500);
+    params.setCorrelationTimeTauPS(80.0);
+    params.setMixingTimeSec(0.5);
+    params.setCutoffAng(10.0);
+    params.setRhoStar(0.1);
+    params.setNoesy(true);
+    new NMRNoeMatrix(params).doItAll(new File(args[0]));
+  }
+
   static class NOEAtom {
 
     double x, y, z, x1, y1, z1, x2, y2, z2;
