@@ -61,6 +61,7 @@ public abstract class MeshRenderer extends ShapeRenderer {
   protected float width;
   
 
+  protected boolean allowDashed;
   protected boolean isTranslucent;
   protected boolean frontOnly;
   protected boolean isShell;
@@ -538,7 +539,8 @@ public abstract class MeshRenderer extends ShapeRenderer {
     } else {
       pt1f.ave(vA, vB);
       tm.transformPtScr(pt1f, pt1i);
-      if (width < 0) {
+      if (width < 0 && allowDashed) {
+        // not draw cylinder
         diameter = -1;
       } else {
         int mad = (int) Math.floor(Math.abs(width) * 1000);
