@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-02-20 17:14:32 -0600 (Sun, 20 Feb 2022) $
- * $Revision: 22343 $
+ * $Date: 2023-01-05 08:42:06 -0600 (Thu, 05 Jan 2023) $
+ * $Revision: 22500 $
 
  *
  * Copyright (C) 2002-2005  The Jmol Development Team
@@ -146,7 +146,7 @@ public class SticksRenderer extends FontLineShapeRenderer {
     a = atomA0 = bond.atom1;
     b = atomB0 = bond.atom2;
 
-    int order = bond.order & ~Edge.BOND_NEW;
+    int order = bond.order & Edge.BOND_RENDER_MASK;
     if (bondsBackbone) {
       if (ssbondsBackbone && (order & Edge.BOND_SULFUR_MASK) != 0) {
         // for ssbonds, always render the sidechain,
@@ -210,7 +210,7 @@ public class SticksRenderer extends FontLineShapeRenderer {
 
     // set the rendered bond order
 
-    bondOrder = order & ~Edge.BOND_NEW;
+    bondOrder = order & Edge.BOND_RENDER_MASK;
     if ((bondOrder & Edge.BOND_PARTIAL_MASK) == 0) {
       if ((bondOrder & Edge.BOND_SULFUR_MASK) != 0)
         bondOrder &= ~Edge.BOND_SULFUR_MASK;
@@ -229,6 +229,7 @@ public class SticksRenderer extends FontLineShapeRenderer {
     switch (bondOrder) {
     case Edge.BOND_STEREO_NEAR:
     case Edge.BOND_STEREO_FAR:
+    case Edge.BOND_STEREO_EITHER:
       bondOrder = 1;
       //$FALL-THROUGH$
     case 1:
