@@ -276,8 +276,6 @@ public class ScriptMathProcessor {
   }
 
   public boolean addXFloat(float x) {
-    if (Float.isNaN(x))
-      return addXStr("NaN");
     putX(SV.newF(x));
     return wasX = true;
   }
@@ -466,6 +464,7 @@ public class ScriptMathProcessor {
       if (!wasX)
         op = SV.newV(T.unaryMinus, "-");
       break;
+    case T.pivot:
     case T.min:
     case T.max:
     case T.average:
@@ -1005,6 +1004,10 @@ public class ScriptMathProcessor {
         String[] keys = x2.getKeys((op.intValue & T.minmaxmask) == T.minmaxmask);
         return (keys == null ? addXStr("") : addXAS(keys));
       case T.length:
+        if (x2.tok == T.point3f) {
+          return addXFloat(((T3) x2.value).distance(SV.pt0));
+        }
+        //$FALL-THROUGH$
       case T.count:
       case T.size:
         if (iv == T.length && x2.value instanceof BondSet)
@@ -1139,11 +1142,11 @@ public class ScriptMathProcessor {
     case T.opLE:
       return addXBool(x1.tok == T.integer && x2.tok == T.integer
           ? x1.intValue <= x2.intValue
-          : x1.asFloat() <= x2.asFloat());
+          : x1.isNaN() && x2.isNaN() || x1.asFloat() <= x2.asFloat());
     case T.opGE:
       return addXBool(x1.tok == T.integer && x2.tok == T.integer
           ? x1.intValue >= x2.intValue
-          : x1.asFloat() >= x2.asFloat());
+          : x1.isNaN() && x2.isNaN() || x1.asFloat() >= x2.asFloat());
     case T.opGT:
       return addXBool(
           x1.tok == T.integer && x2.tok == T.integer ? x1.intValue > x2.intValue
@@ -1287,8 +1290,8 @@ public class ScriptMathProcessor {
       }
       pt = (x1.tok == T.matrix3f || x1.tok == T.matrix4f ? ptValue(x2, null)
           : x2.tok == T.matrix3f ? ptValue(x1, null) : null);
-      pt4 = (x1.tok == T.matrix4f ? planeValue(x2)
-          : x2.tok == T.matrix4f ? planeValue(x1) : null);
+      pt4 = (x1.tok == T.matrix4f ? eval.planeValue(x2)
+          : x2.tok == T.matrix4f ? eval.planeValue(x1) : null);
       // checking here to make sure arrays remain arrays and
       // points remain points with matrix operations.
       // we check x2, because x1 could be many things.
@@ -1385,11 +1388,11 @@ public class ScriptMathProcessor {
           for (int i = l.size(); --i >= 0;) {
             P3 pt1 = P3.newP(SV.ptValue(l.get(i)));
             m4.rotTrans(pt1);
-            lnew.add(pt1);
+            lnew.addLast(pt1);
           }
           return addXList(lnew);
         }
-        return addXStr("NaN");
+        return addXFloat(Float.NaN);
       case T.point3f:
         pt = P3.newP((P3) x1.value);
         switch (x2.tok) {
@@ -1465,6 +1468,7 @@ public class ScriptMathProcessor {
       // Point3f * Point3f does dot product
       // Point3f / Point3f divides by magnitude
       // float * Point3f gets magnitude
+      // Point3f % n.0 offsets n,n,n ???
       // Point4f % n returns q0, q1, q2, q3, or theta
       // Point4f % Point4f
       s = null;
@@ -1502,6 +1506,7 @@ public class ScriptMathProcessor {
         return addXAS(list);
       case T.point3f:
         pt = P3.newP((P3) x1.value);
+        // BH why such an esoteric offset? unfortunately, is documented
         vwr.toUnitCell(pt, P3.new3(n, n, n));
         return addXPt(pt);
       case T.point4f:
@@ -1612,8 +1617,11 @@ public class ScriptMathProcessor {
         bs = BSUtil.copy(bs);
         bs.and(bsRestrict);
       }
-      return (P3) eval.getBitsetProperty(bs, null, T.xyz, null,
-          null, x.value, null, false, Integer.MAX_VALUE, false);
+      Object o = (bs.cardinality() == 0 ? null : eval.getBitsetProperty(bs, null, T.xyz, null,
+          null, x.value, null, false, Integer.MAX_VALUE, false));
+//      if (o != null && !(o instanceof P3))
+//        System.out.println("ScriptMathProc OHOH");
+      return (P3) o;
     case T.string:
       pt = Escape.uP(SV.sValue(x));
       if (pt instanceof P3)
@@ -1628,48 +1636,6 @@ public class ScriptMathProcessor {
     return null;
   }
 
-  public static P4 planeValue(T x) {
-    Object pt;
-    switch (x.tok) {
-    case T.point4f:
-      return (P4) x.value;
-    case T.varray:
-      break;
-    case T.string:
-      String s = (String) x.value;
-      boolean isMinus = s.startsWith("-");
-      float f = (isMinus ? -1 : 1);
-      if (isMinus)
-        s = s.substring(1);
-      P4 p4 = null;
-      switch (s.length() < 2 ? -1
-          : "xy yz xz x= y= z=".indexOf(s.substring(0, 2))) {
-      case 0:
-        return P4.new4(1, 1, 0, f);
-      case 3:
-        return P4.new4(0, 1, 1, f);
-      case 6:
-        return P4.new4(1, 0, 1, f);
-      case 9:
-        p4 = P4.new4(1, 0, 0, -f * PT.parseFloat(s.substring(2)));
-        break;
-      case 12:
-        p4 = P4.new4(0, 1, 0, -f * PT.parseFloat(s.substring(2)));
-        break;
-      case 15:
-        p4 = P4.new4(0, 0, 1, -f * PT.parseFloat(s.substring(2)));
-        break;
-      }
-      if (p4 != null && !Float.isNaN(p4.w))
-        return p4;
-      break;
-    default:
-      return null;
-    }
-    pt = Escape.uP(SV.sValue(x));
-    return (pt instanceof P4 ? (P4) pt : null);
-  }
-
   static private String typeOf(SV x) {
     int tok = (x == null ? T.nada : x.tok);
     switch (tok) {
@@ -1749,7 +1715,7 @@ public class ScriptMathProcessor {
       case T.sum:
       case T.sum2:
       case T.pivot:
-        return addXObj(eval.getMathExt().getMinMax(x2.getList(), op.intValue));
+        return addXObj(eval.getMathExt().getMinMax(x2.getList(), op.intValue, true));
       case T.pop:
         return addX(x2.pushPop(null, null));
       case T.sort:
