@@ -9,7 +9,6 @@ import org.jmol.util.BSUtil;
 import org.jmol.util.Edge;
 import org.jmol.util.Escape;
 import org.jmol.util.Logger;
-import org.jmol.util.SimpleUnitCell;
 
 import javajs.util.BS;
 import javajs.util.CU;
@@ -301,6 +300,7 @@ abstract public class ScriptParam extends ScriptError {
     boolean isNegated = (tokAt(i) == T.minus);
     if (isNegated)
       i++;
+    try {
     if (i < slen) {
       switch (getToken(i).tok) {
       case T.dollarsign:
@@ -397,6 +397,9 @@ abstract public class ScriptParam extends ScriptError {
       if (!chk && Logger.debugging)
         Logger.debug(" defined plane: " + plane);
     }
+    } catch (Exception e) {
+      plane = null;
+    }
     if (plane == null)
       errorMore(ERROR_planeExpected, "{a b c d}",
           "\"xy\" \"xz\" \"yz\" \"x=...\" \"y=...\" \"z=...\" \"ab\" \"bc\" \"ac\" \"ab1\" \"bc1\" \"ac1\"", "$xxxxx");
@@ -1073,7 +1076,7 @@ abstract public class ScriptParam extends ScriptError {
       // model/frame number encoded
       break;
     case T.string:
-      iFrame = getFloatEncodedInt(stringParameter(index));
+      iFrame = Edge.getFloatEncodedInt(stringParameter(index));
       break;
     default:
       invArg();
@@ -1151,63 +1154,6 @@ abstract public class ScriptParam extends ScriptError {
     return null;
   }
 
-  /**
-   * Encodes a string such as "2.10" as an integer instead of a float so as to
-   * distinguish "2.1" from "2.10" used for model numbers and partial bond
-   * orders. 2147483647 is maxvalue, so this allows loading simultaneously up to
-   * 2147 files, each with 999999 models (or trajectories)
-   * 
-   * @param strDecimal
-   * @return float encoded as an integer
-   */
-  static int getFloatEncodedInt(String strDecimal) {
-    int pt = strDecimal.indexOf(".");
-    if (pt < 1 || strDecimal.charAt(0) == '-' || strDecimal.endsWith(".")
-        || strDecimal.contains(".0"))
-      return Integer.MAX_VALUE;
-    int i = 0;
-    int j = 0;
-    if (pt > 0) {
-      try {
-        i = Integer.parseInt(strDecimal.substring(0, pt));
-        if (i < 0)
-          i = -i;
-      } catch (NumberFormatException e) {
-        i = -1;
-      }
-    }
-    if (pt < strDecimal.length() - 1)
-      try {
-        j = Integer.parseInt(strDecimal.substring(pt + 1));
-      } catch (NumberFormatException e) {
-        // not a problem
-      }
-    i = i * 1000000 + j;
-    return (i < 0 || i > Integer.MAX_VALUE ? Integer.MAX_VALUE : i);
-  }
-
-  /**
-   * reads standard n.m float-as-integer n*1000000 + m and returns (n % 7) << 5
-   * + (m % 0x1F)
-   * 
-   * @param bondOrderInteger
-   * @return Bond order partial mask
-   */
-  public static int getPartialBondOrderFromFloatEncodedInt(int bondOrderInteger) {
-    return (((bondOrderInteger / 1000000) % 7) << 5)
-        + ((bondOrderInteger % 1000000) & 0x1F);
-  }
-
-  public static int getBondOrderFromString(String s) {
-    return (s.indexOf(' ') < 0 ? Edge.getBondOrderFromString(s)
-        : s.toLowerCase().indexOf("partial ") == 0 ? getPartialBondOrderFromString(s
-            .substring(8).trim()) : Edge.BOND_ORDER_NULL);
-  }
-
-  private static int getPartialBondOrderFromString(String s) {
-    return getPartialBondOrderFromFloatEncodedInt(getFloatEncodedInt(s));
-  }
-
   public boolean isColorParam(int i) {
     int tok = tokAt(i);
     return tok != T.nada && (tok == T.navy || tok == T.spacebeforesquare || tok == T.leftsquare
@@ -1431,6 +1377,9 @@ abstract public class ScriptParam extends ScriptError {
 
   public P4 planeValue(T x) {
     Object pt;
+    SymmetryInterface sym = null;
+    float offset = Float.NaN;
+    P3 vc = null;
     switch (x.tok) {
     case T.point4f:
       return (P4) x.value;
@@ -1444,41 +1393,79 @@ abstract public class ScriptParam extends ScriptError {
       if (isMinus)
         s = s.substring(1);
       P4 p4 = null;
-      boolean is1 = (s.length() > 2 && s.charAt(2) == '1');
-      int mode = (s.length() < 2 ? -1
-          : "xy yz xz x= y= z= ab bc ac".indexOf(s.substring(0, 2)));
-      if (mode >= 18 && vwr.getCurrentUnitCell() == null) {
+      int len = s.length();
+      // also allows ab1, ac1, and bc1, basically c=1, b=1, and a=1
+      int mode = (len < 2 ? -1
+          : "xy yz xz x= y= z= ab bc ac a= b= c=".indexOf(s.substring(0, 2).toLowerCase()));
+      if (mode >= 18 && (sym = vwr.getCurrentUnitCell()) == null) {
         mode -= 18; // to xy yz xz if no unit cell       
       }
+      boolean isab = (s.indexOf("=") < 0);
+      if (len > 2) {
+        if (!isab)
+          offset = -f * PT.parseFloat(s.substring(2));
+        else if (Float.isNaN(offset) && mode >= 18 && s.charAt(2) == '1')
+          offset = -1;
+      }
+      // -xy, -yz, -x=2, etc. are reverse of the following:
       switch (mode) {
       case 0:
+          // xy; z > 0 removed
         return P4.new4(1, 1, 0, f);
       case 3:
+          // yz; x > 0 removed
         return P4.new4(0, 1, 1, f);
       case 6:
+          // xz; y > 0 removed
         return P4.new4(1, 0, 1, f);
-      case 9:
+      case 9: // x > value removed
+          // note that -x=1 is not the same as x=-1
         p4 = P4.new4(1, 0, 0, -f * PT.parseFloat(s.substring(2)));
         break;
-      case 12:
+      case 12: // y > value removed
         p4 = P4.new4(0, 1, 0, -f * PT.parseFloat(s.substring(2)));
         break;
-      case 15:
+      case 15: // z > value removed
         p4 = P4.new4(0, 0, 1, -f * PT.parseFloat(s.substring(2)));
         break;
-      case 18: // ab
-        p4 = getHklPlane(P3.new3(0, 0, 1), is1 ? vwr.getUnitCellInfo(SimpleUnitCell.INFO_C) : 0, null);
-        break;
-      case 21: // bc
-        p4 = getHklPlane(P3.new3(1, 0, 0), is1 ? -vwr.getUnitCellInfo(SimpleUnitCell.INFO_A) : 0, null);
-        break;
-      case 24: // ac
-        p4 = getHklPlane(P3.new3(0, 1, 0), is1 ? vwr.getUnitCellInfo(SimpleUnitCell.INFO_B) : 0, null);
-        break;
-      }
-      if (p4 != null && !Float.isNaN(p4.w))
-        return p4;
-      break;
+      case 18: // ab, outside unitcell removed
+          if (Float.isNaN(offset))
+            offset = 0;
+          //$FALL-THROUGH$
+        case 33: // c>value removed
+          p4 = getHklPlane(vc = P3.new3(0, 0, 1), 0, null);
+          p4.scale4(f = -f);
+          break;
+        case 21: // bc, outside unitcell removed
+          if (Float.isNaN(offset))
+            offset = 0;
+          //$FALL-THROUGH$
+        case 27: // a>value removed
+          p4 = getHklPlane(vc = P3.new3(1, 0, 0), 0, null);
+          p4.scale4(-(f = -f));
+          break;
+        case 24: // ac, outside unitcell removed
+          if (Float.isNaN(offset))
+            offset = 0;
+          //$FALL-THROUGH$
+        case 30: // b>value removed
+          p4 = getHklPlane(vc = P3.new3(0, 1, 0), 0, null);
+          p4.scale4(-f);
+          break;
+        }
+        if (p4 == null || Float.isNaN(p4.w)) 
+          break;
+        if (sym != null && !Float.isNaN(offset)) {
+          // slab external of a=1, b=1, or c=1
+          sym.toCartesian(vc, true);
+          if (isab || !isMinus) {
+            offset = -offset;
+          }
+          p4.w = vc.dot(p4) * offset;
+          if (!isab || offset != 0)
+            p4.scale(-1);
+        }
+          return p4;
     default:
       return null;
     }
