@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-03-10 17:02:09 -0600 (Thu, 10 Mar 2022) $
- * $Revision: 22364 $
+ * $Date: 2023-01-07 08:24:29 -0600 (Sat, 07 Jan 2023) $
+ * $Revision: 22501 $
  *
  * Copyright (C) 2002-2005  The Jmol Development Team
  *
@@ -93,7 +93,7 @@ public class Measures extends AtomShape implements JmolMeasurementClient {
   }
 
   @Override
-  public void setProperty(String propertyName, Object value, BS bsIgnored) {
+  public void setProperty(String propertyName, Object value, BS bsAtoms) {
     // the following can be used with "select measures ({bitset})"
 
     Measurement mt;
@@ -123,9 +123,8 @@ public class Measures extends AtomShape implements JmolMeasurementClient {
       if (mPending == null)
         return;
       if (mPending.count > 1)
-        vwr.setStatusMeasuring("measurePending", mPending
-            .count, getMessage(mPending, false),
-            mPending.value);
+        vwr.setStatusMeasuring("measurePending", mPending.count,
+            getMessage(mPending, false), mPending.value);
       return;
     }
 
@@ -209,17 +208,7 @@ public class Measures extends AtomShape implements JmolMeasurementClient {
         return;
       }
       Measurement m = setSingleItem(md.points);
-      if (md.thisID != null) {
-        m.thisID = md.thisID;
-        m.mad = md.mad;
-        if (md.colix != 0)
-          m.colix = md.colix;
-        m.strFormat = md.strFormat;
-        m.text = md.text;
-      }
-      m.units = md.units;
-      m.property = md.property;
-      m.fixedValue = md.fixedValue;
+      m.setFromMD(md, false);
       switch (md.tokAction) {
       case T.refresh:
         doAction(md, md.thisID, T.refresh);
@@ -257,6 +246,24 @@ public class Measures extends AtomShape implements JmolMeasurementClient {
       return;
     }
 
+    if ("deleteAtoms" == propertyName) {
+      for (int i = measurementCount; --i >= 0;) {
+        out: for (int iatom = bsAtoms.nextSetBit(0); iatom >= 0; iatom = bsAtoms
+            .nextSetBit(iatom + 1)) {
+          mt = measurements.get(i);
+          int[] indices = mt.countPlusIndices;
+          for (int j = 1; j <= indices[0]; j++) {
+            if (indices[j] == iatom) {
+              deleteI(i);
+              break out;
+            }
+          }
+
+        }
+      }
+      return;
+    }
+
     if ("deleteModelAtoms" == propertyName) {
       //atoms = (Atom[]) ((Object[]) value)[1];
       int modelIndex = ((int[]) ((Object[]) value)[2])[0];
@@ -297,8 +304,8 @@ public class Measures extends AtomShape implements JmolMeasurementClient {
       if (value instanceof String) {
         doAction(null, (String) value, T.hide);
       } else {
-        showHideM(new Measurement().setPoints(ms, (int[]) value, null,
-            null), true);
+        showHideM(new Measurement().setPoints(ms, (int[]) value, null, null),
+            true);
       }
       return;
     }
@@ -311,8 +318,8 @@ public class Measures extends AtomShape implements JmolMeasurementClient {
       if (value instanceof String) {
         doAction(null, (String) value, T.show);
       } else {
-        showHideM(new Measurement().setPoints(ms, (int[]) value, null,
-            null), false);
+        showHideM(new Measurement().setPoints(ms, (int[]) value, null, null),
+            false);
       }
       return;
     }
@@ -591,28 +598,7 @@ public class Measures extends AtomShape implements JmolMeasurementClient {
           || isWild && PT.isMatch(m.thisID.toUpperCase(), id, true, true)))
         switch (tok) {
         case T.refresh:
-          if (md.colix != 0)
-            m.colix = md.colix;
-          if (md.mad != 0)
-            m.mad = md.mad;
-          if (md.strFormat != null) {
-            m.strFormat = m.strFormat.substring(0, 2)
-                + md.strFormat.substring(2);
-          }
-          if (md.text != null) {
-            if (m.text == null) {
-              m.text = md.text;
-            } else {
-              if (md.text.font != null)
-                m.text.font = md.text.font;
-              m.text.text = null;
-              if (md.text.align != 0)
-                m.text.align = md.text.align;
-              if (md.colix != 0)
-                m.labelColix = m.text.colix = md.text.colix;
-            }
-          }
-          m.formatMeasurement(null);
+          m.setFromMD(md, true);
           break;
         case T.radius:
           m.mad = md.mad;
