@@ -635,7 +635,7 @@ public class Polyhedra extends AtomShape implements Comparator<Object[]>{
     Atom[] atoms = ms.at;
     for (int i = bsAtoms.nextSetBit(0); i >= 0; i = bsAtoms.nextSetBit(i + 1)) {
       for (int f = faces.length; --f >= 0;) {
-        System.out.println(Measure.distanceToPlane(p.planes[f], atoms[i]));
+        //System.out.println(Measure.distanceToPlane(p.planes[f], atoms[i]));
         if (Measure.distanceToPlane(p.planes[f], atoms[i]) > offset + 0.001f) {
           bsAtoms.clear(i);
           break;
