@@ -396,7 +396,7 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
       if (!sg.setProp("lcaoCartoonCenter", info[2], null))
         drawLcaoCartoon(info[0], info[1], info[3],
             ("lonePair" == propertyName ? 2
-                : "radical" == propertyName ? 1 : 0));
+                : "radical" == propertyName ? 1 : 0), thisMesh == null ? false : thisMesh.reverseColor);
       return;
     }
 
@@ -410,6 +410,12 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
         return;
     }
 
+    if ("reversecolor" == propertyName) {
+      if (thisMesh != null)
+        thisMesh.reverseColor = (value == Boolean.TRUE);
+      return;
+    }
+
     if ("meshcolor" == propertyName) {
       int rgb = ((Integer) value).intValue();
       meshColix = C.getColix(rgb);
@@ -478,11 +484,6 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
       return;
     }
 
-    if ("cutoffRange" == propertyName) {
-      cutoffRange = (float[]) value;
-      return;
-    }
-
     if ("fixLattice" == propertyName) {
       if (thisMesh != null)
         thisMesh.fixLattice();
@@ -661,6 +662,8 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
     } else if (("nci" == propertyName || "orbital" == propertyName)
         && sg != null) {
       sg.params.testFlags = (vwr.getBoolean(T.testflag2) ? 2 : 0);
+    } else if ("cutoffRange" == propertyName) {
+      cutoffRange = (float[]) value;
     }
 
     // surface Export3D only (return TRUE) or shared (return FALSE)
@@ -923,8 +926,12 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
         return "invalid! (no atoms selected?)";
       if (!Float.isNaN(jvxlData.integration))
         s += "integration " + jvxlData.integration;
-      if (shapeID == JC.SHAPE_ISOSURFACE || shapeID == JC.SHAPE_MO  || shapeID == JC.SHAPE_NBO)
-        s += " with cutoff=" + jvxlData.cutoff;
+      if (shapeID == JC.SHAPE_ISOSURFACE || shapeID == JC.SHAPE_MO  || shapeID == JC.SHAPE_NBO) {
+        if (jvxlData.cutoffRange == null)
+          s += " with cutoff=" + jvxlData.cutoff;
+        else
+          s += " with cutoffRange=" + Escape.eAF(jvxlData.cutoffRange);
+      }
       if (shapeID == JC.SHAPE_MO || shapeID == JC.SHAPE_NBO)
         return s;
       if (jvxlData.dataMin != Float.MAX_VALUE)
@@ -968,6 +975,8 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
     }
     if (property == "cutoff")
       return Float.valueOf(jvxlData.cutoff);
+    if (property == "cutoffRange")
+        return jvxlData.cutoffRange;
     if (property == "minMaxInfo")
       return new float[] { jvxlData.dataMin, jvxlData.dataMax };
     if (property == "plane")
@@ -1333,17 +1342,29 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
 
   private int nLCAO = 0;
 
-  private void drawLcaoCartoon(V3 z, V3 x, V3 rotAxis, int nElectrons) {
+  private void drawLcaoCartoon(V3 z, V3 x, V3 rotAxis, int nElectrons, boolean reverseColor) {
     String lcaoCartoon = sg.setLcao();
+    boolean addAnti = (lcaoCartoon.indexOf("anti-sp") >= 0);
+    if (addAnti) {
+      // anti-sp3a becomes sp3a, with small added back lobe
+      // -anti-sp3a becomes -sp3a with small added back lobe
+      lcaoCartoon = lcaoCartoon.substring(5);
+    }
+
     //really rotRadians is just one of these -- x, y, or z -- not all
     float rotRadians = rotAxis.x + rotAxis.y + rotAxis.z;
     defaultColix = C.getColix(sg.params.colorPos);
     short colixNeg = C.getColix(sg.params.colorNeg);
+    if (reverseColor) {
+        short c = colixNeg;
+        colixNeg = defaultColix;
+        defaultColix = c;
+    }
     V3 y = new V3();
     boolean isReverse = (lcaoCartoon.length() > 0 && lcaoCartoon.charAt(0) == '-');
     if (isReverse)
       lcaoCartoon = lcaoCartoon.substring(1);
-    int sense = (isReverse ? -1 : 1);
+    float sense = (isReverse ? -1 : 1);
     y.cross(z, x);
     if (rotRadians != 0) {
       A4 a = new A4();
@@ -1371,7 +1392,7 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
       if (nElectrons > 0) 
         return;
       setProperty("thisID", id + "b", null);
-      createLcaoLobe(x, -sense, nElectrons);
+      createLcaoLobe(x, -sense, 0);
       thisMesh.colix = colixNeg;
       linkedMesh = thisMesh.linkedMesh = meshA;
       return;
@@ -1383,19 +1404,19 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
       if (nElectrons > 0) 
         return;
       setProperty("thisID", id + "b", null);
-      createLcaoLobe(y, -sense, nElectrons);
+      createLcaoLobe(y, -sense, 0);
       thisMesh.colix = colixNeg;
       linkedMesh = thisMesh.linkedMesh = meshA;
       return;
     }
+    Mesh meshA = thisMesh;
     if (lcaoCartoon.equals("pz")) {
-      thisMesh.thisID += "a";
-      Mesh meshA = thisMesh;
+      meshA.thisID += "a";
       createLcaoLobe(z, sense, nElectrons);
       if (nElectrons > 0) 
         return;
       setProperty("thisID", id + "b", null);
-      createLcaoLobe(z, -sense, nElectrons);
+      createLcaoLobe(z, -sense, 0);
       thisMesh.colix = colixNeg;
       linkedMesh = thisMesh.linkedMesh = meshA;
       return;
@@ -1405,6 +1426,13 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
         || lcaoCartoon.indexOf("d") == 0 
         || lcaoCartoon.indexOf("lp") == 0) {
       createLcaoLobe(z, sense, nElectrons);
+      if (addAnti && nElectrons == 0) {
+        meshA.thisID += "a";
+        setProperty("thisID", id + "b", null);
+        createLcaoLobe(z, -sense/2, 0);
+        thisMesh.colix = colixNeg;
+        linkedMesh = thisMesh.linkedMesh = meshA;
+      }
       return;
     }
     if (lcaoCartoon.equals("pzb")) {
@@ -1777,11 +1805,6 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
     String s = findValue(x, y, false, bsVisible);
     if (s == null)
       return false;
-    if (vwr.gdata.antialiasEnabled) {
-      //because hover rendering is done in FIRST pass only
-      x <<= 1;
-      y <<= 1;
-    }      
     vwr.hoverOnPt(x, y, s, pickedMesh.thisID, pickedPt);
     return true;
   }
@@ -1812,10 +1835,6 @@ public class Isosurface extends MeshCollection implements MeshDataServer {
         f = thisMesh.colorEncoder.quantize(f, false);
         s = "" + g + " - " + f;
       }
-      if (vwr.gdata.isAntialiased()) {
-        x <<= 1;
-        y <<= 1;
-      }
       vwr.hoverOnPt(x, y, s, null, null);
     } catch (Exception e) {
       // never mind!
