@@ -64,6 +64,7 @@ public class LcaoCartoon extends Isosurface {
   private float lcaoTranslucentLevel;
   private Integer lcaoColorPos;
   private Integer lcaoColorNeg;
+  private boolean lcaoReverseColor;
   boolean isLonePair;
   boolean isRadical;
   private Object cappingObject;
@@ -288,6 +289,7 @@ public class LcaoCartoon extends Isosurface {
       setPropI("colorRGB", lcaoColorNeg, null);
       setPropI("colorRGB", lcaoColorPos, null);
     }
+    setPropI("reversecolor", Boolean.valueOf(lcaoReverseColor), null);
     if (slabbingObject != null)
       setPropI("slab", slabbingObject, null);
     if (cappingObject != null)
@@ -312,9 +314,14 @@ public class LcaoCartoon extends Isosurface {
       if (thisType.indexOf("-") == 0)
         axes[0].scale(-1);
     }
+    String type = thisType;
+    boolean isAnti = (type.indexOf("anti-sp") >= 0);
+    if (isAnti) {
+      type = type.substring(5);
+    }
     if (isMolecular || isCpk
         || thisType.equalsIgnoreCase("s")
-        || vwr.getHybridizationAndAxes(iAtom, axes[0], axes[1], thisType) != null) {
+        || vwr.getHybridizationAndAxes(iAtom, axes[0], axes[1], type) != null) {
       setPropI((isRadical ? "radical" : isLonePair ? "lonePair" : "lcaoCartoon"), axes, null);
     }
     if (isCpk) {
@@ -343,6 +350,8 @@ public class LcaoCartoon extends Isosurface {
     SB sb = new SB();
     if (lcaoScale != null)
       appendCmd(sb, "lcaoCartoon scale " + lcaoScale.floatValue());
+    if (lcaoReverseColor)
+        appendCmd(sb, "lcaoCartoon reverse");
     if (lcaoColorNeg != null)
       appendCmd(sb, "lcaoCartoon color "
           + Escape.escapeColor(lcaoColorNeg.intValue()) + " "
@@ -362,6 +371,7 @@ public class LcaoCartoon extends Isosurface {
     lcaoColorNeg = lc.lcaoColorNeg;
     lcaoTranslucent = lc.lcaoTranslucent;
     lcaoTranslucentLevel = lc.lcaoTranslucentLevel;
+    lcaoReverseColor = lc.lcaoReverseColor;
     super.merge(shape);
   }
   
