@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-03-11 11:09:21 -0600 (Fri, 11 Mar 2022) $
- * $Revision: 22365 $
+ * $Date: 2023-01-05 08:42:06 -0600 (Thu, 05 Jan 2023) $
+ * $Revision: 22500 $
  *
  * Copyright (C) 2005  The Jmol Development Team
  *
@@ -266,7 +266,7 @@ public class SmilesBond extends Edge {
 
   @Override
   public int getCovalentOrder() {
-    return order & ~BOND_NEW;
+    return order & BOND_RENDER_MASK;
   }
 
   @Override
@@ -279,6 +279,11 @@ public class SmilesBond extends Edge {
     return order != TYPE_BIO_CROSSLINK;
   }
 
+  @Override
+  public boolean isPartial() {
+    return false;
+  }
+
   @Override
   public boolean isHydrogen() {
     return order == TYPE_BIO_CROSSLINK;
@@ -294,7 +299,7 @@ public class SmilesBond extends Edge {
     SmilesAtom a = atom1;
     atom1 = atom2;
     atom2 = a;
-    switch (order & ~BOND_NEW) {
+    switch (order & BOND_RENDER_MASK) {
     case TYPE_ATROPISOMER:
       order = TYPE_ATROPISOMER_REV;
       break;
@@ -311,14 +316,14 @@ public class SmilesBond extends Edge {
   }
 
   public int getRealCovalentOrder() {
-    switch (order & ~BOND_NEW) {
+    switch (order & BOND_RENDER_MASK) {
     case TYPE_ATROPISOMER:
     case TYPE_ATROPISOMER_REV:
     case BOND_STEREO_NEAR:
     case BOND_STEREO_FAR:
       return BOND_COVALENT_SINGLE;
     }
-    return order & ~BOND_NEW;
+    return order & BOND_RENDER_MASK;
   }
 
   public Edge getMatchingBond() {
