@@ -28,13 +28,6 @@ import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.Map;
 
-import javajs.util.AU;
-import javajs.util.Lst;
-import javajs.util.P3;
-import javajs.util.SB;
-
-import javajs.util.BS;
-
 import org.jmol.util.BSUtil;
 import org.jmol.util.Edge;
 import org.jmol.util.Elements;
@@ -45,6 +38,13 @@ import org.jmol.util.SimpleEdge;
 import org.jmol.util.SimpleNode;
 import org.jmol.viewer.JC;
 
+import javajs.util.AU;
+import javajs.util.BS;
+import javajs.util.Lst;
+import javajs.util.P3;
+import javajs.util.SB;
+import javajs.util.T3;
+
 /**
  * Double bond, allene, square planar and tetrahedral stereochemistry only
  * not octahedral or trigonal bipyramidal.
@@ -1234,10 +1234,10 @@ public class SmilesGenerator {
         if (atom == b.getAtom(0)) {
           switch (b.getBondType()) {
           case Edge.BOND_STEREO_NEAR:
-            setStereoTemp(stereo, c = b.getAtom(1), dir);
+            c = setStereoTemp(null, stereo, b.getAtom(1), dir);
             break;
           case Edge.BOND_STEREO_FAR:
-            setStereoTemp(stereo, c = b.getAtom(1), -dir);
+            c = setStereoTemp(null, stereo, b.getAtom(1), -dir);
             break;
           }
         }
@@ -1245,22 +1245,45 @@ public class SmilesGenerator {
       if (c == null)
         return "";
       if (stereoFlag == 3) {
-        stereo[stereoFlag++] = c;
+        stereo[stereoFlag++] = setStereoTemp(atom, stereo, c, 0);
       }
     }
     return SmilesStereo.getStereoFlag(atom, stereo, stereoFlag, vTemp, is2D);
   }
 
-  private void setStereoTemp(SimpleNode[] stereo, SimpleNode a, float z) {
+  /**
+   * Create a dummy atom at the position of an atom at the end of a wedge or hash.
+   * 
+   * In the case where we need a fourth atom, add this atom in a way that 
+   * roughly puts the center atom at the center of geometry of the four atoms.
+   * 
+   * @param atom
+   * @param stereo
+   * @param a
+   * @param z
+   * @return the new atom
+   */
+  private static SimpleNode setStereoTemp(SimpleNode atom, SimpleNode[] stereo,
+                                          SimpleNode a, float z) {
+    SmilesAtom b = new SmilesAtom();
     for (int i = 0; i < 4; i++) {
-      if (stereo[i] == a) {
-        SmilesAtom b = new SmilesAtom();
-        P3 c = a.getXYZ();
-        b.set(c.x, c.y, z);
-        stereo[i] = b;
-        break;
+      boolean isA = (stereo[i] == a);
+      if (atom == null) {
+        if (isA) {
+          P3 c = a.getXYZ();
+          b.set(c.x, c.y, z);
+          return stereo[i] = b;
+        }
+      } else if (i < 3) {
+          b.add((T3) stereo[i]);
       }
     }
+    if (atom == null)
+      return null;
+    // A + (A-b0 + A-b1 + A-b2)/3 = 2A - (b0 + b1 + b2)/3 
+    b.scale(-1/3f);
+    b.scaleAdd2(2, (T3) atom, b);
+    return b;
   }
 
   private int chainCheck;
