@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-01-17 18:01:15 -0600 (Mon, 17 Jan 2022) $
- * $Revision: 22302 $
+ * $Date: 2022-08-07 17:43:09 -0500 (Sun, 07 Aug 2022) $
+ * $Revision: 22451 $
  *
  * Copyright (C) 2005  The Jmol Development Team
  *
@@ -489,7 +489,9 @@ public class SmilesParser {
         boolean isAtom = (!isConnect && (ch == '_' || ch == '[' || ch == '*' || PT
             .isLetter(ch)));
         if (isConnect) {
-          if (wasMeasure || wasBranch)
+          if (wasMeasure
+//            || wasBranch // relaxing this constraint as per Open Smiles Jmol 14.32.36
+             )
             throw new InvalidSmilesException(
                 "connection number must immediately follow its connecting atom");
           index = getRingNumber(pattern, index, ch, ret);
