@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2021-12-08 13:29:59 -0600 (Wed, 08 Dec 2021) $
- * $Revision: 22273 $
+ * $Date: 2022-03-13 21:21:32 -0500 (Sun, 13 Mar 2022) $
+ * $Revision: 22369 $
  *
  * Copyright (C) 2005  The Jmol Development Team
  *
@@ -161,6 +161,8 @@ public class SmilesSearch extends JmolMolecule {
 
   SmilesAtom polyAtom;
 
+  public boolean autoAddImplicitH = true;
+
   static final int addFlags(int flags, String strFlags) {
     if (strFlags.indexOf("OPEN") >= 0)
       flags |= JC.SMILES_TYPE_OPENSMILES;
@@ -292,7 +294,7 @@ public class SmilesSearch extends JmolMolecule {
       if (atom.isAromatic)
         patternAromatic = true;
       atom.setBondArray();
-      if (!isSmarts && atom.bioType == '\0' && !atom.setHydrogenCount())
+      if (autoAddImplicitH && !isSmarts && atom.bioType == '\0' && !atom.setHydrogenCount())
         throw new InvalidSmilesException("unbracketed atoms must be one of: "
             + SmilesAtom.UNBRACKETED_SET);
     }
@@ -500,11 +502,11 @@ public class SmilesSearch extends JmolMolecule {
       for (int i = bsSelected.nextSetBit(0); i >= 0; i = bsSelected
           .nextSetBit(i + 1)) {
         Node atom = targetAtoms[i];
-        Edge[] bonds = atom.getEdges();
-        if (bonds != null)
-          for (int k = bonds.length; --k >= 0;)
+        int nb = atom.getBondCount();
+          for (int k = nb; --k >= 0;) {
             if (ringCounts[atom.getBondedAtomIndex(k)] > 0)
               ringConnections[i]++;
+          }
       }
     }
   }
@@ -836,7 +838,7 @@ public class SmilesSearch extends JmolMolecule {
       if (patternAtoms[j].isBioAtomWild)
         targetAtoms[i].getGroupBits(bs);
       if (firstAtomOnly)
-        break; // TODO -- ohoh, I need this?
+        break;
       if (!isSmarts)
         if (!setAtropicity && patternAtoms[j].explicitHydrogenCount > 0) {
           Node atom = targetAtoms[i];
@@ -1499,7 +1501,7 @@ public class SmilesSearch extends JmolMolecule {
         b = sAtom1.getBond(j);
         boolean isAtom2 = (b.atom2 == sAtom1);
         indexOrder = (b.atom1.index < b.atom2.index);
-        int type = b.order;
+        int type = b.getBondType();
         switch (type) {
         case Edge.TYPE_ATROPISOMER:
         case Edge.TYPE_ATROPISOMER_REV:
@@ -1543,6 +1545,7 @@ public class SmilesSearch extends JmolMolecule {
           Logger.info("atropisomer check for atoms " + sAtomDirected1 + sAtom1
               + " " + sAtom2 + sAtomDirected2);
       } else {
+        // double bond
         if (sAtom2 == null || dir1 == 0)
           continue;
         // cumulene stuff here
@@ -1561,7 +1564,7 @@ public class SmilesSearch extends JmolMolecule {
         nBonds = sAtom2.getBondCount();
         for (int j = 0; j < nBonds && dir2 == 0; j++) {
           b = sAtom2.getBond(j);
-          int type = b.order;
+          int type = b.getBondType();
           switch (type) {
           case Edge.BOND_STEREO_NEAR:
           case Edge.BOND_STEREO_FAR:
@@ -1642,7 +1645,7 @@ public class SmilesSearch extends JmolMolecule {
     return (s + "   ").substring(0, 3);
   }
 
-  private void setTopoCoordinates(SmilesAtom dbAtom1, SmilesAtom dbAtom2,
+  private static void setTopoCoordinates(SmilesAtom dbAtom1, SmilesAtom dbAtom2,
                                       SmilesAtom dbAtom1a, SmilesAtom dbAtom2a,
                                       int bondType) {
     dbAtom1.set(-1, 0, 0);
@@ -1768,7 +1771,7 @@ public class SmilesSearch extends JmolMolecule {
    */
   void createTopoMap(BS bsAro) throws InvalidSmilesException {
     boolean isForMF = (bsAro == null);
-    int nAtomsMissing = getMissingHydrogenCount();
+    int nAtomsMissing = (autoAddImplicitH ? getMissingHydrogenCount() : 0);
     int totalAtoms = ac + nAtomsMissing;
     SmilesAtom[] atoms = new SmilesAtom[totalAtoms];
     targetAtoms = atoms;
@@ -1776,14 +1779,14 @@ public class SmilesSearch extends JmolMolecule {
       SmilesAtom sAtom = patternAtoms[i];
       // this number will include the number of Hs in [CH2] as well as the number needed by C by itself
       int n = sAtom.explicitHydrogenCount;
-      if (n < 0)
+      if (n < 0 || !autoAddImplicitH)
         n = 0;
       // create a Jmol atom for this pattern atom
       // we co-opt atom.matchingAtom here
       // because this search will never actually be run
       SmilesAtom atom = atoms[ptAtom] = new SmilesAtom().setTopoAtom(sAtom.component, ptAtom,
           sAtom.symbol, sAtom.getCharge(), i);
-      atom.implicitHydrogenCount = n;
+        atom.implicitHydrogenCount = n;
       if (isForMF)
         continue;
       atom.mapIndex = i;
@@ -1906,9 +1909,7 @@ public class SmilesSearch extends JmolMolecule {
    * 
    * Not applicable to SMARTS
    * 
-   * @param atoms
    * @param bsAromatic
-   * @param flags
    * @throws InvalidSmilesException
    */
   void normalizeAromaticity(BS bsAromatic)
