@@ -53,7 +53,7 @@ public class SmilesStereo {
   private String details;
   private SmilesSearch search;
   private Node[] jmolAtoms;
-  private String directives;
+//  private String directives;
   final public static int DEFAULT = 0;
   final public static int POLYHEDRAL = 1;           // Jmol polySMILES
   final public static int ALLENE = 2;
@@ -77,12 +77,12 @@ public class SmilesStereo {
   }
 
   SmilesStereo(int chiralClass, int chiralOrder, int atomCount, String details,
-      String directives) throws InvalidSmilesException {
+      @SuppressWarnings("unused") String directives) throws InvalidSmilesException {
     this.chiralClass = chiralClass;
     this.chiralOrder = chiralOrder;
     this.atomCount = atomCount;
     this.details = details;
-    this.directives = directives;
+//    this.directives = directives;
     if (chiralClass == POLYHEDRAL)
       getPolyhedralOrders();
   }
@@ -327,7 +327,7 @@ public class SmilesStereo {
    * @param sAtom2 allene atom
    * @param cAtoms the target atoms
    * @param isNot
-   * @return
+   * @return true if successful
    */
   public boolean setTopoCoordinates(SmilesAtom sAtom0, SmilesAtom pAtom,
                                        SmilesAtom sAtom2, Node[] cAtoms, boolean isNot) {
@@ -595,7 +595,7 @@ public class SmilesStereo {
 
   public int checkStereoForAtom(SmilesAtom pAtom, boolean isNot, boolean haveTopo) {
     Node atom1 = null, atom2 = null, atom3 = null, atom4 = null, atom5 = null, atom6 = null;
-    SmilesAtom pAtom2 = null, sAtom0 = null;
+    SmilesAtom sAtom0 = null;
     Node[] jn;
 
     Node atom0 = pAtom.getMatchingAtom();
@@ -687,12 +687,11 @@ public class SmilesStereo {
       }
       return 0;
     case ALLENE:
-      jn = getAlleneAtoms(pAtom, null);
+      jn = getAlleneAtoms(haveTopo, sAtom0, pAtom, null);
       if (jn == null)
         return 0;
-      if (haveTopo && !setTopoCoordinates(sAtom0, pAtom, pAtom2, jn, false))
+      if (jn.length == 0)
         return -1;
-      
       if (!checkStereochemistryAll(isNot, atom0,
           chiralClass, order, jn[0], jn[1], jn[2], jn[3], null, null, v))
         return -1;
@@ -753,7 +752,15 @@ public class SmilesStereo {
     return true;
   }
 
-  public Node[] getAlleneAtoms(SmilesAtom pAtom, SmilesAtom pAtom1) {
+  /**
+   * 
+   * @param haveTopo 
+   * @param sAtom0 
+   * @param pAtom
+   * @param pAtom1
+   * @return allene atoms
+   */
+  public Node[] getAlleneAtoms(boolean haveTopo, SmilesAtom sAtom0, SmilesAtom pAtom, SmilesAtom pAtom1) {
     if (pAtom1 == null)
       pAtom1 = pAtom.getBond(0).getOtherAtom(pAtom);
     SmilesAtom pAtom2 = pAtom.getBond(1).getOtherAtom(pAtom);
@@ -825,6 +832,9 @@ public class SmilesStereo {
     for (int k = 0; k < 4; k++)
       if (jn[k] == null)
         addAlleneLonePair(k < 2 ? pAtom : pAtom2, jn, k);
+    
+    if (haveTopo && !setTopoCoordinates(sAtom0, pAtom, pAtom2, jn, false))
+      return new Node[0]; 
     return jn;
   }
 
@@ -1134,7 +1144,7 @@ public class SmilesStereo {
       details = "!" + details.substring(1);
     if (details.length() == 0 || details.equals("!")) {
       for (int i = 2; i <= atomCount; i++)
-        details += (i < 10 ? i : "%" + i);
+        details += (i < 10 ? "" + i : "%" + i);
     }
     int[] temp = new int[details.length()];
     int[] ret = new int[1];
