@@ -211,20 +211,27 @@ class PointGroup {
   static PointGroup getPointGroup(PointGroup pgLast, T3 center,
                                          T3[] atomset, BS bsAtoms,
                                          boolean haveVibration,
-                                         float distanceTolerance, float linearTolerance, boolean localEnvOnly) {
+                                         float distanceTolerance, float linearTolerance, int maxAtoms, boolean localEnvOnly) {
     PointGroup pg = new PointGroup();
-    if (distanceTolerance == 0) {
+    if (distanceTolerance <= 0) {
       distanceTolerance = 0.01f;
+    }
+    if (linearTolerance <= 0) {
       linearTolerance = 0.5f;
     }
+    if (maxAtoms <= 0)
+      maxAtoms = 250;
     pg.distanceTolerance = distanceTolerance;
     pg.distanceTolerance2 = distanceTolerance * distanceTolerance;
     pg.linearTolerance = linearTolerance;
+    pg.maxAtoms = maxAtoms;
     pg.isAtoms = (bsAtoms != null);
     pg.bsAtoms = (pg.isAtoms ? bsAtoms : BSUtil.newBitSet2(0, atomset.length));
     pg.haveVibration = haveVibration;
     pg.center = center;
     pg.localEnvOnly = localEnvOnly;
+    if (Logger.debugging)
+      pgLast = null;
     return (pg.set(pgLast, atomset) ? pg : pgLast);
   }
 
@@ -253,7 +260,7 @@ class PointGroup {
     cosTolerance = (float) (Math.cos(linearTolerance / 180 * Math.PI));
     if (!getPointsAndElements(atomset)) {
       Logger.error("Too many atoms for point group calculation");
-      name = "point group not determined -- ac > " + ATOM_COUNT_MAX
+      name = "point group not determined -- ac > " + maxAtoms
           + " -- select fewer atoms and try again.";
       return true;
     }
@@ -432,11 +439,11 @@ class PointGroup {
     return null;
   }
 
-  private final static int ATOM_COUNT_MAX = 100;
+  int maxAtoms = 250;
 
   private boolean getPointsAndElements(T3[] atomset) {
     int ac = bsAtoms.cardinality();
-    if (isAtoms && ac > ATOM_COUNT_MAX)
+    if (isAtoms && ac > maxAtoms)
       return false;
     points = new P3[ac];
     elements = new int[ac];
