@@ -16,13 +16,14 @@ import javajs.util.BS;
 import javajs.util.Lst;
 //import javajs.util.M3;
 import javajs.util.P3;
+import javajs.util.PT;
 
 /**
  * A relatively simple space group finder given a unit cell.
  * The unit cell is used to reduce the options involving hexagonal, tetragonal, and cubic groups.
  * 
  * See https://stokes.byu.edu/iso/findsymform.php for finding the space group
- * given no unit cell information.
+ * given no unit cell information.sp
  * 
  */
 public class SpaceGroupFinder {
@@ -44,7 +45,7 @@ public class SpaceGroupFinder {
   private final static float //SLOP02 = 0.02f, 
       SLOP001 = 0.001f, SLOP0001= 0.0001f;  // 0.001 was too tight for labradorite Si // 0.0001 was too tight here. 
 
-  private static int GROUP_COUNT; // 530
+  private static int GROUP_COUNT; // 531
   private static int OP_COUNT; // 882
   private static BS[] bsOpGroups;
   private static BS[] bsGroupOps;
@@ -73,8 +74,20 @@ public class SpaceGroupFinder {
     }
   }
 
-  public Object findSpaceGroup(Viewer vwr, BS atoms0, String opXYZ0,
-                               SymmetryInterface uc, boolean asString) {
+  /**
+   * 
+   * @param vwr
+   * @param atoms0
+   * @param xyzList
+   * @param unitCellParams
+   * @param uc
+   * @param asString
+   * @param isAssign
+   * @return SpaceGroup or null if isAssign, spacegroup information map if
+   */
+  public Object findSpaceGroup(Viewer vwr, BS atoms0, String xyzList,
+                               float[] unitCellParams, SymmetryInterface uc,
+                               boolean asString, boolean isAssign) {
     P3[] oabc = null;
     Atom[] cartesians = vwr.ms.at;
     int isg = 0;
@@ -82,7 +95,7 @@ public class SpaceGroupFinder {
     BS bsOps = new BS();
     BS bsAtoms = null;
     BS bsPoints0 = new BS();
-    if (opXYZ0 == null) {
+    if (xyzList == null || isAssign) {
       bsAtoms = BSUtil.copy(atoms0);
       nAtoms = bsAtoms.cardinality();
     }
@@ -92,15 +105,21 @@ public class SpaceGroupFinder {
     // this will be set in checkSupercell
     P3 scaling = P3.new3(1, 1, 1);
     //    BS withinCell = null;
+    SpaceGroup sg = null;
     try {
       if (bsOpGroups == null)
         loadData(vwr, this);
-      if (opXYZ0 != null) {
-        return getGroupsWithOp(opXYZ0);
+      if (xyzList != null) {
+        Object ret = getGroupsWithOps(xyzList, unitCellParams, isAssign);
+        if (!isAssign)
+          return ret;
+        sg = (SpaceGroup) ret;
+        uc.setUnitCell(unitCellParams, false);
       }
       oabc = uc.getUnitCellVectors();
       uc = uc.getUnitCellMultiplied();
-      filterGroups(bsGroups, uc);
+      filterGroups(bsGroups, uc.getUnitCellParams());
+
       //      withinCell = vwr.ms.getAtoms(T.unitcell, uc);
       //BS extraAtoms = BSUtil.copy(bsAtoms);
       //extraAtoms.andNot(withinCell);
@@ -199,7 +218,7 @@ public class SpaceGroupFinder {
       BS temp1 = BS.newN(OP_COUNT);
       BS targeted = BS.newN(nAtoms);
 
-      bsOps.setBits(1, OP_COUNT);
+      bsOps.setBits(1, sg == null ? OP_COUNT : sg.getOperationCount());
       if (nAtoms == 0) {
         bsGroups.clearBits(1, GROUP_COUNT);
         bsOps.clearAll();
@@ -211,12 +230,16 @@ public class SpaceGroupFinder {
       BS opsChecked = BS.newN(OP_COUNT);
       opsChecked.set(0);
       boolean hasC1 = false;
-      for (int iop = bsOps.nextSetBit(1);iop > 0 && bsGroups.cardinality() > 0; iop = bsOps.nextSetBit(iop + 1)) {
-        SymmetryOperation op = getOp(iop);
+      for (int iop = bsOps.nextSetBit(1); iop > 0
+          && bsGroups.cardinality() > 0; iop = bsOps.nextSetBit(iop + 1)) {
+        SymmetryOperation op = (sg == null ? getOp(iop)
+            : (SymmetryOperation) sg.getOperation(iop));
+        if (sg == null) {
         System.out.println("\nChecking operation " + iop + " " + opXYZ[iop]);
         System.out.println("bsGroups = " + bsGroups);
         System.out.println("bsOps = " + bsOps);
         nChecked++;
+        }
         boolean isOK = true;
         bsPoints.clearAll();
         bsPoints.or(bsPoints0);
@@ -227,15 +250,18 @@ public class SpaceGroupFinder {
           //          if (iop == 15 && i == 46)
           //            System.out.println("????");
           int j = findEquiv(iop, op, i, bsPoints, pt, true);
-          if (j < 0) {
-              System.out.println("failed op " + iop + " for atom " + i + " " + atoms[i].name + " " + atoms[i] + " looking for " + pt + "\n" + op);
+          if (j < 0 && sg == null) {
+            System.out.println(
+                "failed op " + iop + " for atom " + i + " " + atoms[i].name
+                    + " " + atoms[i] + " looking for " + pt + "\n" + op);
             isOK = false;
             break;
           }
-          if (i != j) {
+          if (j >= 0 && i != j) {
             targeted.set(j);
           }
         }
+        if (sg == null) {
         BS myGroups = bsOpGroups[iop];
         bsOps.clear(iop);
         opsChecked.set(iop);
@@ -271,7 +297,11 @@ public class SpaceGroupFinder {
           }
           bsOps.and(temp1);
         }
+        } else {
+          targets.or(targeted);
       }
+      }
+      if (sg == null) {
       n = bsGroups.cardinality();
       if (n == 0) {
         bsGroups.set(hasC1 ? 1 : 0);
@@ -309,11 +339,13 @@ public class SpaceGroupFinder {
         if (isg == 0)
           targets.clearAll();
       }
-
+      }
     } catch (Exception e) {
       e.printStackTrace();
       bsGroups.clearAll();
     }
+
+    if (sg == null) {
     System.out.println("checked " + nChecked + " operations; now " + n + " "
         + bsGroups + " " + bsOps);
     for (int i = bsGroups.nextSetBit(0); i >= 0; i = bsGroups
@@ -322,16 +354,15 @@ public class SpaceGroupFinder {
     }
     if (n != 1)
       return null;
-    SpaceGroup sg = SpaceGroup.nameToGroup.get(groupNames[isg]);
+      sg = SpaceGroup.nameToGroup.get(groupNames[isg]);
+    }
     String name = sg.asString();
-//    uc.setSpaceGroupName(name);
-    BS basis = BSUtil.copy(
-        //isg == 0 ? withinCell : 
-        bsAtoms);
+    BS basis = BSUtil.copy(bsAtoms);
     for (int i = targets.nextSetBit(0); i >= 0; i = targets.nextSetBit(i + 1))
       basis.clear(atoms[i].index);
     int nb = basis.cardinality();
-    String msg = name + "\nbasis is " + nb + " atom" + (nb == 1 ? "" : "s") + ": " + basis;
+    String msg = name + "\nbasis is " + nb + " atom" + (nb == 1 ? "" : "s")
+        + ": " + basis;
     System.out.println(msg);
     if (asString)
       return msg;
@@ -340,6 +371,7 @@ public class SpaceGroupFinder {
     System.out.println("unitcell is " + uc.getUnitCellInfo(true));
     BS bs1 = BS.copy(bsPoints0);
     bs1.andNot(targets);
+    if (!isAssign)
     dumpBasis(bsGroupOps[isg], bs1, bsPoints0);
     map.put("name", name);
     map.put("basis", basis);
@@ -348,6 +380,8 @@ public class SpaceGroupFinder {
     oabc[2].scale(scaling.y);
     oabc[3].scale(scaling.z);
     map.put("unitcell", oabc);
+    if (isAssign)
+      map.put("sg", sg);
     return map;
   }
 
@@ -472,10 +506,9 @@ public class SpaceGroupFinder {
    * 
    * 
    * @param bsGroups
-   * @param uc
+   * @param params
    */
-  private void filterGroups(BS bsGroups, SymmetryInterface uc) {
-    float[] params = uc.getUnitCellParams();
+  private void filterGroups(BS bsGroups, float[] params) {
     boolean isOrtho = false, isTet = false, isTri = false,
         isRhombo = false, isCubic = false;
     boolean absame = approx0(params[0]-params[1]);
@@ -554,23 +587,91 @@ public class SpaceGroupFinder {
     return i;
   }
 
-  private Object getGroupsWithOp(String opXYZ0) {
-    BS groups = null;
-    for (int i = opXYZ.length; --i >= 0;) {
-      if (opXYZ[i].equals(opXYZ0)) {
-        groups = bsOpGroups[i];
-        System.out.println("found for " + opXYZ0 + " " + groups);
-        break;
+  /**
+   * Find all space groups that match EXACTLY or contain all of the operations
+   * specified. Operation need not be in Jmol-canonical form. For instance,
+   * "1-x,-y,-z" will be matched to "-x,-y,-z".
+   *
+   * 
+   * Could be the result of spacegroup(nameOrXYZList, unitcellParametersArray)
+   * or MODELKIT ASSIGN SPACEGROUP "nameOrXYZList" other than P1
+   * 
+   * @param xyzList
+   *        a semicolon-separated list of possible space groups, such as
+   *        "-x,-y,-z;x,-y,-z" or a space group ID such as "133:2"; if a list,
+   *        prefixing or postfixing the list with "&" or joining with "&"
+   *        indicates that a partial match is desired, returning a list of names
+   *        of space groups that have at least the specified operations
+   * @param unitCellParams
+   * @param isAssign
+   *        from ModelKit
+   * @return an array of space group IDs if not isAssign and not "="; a
+   *         SpaceGroup or null if isAssign; a single space group ID as a string
+   *         if "=" and a string starting and ending with "?" if an xyz operator
+   *         is of an invalid form.
+   */
+  private Object getGroupsWithOps(String xyzList, float[] unitCellParams, boolean isAssign) {
+    BS groups = new BS();
+    if (unitCellParams == null) {
+      groups.setBits(0,  GROUP_COUNT);
+    } else {
+      filterGroups(groups, unitCellParams);
+    }
+    SpaceGroup sg = null;
+    if (xyzList.indexOf("x") < 0) {
+      // space group name -- here we return a space group if unit cell symmetry is allowed
+      sg = SpaceGroup.determineSpaceGroupNA(xyzList, unitCellParams);
+      if (sg == null)
+        return null;
+      sg.checkHallOperators();
+      // check for appropriate unit cell
+      for (int i = 0; i < GROUP_COUNT; i++)
+        if (groupNames[i].equals(sg.intlTableNumberFull))
+          return (groups.get(i) ? sg : null);
+      return null;
+    }
+    // xyz list only, possibly starting with "&" for partial match
+    boolean isEqual = xyzList.indexOf("&") < 0 || isAssign;
+    String[] ops = PT.split(PT.trim(xyzList.trim().replace('&', ';'), ";="), ";");
+    for (int j = ops.length; --j >= 0;) {
+      String xyz = ops[j];
+      if (xyz == null || xyz.indexOf("z") < xyz.lastIndexOf(","))
+        return "?" + ops[j] + "?";
+      xyz = SymmetryOperation.getJmolCanonicalXYZ(xyz);
+      for (int i = opXYZ.length; --i >= 0;) {
+        if (opXYZ[i].equals(xyz)) {
+          groups.and(bsOpGroups[i]);
+          break;
+        }
+        // check for not found
+        if (i == 0)
+          groups.clearAll();
       }
     }
-    if (groups != null) {
-      String[] ret = new String[groups.cardinality()];
-      for (int p = 0, i = groups.nextSetBit(0); i >= 0; i = groups.nextSetBit(i + 1)) {
-        ret[p++] = SpaceGroup.getID(i);
-      }
-      return ret;
+    if (groups.isEmpty()) {
+      // if assigning, we must assume that this is a non-standard unknown setting 
+      // and the unit cell is OK. We just define the space group as is.
+      return (isAssign ? SpaceGroup.createSpaceGroupN(xyzList) : null);
     }
-    return null;
+    if (isEqual) {
+      for (int n = ops.length, i = groups.nextSetBit(0); i >= 0; i = groups
+          .nextSetBit(i + 1)) {
+        if (bsGroupOps[i].cardinality() == n) {
+          if (isAssign) {
+            return SpaceGroup.createSpaceGroupN(groupNames[i]);
+          }
+          return SpaceGroup.getInfo(null, groupNames[i], unitCellParams, true, false);
+        } 
+      }
+      return null;
+    }
+    // at this point, the group has cardinality of at least 1 
+    String[] ret = new String[groups.cardinality()];
+    for (int p = 0, i = groups.nextSetBit(0); i >= 0; i = groups
+        .nextSetBit(i + 1)) {
+      ret[p++] = groupNames[i];
+    }
+    return ret;
   }
 
 //  private SymmetryInterface checkTetragonal(Viewer vwr, SymmetryInterface uc, M3 mtet) {    
