@@ -103,10 +103,10 @@ public class Symmetry implements SymmetryInterface {
                                          boolean haveVibration,
                                          float distanceTolerance,
                                          float linearTolerance,
-                                         boolean localEnvOnly) {
+                                         int maxAtoms, boolean localEnvOnly) {
     pointGroup = PointGroup.getPointGroup(
         siLast == null ? null : ((Symmetry) siLast).pointGroup, center, atomset,
-        bsAtoms, haveVibration, distanceTolerance, linearTolerance,
+        bsAtoms, haveVibration, distanceTolerance, linearTolerance, maxAtoms,
         localEnvOnly);
     return this;
   }
@@ -179,9 +179,9 @@ public class Symmetry implements SymmetryInterface {
   }
 
   @Override
-  public Object getSpaceGroupInfoObj(String name, SymmetryInterface cellInfo,
+  public Object getSpaceGroupInfoObj(String name, float[] params,
                                      boolean isFull, boolean addNonstandard) {
-    return SpaceGroup.getInfo(spaceGroup, name, cellInfo, isFull,
+    return SpaceGroup.getInfo(spaceGroup, name, params, isFull,
         addNonstandard);
   }
 
@@ -217,11 +217,6 @@ public class Symmetry implements SymmetryInterface {
                 : spaceGroup.finalOperations[i]);
   }
 
-  @Override
-  public M4 getSpaceGroupOperationRaw(int i) {
-    return spaceGroup.getRawOperation(i);
-  }
-
   @Override
   public String getSpaceGroupXyz(int i, boolean doNormalize) {
     return spaceGroup.getXyz(i, doNormalize);
@@ -771,10 +766,11 @@ public class Symmetry implements SymmetryInterface {
           .append(SimpleUnitCell.escapeMultiplier(pt));
       loadUC = true;
     }
-    String sg0 = (String) ms.getInfo(modelIndex, "spaceGroupOriginal");
+    boolean isAssigned = (ms.getInfo(modelIndex, "spaceGroupAssigned") != null);
     String sg = (String) ms.getInfo(modelIndex, "spaceGroup");
-    if (sg0 != null && sg != null && !sg.equals(sg0)) {
-      commands.append("\nMODELKIT SPACEGROUP " + PT.esc(sg));
+    if (isAssigned && sg != null) {
+      commands.append("\n UNITCELL " + Escape.e(ms.getUnitCell(modelIndex).getUnitCellVectors()));
+      commands.append("\n MODELKIT SPACEGROUP " + PT.esc(sg));
       loadUC = true;
     }
     return loadUC;
@@ -914,11 +910,11 @@ public class Symmetry implements SymmetryInterface {
   }
 
   @Override
-  public Object findSpaceGroup(Viewer vwr, BS atoms, String opXYZ,
-                               boolean asString) {
+  public Object findSpaceGroup(Viewer vwr, BS atoms, String xyzList, float[] unitCell,
+                               boolean asString, boolean isAssign) {
     return ((SpaceGroupFinder) Interface
         .getInterface("org.jmol.symmetry.SpaceGroupFinder", vwr, "eval"))
-            .findSpaceGroup(vwr, atoms, opXYZ, this, asString);
+            .findSpaceGroup(vwr, atoms, xyzList, unitCell, this, asString, isAssign);
   }
 
   @Override
@@ -932,32 +928,34 @@ public class Symmetry implements SymmetryInterface {
   }
 
   @Override
-  public BS removeDuplicates(ModelSet ms, BS bs) {
+  public BS removeDuplicates(ModelSet ms, BS bs, boolean highPrec) {
     UnitCell uc = this.unitCell;
     Atom[] atoms = ms.at;
     float[] occs = ms.occupancies;
     boolean haveOccupancies = (occs != null);
-    P3 pt = new P3();
-    P3 pt2 = new P3();
+    P3[] unitized = new P3[bs.length()];
+    for (int i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
+      P3 pt = unitized[i] =  P3.newP(atoms[i]);
+      uc.toFractional(pt, false);
+      if (highPrec)
+        uc.unitizeRnd(pt); 
+      else
+        uc.unitize(pt);
+    }
     for (int i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
       Atom a = atoms[i];
-      pt.setT(a);
-      uc.toFractional(pt, false);
-      uc.unitizeRnd(pt);
+      P3 pt = unitized[i];
       int type = a.getAtomicAndIsotopeNumber();
-
       float occ = (haveOccupancies ? occs[i] : 0);
       for (int j = bs.nextSetBit(i + 1); j >= 0; j = bs.nextSetBit(j + 1)) {
         Atom b = atoms[j];
         if (type != b.getAtomicAndIsotopeNumber()
             || (haveOccupancies && occ != occs[j]))
           continue;
-        pt2.setT(b);
-        uc.toFractional(pt2, false);
-        uc.unitizeRnd(pt2);
+        P3 pt2 = unitized[j];
         if (pt.distanceSquared(pt2) < JC.UC_TOLERANCE2) {
           bs.clear(j);
-        }
+        } 
       }
     }
     return bs;
@@ -1071,4 +1069,15 @@ public class Symmetry implements SymmetryInterface {
     atom2.add3(x, y, z);
   }
 
+  @Override
+  public boolean isWithinUnitCell(P3 pt, float a, float b, float c) {
+    return unitCell.isWithinUnitCell(a, b, c, pt);
+  }
+
+  @Override
+  public boolean checkPeriodic(P3 pt) {
+    return unitCell.checkPeriodic(pt);
+  }
+
+
 }
