@@ -1796,7 +1796,7 @@ public class SymmetryDesc {
     } else {
       if (haveName && !haveRawName)
         sym.setSpaceGroupName(sgName);
-      data = sym.getSpaceGroupInfoObj(sgName, cellInfo, isFull, !isForModel);
+      data = sym.getSpaceGroupInfoObj(sgName, (cellInfo == null ? null : cellInfo.getUnitCellParams()), isFull, !isForModel);
       if (data == null || data.equals("?")) {
         data = "?";
         info.put("spaceGroupNote",
