@@ -947,27 +947,34 @@ class UnitCell extends SimpleUnitCell implements Cloneable {
     if (packed) {
       // duplicate all the points. 
       for (int i = n0; i < n; i++) {
-        P3 p = list.get(i);
-        unitizeRnd(p);
-        if (p.x == 0) {
-          list.addLast(P3.new3(1, p.y, p.z));
-          if (p.y == 0) {
-            list.addLast(P3.new3(1, 1, p.z));
-            if (p.z == 0) {
+        pf.setT(list.get(i));
+        unitizeRnd(pf);
+        if (pf.x == 0) {
+          list.addLast(P3.new3(0,  pf.y,  pf.z));
+          list.addLast(P3.new3(1,  pf.y,  pf.z));
+          if (pf.y == 0) {
+            list.addLast(P3.new3(1, 1,  pf.z));
+            list.addLast(P3.new3(0, 0,  pf.z));
+            if (pf.z == 0) {
               list.addLast(P3.new3(1, 1, 1));
+              list.addLast(P3.new3(0, 0, 0));
             }
           }
         }
-        if (p.y == 0) {
-          list.addLast(P3.new3(p.x, 1, p.z));
-          if (p.z == 0) {
-            list.addLast(P3.new3(p.x, 1, 1));
+        if (pf.y == 0) {
+          list.addLast(P3.new3( pf.x, 0,  pf.z));
+          list.addLast(P3.new3( pf.x, 1,  pf.z));
+          if (pf.z == 0) {
+            list.addLast(P3.new3( pf.x, 0, 0));
+            list.addLast(P3.new3( pf.x, 1, 1));
           }
         }
-        if (p.z == 0) {
-          list.addLast(P3.new3(p.x, p.y, 1));
-          if (p.x == 0) {
-            list.addLast(P3.new3(1, p.y, 1));
+        if (pf.z == 0) {
+          list.addLast(P3.new3( pf.x,  pf.y, 0));
+          list.addLast(P3.new3( pf.x,  pf.y, 1));
+          if (pf.x == 0) {
+            list.addLast(P3.new3(0,  pf.y, 0));
+            list.addLast(P3.new3(1,  pf.y, 1));
           }
         }
       }
