@@ -24,6 +24,7 @@
 
 package org.jmol.util;
 
+import javajs.util.PT;
 
 public abstract class Edge implements SimpleEdge {
 
@@ -35,29 +36,32 @@ public abstract class Edge implements SimpleEdge {
    *
    */
   
-  // 1111 1111 1100 0000 0000
-  // 9876 5432 1098 7654 3210
-  // || CIP stereochemistry mask (unk)  3 << 18  0xC0000
-  // |  CIP stereochemistry Z           2 << 18  0x80000
-  //  | CIP stereochemistry E           1 << 18  0x40000
-  //   | new connection                 1 << 17  0x20000
-  //    | render as single              1 << 16  0x10000
-  //    |   PyMOL render single         2 << 15  0x18000 + covalent order 
-  //    | | PyMOL render multiple       3 << 15  0x18000 + covalent order 
-  //      | strut                       1 << 15  0x08000
-  //    |  nnm m            | atropisomer        0x10001 + (nnmm << 11)
-  //       ||| | Hydrogen bond          F << 11  0x03800
-  //            |Stereo                 1 << 10  0x00400   
-  //             |Aromatic              1 << 9   0x00200
-  //              |Sulfur-Sulfur        1 << 8   0x00100
-  //                ||| Partial n       7 << 5   0x00E00
-  //                   | |||| Partial m          0x0001F
-  //                      ||| Covalent order     0x00007
-  //            ||| |||| |||| Covalent           0x003FF
-  // 0000 0000 0000 0001 0001 UNSPECIFIED
-  // 0000 1111 1111 1111 1111 ANY
-  // 0001 1111 1111 1111 1111 NULL
+  //.1 1111 1111 1100 0000 0000
+  //.0 9876 5432 1098 7654 3210
+  //
+  //.. ...| |||| |||| |||| |||| render mask         0x01FFFF
+  //.. ||.. CIP stereochemistry mask (unk)  3 << 18  0xC0000
+  //.. |... CIP stereochemistry Z           2 << 18  0x80000
+  //.. .|.. CIP stereochemistry E           1 << 18  0x40000
+  //.. ..|. new connection                  1 << 17  0x20000
+  //.. ...| render as single                1 << 16  0x10000
+  //.. ...| .... PyMOL render single        2 << 15  0x18000 + covalent order 
+  //.. ...| |... PyMOL render multiple      3 << 15  0x18000 + covalent order 
+  //.. .... |... strut                      1 << 15  0x08000
+  //.. ...| .nnm m... .... ...| atropisomer          0x10001 + (nnmm << 11)
+  //.. .... .||| |... Hydrogen bond         F << 11  0x03800
+  //.. .... .... .||| |||| |||| Covalent             0x003FF
+  //.. .... .... .|.. Stereo                1 << 10  0x00400   
+  //.. .... .... ..|. Aromatic              1 << 9   0x00200
+  //.. .... .... ...| Sulfur-Sulfur         1 << 8   0x00100
+  //.. .... .... .... |||. Partial n        7 << 5   0x00E00
+  //.. .... .... .... ...| |||| Partial m            0x0001F
+  //.. .... .... .... .... .||| Covalent order       0x00007
+  //.0 0000 0000 0000 0001 0001 UNSPECIFIED
+  //.0 0000 1111 1111 1111 1111 ANY
+  //.0 0001 1111 1111 1111 1111 NULL
 
+  public final static int BOND_RENDER_MASK     = 0x1FFFF;
   public final static int BOND_RENDER_SINGLE   = 0x10000;
 
   public final static int TYPE_ATROPISOMER     = 0x10001;
@@ -73,8 +77,9 @@ public abstract class Edge implements SimpleEdge {
 
 
   public final static int BOND_STEREO_MASK   = 0x400; // 1 << 10
-  public final static int BOND_STEREO_NEAR   = 0x401; // for JME reader and SMILES
-  public final static int BOND_STEREO_FAR    = 0x411; // for JME reader and SMILES
+  public final static int BOND_STEREO_NEAR   = 0x401; // for JME reader and SMILES and XMLChemDraw reader
+  public final static int BOND_STEREO_FAR    = 0x411; // for JME reader and SMILES and XMLChemDraw reader
+  public final static int BOND_STEREO_EITHER = 0x421; // for JME reader and SMILES and XMLChemDraw reader
   public final static int BOND_AROMATIC_MASK   = 0x200; // 1 << 9
   public final static int BOND_AROMATIC_SINGLE = 0x201; // same as single
   public final static int BOND_AROMATIC_DOUBLE = 0x202; // same as double
@@ -111,7 +116,7 @@ public abstract class Edge implements SimpleEdge {
   public final static int BOND_H_MINUS_3     = 7 << 11;
   public final static int BOND_H_MINUS_4     = 8 << 11;
   public final static int BOND_H_NUCLEOTIDE  = 9 << 11;
-    
+
   private final static int[] argbsHbondType = {
     0xFFFF69B4, // 0  unused - pink
     0xFFFFFF00, // 1  regular yellow
@@ -138,6 +143,8 @@ public abstract class Edge implements SimpleEdge {
   @Override
   abstract public boolean isCovalent();
 
+  abstract public boolean isPartial();
+
   abstract public boolean isHydrogen();
 
   public static int getArgbHbondType(int order) {
@@ -152,7 +159,7 @@ public abstract class Edge implements SimpleEdge {
    * @return a string representation to preserve float n.m
    */
   public final static String getBondOrderNumberFromOrder(int order) {
-    order &= ~BOND_NEW;
+    order &= BOND_RENDER_MASK;
     switch (order) {
     case BOND_ORDER_NULL:
     case BOND_ORDER_ANY:
@@ -192,7 +199,7 @@ public abstract class Edge implements SimpleEdge {
   }
 
   public final static String getBondOrderNameFromOrder(int order) {
-    order &= ~BOND_NEW;
+    order &= BOND_RENDER_MASK;
     switch (order) {
     case BOND_ORDER_ANY:
     case BOND_ORDER_NULL:
@@ -252,13 +259,15 @@ public abstract class Edge implements SimpleEdge {
   }
 
   public final static int getPartialBondOrder(int order) {
-    return ((order & ~BOND_NEW) >> 5);
+    return ((order & BOND_RENDER_MASK) >> 5);
   }
 
   protected final static int getCovalentBondOrder(int order) {
+    if ((order & BOND_STEREO_MASK) != 0)
+      return 1;
     if ((order & BOND_COVALENT_MASK) == 0)
       return 0;
-    order &= ~BOND_NEW; 
+    order &= BOND_RENDER_MASK; 
     if ((order & BOND_PARTIAL_MASK) != 0)
       return getPartialBondOrder(order);
     if ((order & BOND_SULFUR_MASK) != 0)
@@ -293,21 +302,98 @@ public abstract class Edge implements SimpleEdge {
     return BOND_ORDER_NULL;
   }
 
-  public static int getBondOrderFromString(String name) {
-    int order = EnumBondOrder.getCodeFromName(name);
+  /**
+   * Encode name such as 1 2 3 2.1 3.1 single double triple atropisomer_12 or
+   * "partial 1.3"
+   * 
+   * @param s
+   * @return encoded form of bond
+   */
+  public static int getBondOrderFromString(String s) {
+    if (s.indexOf(' ') < 0) {
+      if (s.indexOf(".") >= 0) {
+        s = "partial " + s;
+      } else {
+        if (PT.isOneOf(s, ";1;2;3;4;5;6;")) {
+          return s.charAt(0) - '0';
+        }
+        // single double triple...
+        int order = EnumBondOrder.getCodeFromName(s);
+        if (order != BOND_ORDER_NULL
+            || !s.toLowerCase().startsWith("atropisomer_") || s.length() != 14)
+          return order;
     try {
-      if (order == BOND_ORDER_NULL && name.length() == 14
-          && name.toLowerCase().startsWith("atropisomer_"))
-        order = getAtropismOrder(Integer.parseInt(name.substring(12, 13)), Integer.parseInt(name.substring(13, 14)));
+          // atropoisomer_12 or atropisomer_21 stereochemistry
+          order = getAtropismOrder(Integer.parseInt(s.substring(12, 13)),
+              Integer.parseInt(s.substring(13, 14)));
     } catch (NumberFormatException e) {
       // BOND_ORDER_NULL
     }
     return order;
   }
+    }
+    if (s.toLowerCase().indexOf("partial ") != 0)
+      return BOND_ORDER_NULL;
+    s = s.substring(8).trim();
+    return getPartialBondOrderFromFloatEncodedInt(getFloatEncodedInt(s));
+  }
   
+  /**
+   * reads standard n.m double-as-integer (n*1000000 + m) 
+   * and returns partial bond order as (n % 7) << 5 + (m % 0x1F)
+   * 
+   * @param bondOrderInteger
+   * @return partial bond order encoded as an integer
+   */
+  public static int getPartialBondOrderFromFloatEncodedInt(int bondOrderInteger) {
+    return (((bondOrderInteger / 1000000) % 7) << 5)
+        + ((bondOrderInteger % 1000000) & 0x1F);
+  }
+
+  /**
+   * Encodes a string such as "2.10" as an integer instead of a double so as to
+   * distinguish "2.1" from "2.10".
+   * 
+   * For n.m, returns n * 1000000 + m.
+   * 
+   * 2147483647 is maxvalue, so this allows an encoding of up to 
+   * n = 2147 and m = 999999
+   * 
+   * Used in Jmol for model numbers and partial bond orders. 
+   * 
+   * @param strDecimal
+   * @return double encoded as an integer
+   */
+  public static int getFloatEncodedInt(String strDecimal) {
+    int pt = strDecimal.indexOf(".");
+    if (pt < 1 || strDecimal.charAt(0) == '-' || strDecimal.endsWith(".")
+        || strDecimal.contains(".0"))
+      return Integer.MAX_VALUE;
+    int i = 0;
+    int j = 0;
+    if (pt > 0) {
+      try {
+        i = Integer.parseInt(strDecimal.substring(0, pt));
+        if (i < 0)
+          i = -i;
+      } catch (NumberFormatException e) {
+        i = -1;
+      }
+    }
+    if (pt < strDecimal.length() - 1)
+      try {
+        j = Integer.parseInt(strDecimal.substring(pt + 1));
+      } catch (NumberFormatException e) {
+        // not a problem
+      }
+    i = i * 1000000 + j;
+    return (i < 0 || i > Integer.MAX_VALUE ? Integer.MAX_VALUE : i);
+  }
+
+
   @Override
   public int getBondType() {
-    return order & ~BOND_NEW;
+    return order & BOND_RENDER_MASK;
   }
 
   private enum EnumBondOrder {
@@ -378,4 +464,5 @@ public abstract class Edge implements SimpleEdge {
     return "";
   }
 
+
 }
