@@ -4,6 +4,7 @@ package org.jmol.util;
 import javajs.util.AU;
 import javajs.util.M3;
 import javajs.util.P3;
+import javajs.util.P3i;
 import javajs.util.T3;
 import javajs.util.V3;
 
@@ -408,7 +409,7 @@ public class GData implements JmolGraphicsInterface {
         Font.FONT_STYLE_PLAIN, fontSize, fontSize, apiPlatform, graphicsForMetrics);
   }
 
-  public byte getFontFidFS(String fontFace, float fontSize) {
+  public int getFontFidFS(String fontFace, float fontSize) {
     return getFont3DFSS(fontFace, "Bold", fontSize).fid;
   }
 
@@ -427,10 +428,28 @@ public class GData implements JmolGraphicsInterface {
         font.idFontFace, font.idFontStyle, newScale, font.fontSizeNominal, apiPlatform, graphicsForMetrics));
   }
 
-  public byte getFontFid(float fontSize) {
+  public int getFontFidI(float fontSize) {
     return getFont3D(fontSize).fid;
   }
 
+  protected Font currentFont;
+
+  public Font getFont3DCurrent() {
+    return currentFont;
+  }
+
+  /**
+   * @param font3d  
+   */
+  public void setFont(Font font3d) {
+    // see Graphics3D
+  }
+  
+  public void setFontBold(String fontFace, float fontSize) {
+    setFont(getFont3DFSS(fontFace, "Bold", fontSize));
+  }
+
+
   /**
    * @param TF  
    */
@@ -594,18 +613,6 @@ public class GData implements JmolGraphicsInterface {
   public void renderBackground(JmolRendererInterface jmolRenderer) {
   }
 
-  /**
-   * @param font3d  
-   */
-  public void setFont(Font font3d) {
-  }
-
-  /**
-   * @param fid  
-   */
-  public void setFontFid(byte fid) {
-  }
-
   public int argbNoisyUp, argbNoisyDn;
 
   public void setColor(int argb) {
@@ -742,12 +749,10 @@ public class GData implements JmolGraphicsInterface {
 
   protected static short normixCount = Normix.getNormixCount();
   
-  protected Font currentFont;
-
-  public Font getFont3DCurrent() {
-    return currentFont;
+  @Override
+  public void drawLinePixels(P3i sA, P3i sB, int z, int zslab) {
+    return;
   }
 
 
-
 }
