@@ -146,7 +146,7 @@ public class JmolMolecule {
     if (atomIndexNot >= 0)
       bsToTest.clear(atomIndexNot);
     return (getCovalentlyConnectedBitSet(atoms, atoms[atomIndex],
-        bsToTest, allowCyclic, allowBioResidue, biobranches, bs) ? bs : new BS());
+        bsToTest, allowCyclic, allowBioResidue, biobranches, bs, null, null) ? bs : new BS());
   }
 
   public final static JmolMolecule[] addMolecule(JmolMolecule[] molecules,
@@ -292,13 +292,13 @@ public class JmolMolecule {
     return jm;
   }
 
-  private static boolean getCovalentlyConnectedBitSet(Node[] atoms,
-                                                      Node atom,
+  private static boolean getCovalentlyConnectedBitSet(Node[] atoms, Node atom,
                                                       BS bsToTest,
                                                       boolean allowCyclic,
                                                       boolean allowBioResidue,
                                                       Lst<BS> biobranches,
-                                                      BS bsResult) {
+                                                      BS bsResult,
+                                                      Node origAtom, Node prevAtom) {
     int atomIndex = atom.getIndex();
     if (!bsToTest.get(atomIndex))
       return allowCyclic;
@@ -318,7 +318,7 @@ public class JmolMolecule {
               continue;
             bsToTest.set(j);
             getCovalentlyConnectedBitSet(atoms, atom1, bsToTest, allowCyclic,
-                allowBioResidue, biobranches, bsResult);
+                allowBioResidue, biobranches, bsResult, origAtom, atom);
             bsToTest.clear(j);
           }
           break;
@@ -334,11 +334,17 @@ public class JmolMolecule {
 
     for (int i = bonds.length; --i >= 0;) {
       Edge bond = bonds[i];
-      if (bond != null && bond.isCovalent()
-          && !getCovalentlyConnectedBitSet(atoms, (Node) bond.getOtherNode(atom),
-              bsToTest, allowCyclic, allowBioResidue, biobranches, bsResult))
+      if (bond != null && bond.isCovalent()) {
+        Node n = (Node) bond.getOtherNode(atom);
+        if (n == prevAtom)
+          continue;
+        if (n == origAtom)
+          return false;
+        if (!getCovalentlyConnectedBitSet(atoms, n, bsToTest,
+            allowCyclic, allowBioResidue, biobranches, bsResult, origAtom, atom))
         return false;
     }
+    }
     return true;
   }
   
@@ -378,6 +384,33 @@ public class JmolMolecule {
         return new BS();
     return bs;
   }
+
+  public static BS getBranchesForInversion(Node[] at, int atomIndex,
+                                           BS bsToTest) {
+    BS bs = new BS();
+    Node a = at[atomIndex];
+    Edge[] bonds = a.getEdges();
+    for (int i = a.getBondCount(); --i >= 0;) {
+      if (bonds[i].getBondType() == Edge.BOND_COVALENT_SINGLE)
+        bs.set(bonds[i].getOtherNode(a).getIndex());
+    }
+    if (bs.cardinality() < 2) {
+      bs.clearAll();
+    } else {
+      for (int i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
+        if (at[i].getCovalentBondCount() == 1)
+          continue;
+        BS bs0 = BS.copy(bsToTest);
+        bs0.clear(atomIndex);
+        BS bs1 = BS.newN(at.length);
+        if (!getCovalentlyConnectedBitSet(at, at[i], bs0,
+            true, true, null, bs1, at[atomIndex], at[atomIndex])) {
+          bs.clear(i);
+      }
+    }
+    }
+    return bs;
+  }
   
 
 }  
