@@ -480,7 +480,7 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
         qtOffset = null;
       calculate(qtOffset, isQ);
       if (!Float.isNaN(vOcc))
-        occValue = getOccupancy();
+        getOccupancy(true);
     }
     if (isOn) {
       addTo(a, 1);
@@ -542,8 +542,9 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
   }
 
   @Override
-  public Object getModulation(char type, T3 tuv) {
-    getModCalc();
+  public Object getModulation(char type, T3 tuv, boolean occ100) {
+	// occ100 is for vibration (including occupancy) visualization only
+	getModCalc();
     switch (type) {
     case 'D':
       // return r0 if t456 is null, otherwise calculate dx,dy,dz for a given t4,5,6
@@ -559,8 +560,15 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
           (modDim > 2 ? (float) ta[2][0] : 0));
     case 'O':
       // return the currently modulated or calculated occupation on [0,100]
-      return Float.valueOf(Math.abs(tuv == null ? getOccupancy100(false)
-          : modCalc.calculate(tuv, false).getOccupancy100(false)));
+      if (tuv == null) {
+        return Float.valueOf(occ100 ? getOccupancy100(false) : getOccupancy(false));
+      } 
+        modCalc.calculate(tuv, false);
+        float f = modCalc.getOccupancy(occ100);
+        if (occ100)
+          f = modCalc.getOccupancy100(false);
+      // return the currently modulated or calculated occupation on [0,100]
+      return Float.valueOf(Math.abs(f));
     }
     return null;
   }
@@ -621,7 +629,7 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
     modInfo.put("sigma", sigma.getArray());
     modInfo.put("symop", Integer.valueOf(iop + 1));
     modInfo.put("strop", strop);
-    modInfo.put("unitcell", symmetry.getUnitCellInfo());
+    modInfo.put("unitcell", symmetry.getUnitCellInfo(true));
 
     Lst<Hashtable<String, Object>> mInfo = new Lst<Hashtable<String, Object>>();
     for (int i = 0; i < mods.size(); i++)
@@ -704,26 +712,29 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
     occParams = pt;
     fileOcc = foccupancy;
     occSiteMultiplicity = siteMult;
-    return getOccupancy();
+    return getOccupancy(true);
   }
   
   @Override
-  public int getOccupancy100(boolean isTemp) {
+  public int getOccupancy100(boolean forVibVis) {
     if (isCommensurate || Float.isNaN(vOcc))
       return Integer.MIN_VALUE;
-    if (!isTemp && !enabled)
-      return (int) (-fileOcc * 100);
-    if (isTemp && modCalc != null) {
-      modCalc.getOccupancy();
-      return modCalc.getOccupancy100(false);
+    if (forVibVis) {
+        if (modCalc != null) {
+          modCalc.getOccupancy(true);
+          return modCalc.getOccupancy100(false);
+        }     
+      } else {
+        if (!enabled)
+          return (int) (-fileOcc * 100);
+      }
+      return (int) (getOccupancy(forVibVis) * 100);
     }
-    return (int) (occValue * 100);
-  }
 
-  private float getOccupancy() {
+  private float getOccupancy(boolean checkCutoff) {
     double occ;
     if (occAbsolute) {
-      // Crenel
+      // Crenel, legendre
       occ = vOcc;
     } else if (occParams == null) {
       // cif Fourier
@@ -739,9 +750,16 @@ public class ModulationSet extends Vibration implements JmolModulationSet {
       // occ_site * (occ_0 + SUM)
       occ = occParams[0] * (occParams[1] + vOcc);
     }
-    // 49/50 is an important range for cutoffs -- we never return a value in this range
-    occ = (occ > 0.49 && occ < 0.50 ? 0.489 : Math.min(1, Math.max(0, occ)));
-    return occValue = (float) occ;
+    if (checkCutoff) {
+        // only for visualization purposes, from ShapeManager
+        // and possibly for commensurate?
+        // never for crenel
+        // 49/50 is an important range for cutoffs -- no return in this range?
+        // this seems rather arbitrary??
+        // disabled for double presision
+        //occ = (occ > 0.49 && occ < 0.50 ? 0.489 : Math.min(1, Math.max(0, occ)));
+      }
+      return occValue = (float) occ;
   }
 
 
