@@ -24,8 +24,6 @@
 
 package org.jmol.util;
 
-import org.jmol.api.SymmetryInterface;
-
 import javajs.util.AU;
 import javajs.util.M4;
 import javajs.util.P3;
@@ -444,73 +442,6 @@ public class SimpleUnitCell {
     return Float.NaN;
   }
 
-  /**
-   * Expanded cell notation:
-   * 
-   * 111 - 1000 --> center 5,5,5; range 0 to 9 or -5 to +4
-   * 
-   * 1000000 - 1999999 --> center 50,50,50; range 0 to 99 or -50 to +49
-   * 1000000000 - 1999999999 --> center 500, 500, 500; range 0 to 999 or -500 to
-   * +499
-   * 
-   * @param nnn
-   * @param cell
-   * @param offset
-   *        0 or 1 typically; < 0 means "apply no offset"
-   * @param kcode
-   *        Generally the multiplier is just {ijk ijk scale}, but when we have
-   *        1iiijjjkkk 1iiijjjkkk scale, floats lose kkk due to Java float
-   *        precision issues so we use P4 {1iiijjjkkk 1iiijjjkkk scale,
-   *        1kkkkkk}. Here, our offset -- initially 0 or 1 from the uccage
-   *        renderer, but later -500 or -499 -- tells us which code we are
-   *        looking at, the first one or the second one.
-   * 
-   */
-  public static void ijkToPoint3f(int nnn, P3 cell, int offset, int kcode) {
-    int f = (nnn > 1000000000 ? 1000 : nnn > 1000000 ? 100 : 10);
-    int f2 = f * f;
-    offset -= (offset >= 0 ? 5 * f / 10 : offset);
-    cell.x = ((nnn / f2) % f) + offset;
-    cell.y = (nnn % f2) / f + offset;
-    cell.z = (kcode == 0 ? nnn % f 
-        : (offset == -500 ? kcode / f : kcode) % f) + offset;
-  }
-  
-
-  /**
-   * Convert user's {3 2 1} to {1500500500, 1503502501, 0 or 1, 1500501}
-   * @param pt
-   * @param scale 1 for block of unit cells; 0 for one large supercell
-   * @return converted P4
-   */
-  public static P4 ptToIJK(T3 pt, int scale) {
-    if (pt.x <= 5 && pt.y <= 5 && pt.z <= 5) {
-      return P4.new4(555, (pt.x + 4) * 100 + (pt.y + 4) * 10 + pt.z + 4, scale, 0);
-    } 
-    int i555 = 1500500500;
-    return P4.new4(i555, i555 + pt.x*1000000 + pt.y * 1000 + pt.z, scale, 1500500 + pt.z);
-  }
-
-  /**
-   * Generally the multiplier is just {ijk ijk scale}, but when we have
-   * 1iiijjjkkk 1iiijjjkkk scale, floats lose kkk due to Java float precision
-   * issues so we use P4 {1iiijjjkkk 1iiijjjkkk scale, 1kkkkkk}
-   * 
-   * @param pt
-   * @return String representation for state
-   */
-  public static String escapeMultiplier(T3 pt) {
-    if (pt instanceof P4) {
-      P4 pt4 = (P4) pt;
-      int x = (int) Math.floor(pt4.x / 1000)*1000 
-                  + (int) Math.floor(pt4.w / 1000) - 1000;
-      int y = (int) Math.floor(pt4.y / 1000)*1000 
-          + (int) Math.floor(pt4.w) % 1000;
-      return "{" + x + " " + y + " " + pt.z + "}"; 
-    }
-    return Escape.eP(pt);
-  }
-
   public final static float SLOP = 0.02f;
   private final static float SLOP1 = 1 - SLOP;
 
@@ -587,53 +518,6 @@ public class SimpleUnitCell {
     return ucnew;
   }
 
-  /**
-   * 
-   * @param dimension
-   * @param minXYZ
-   * @param maxXYZ
-   * @param kcode
-   *        Generally the multiplier is just {ijk ijk scale}, but when we have
-   *        1iiijjjkkk 1iiijjjkkk scale, floats lose kkk due to Java float
-   *        precision issues so we use P4 {1iiijjjkkk 1iiijjjkkk scale,
-   *        1kkkkkk}. Here, our offset -- initially 0 or 1 from the uccage
-   *        renderer, but later -500 or -499 -- tells us which code we are
-   *        looking at, the first one or the second one.
-   */
-  public static void setMinMaxLatticeParameters(int dimension, P3i minXYZ, P3i maxXYZ, int kcode) {
-    
-    if (maxXYZ.x <= maxXYZ.y && maxXYZ.y >= 555) {
-      //alternative format for indicating a range of cells:
-      //{111 666}
-      //555 --> {0 0 0}
-      P3 pt = new P3();
-      ijkToPoint3f(maxXYZ.x, pt, 0, kcode);
-      minXYZ.x = (int) pt.x;
-      minXYZ.y = (int) pt.y;
-      minXYZ.z = (int) pt.z;
-      ijkToPoint3f(maxXYZ.y, pt, 1, kcode);
-      //555 --> {1 1 1}
-      maxXYZ.x = (int) pt.x;
-      maxXYZ.y = (int) pt.y;
-      maxXYZ.z = (int) pt.z;
-    }
-    switch (dimension) {
-    case 1: // polymer
-      minXYZ.y = 0;
-      maxXYZ.y = 1;
-      //$FALL-THROUGH$
-    case 2: // slab
-      minXYZ.z = 0;
-      maxXYZ.z = 1;
-    }
-  }
-
-
-  @Override
-  public String toString() {
-    return "[" + a + " " + b + " " + c + " " + alpha + " " + beta + " " + gamma + "]";
-  }
-
   public static void unitizeDim(int dimension, T3 pt) {
     switch (dimension) {
     case 3:
@@ -695,19 +579,154 @@ public class SimpleUnitCell {
    * @param pt 
    * @return true if in [0, 1)
    */
-  public static boolean checkPeriodic(P3 pt) {
-    return (pt.x >= -SLOP2 && pt.x < 1 - SLOP2
-        && pt.y >= -SLOP2 && pt.y < 1 - SLOP2
-        && pt.z >= -SLOP2 && pt.z < 1 - SLOP2
-        );
+  public boolean checkPeriodic(P3 pt) {
+    switch (dimension) {
+    case 3:
+      if (pt.z < -SLOP2 || pt.z > 1 - SLOP2)
+        return false;
+      //$FALL-THROUGH$
+    case 2:
+      if (pt.y < -SLOP2 || pt.y > 1 - SLOP2)
+        return false;
+      //$FALL-THROUGH$
+    case 1:
+    if (pt.x < -SLOP2 || pt.x > 1 - SLOP2)
+      return false;
+    }
+    return true;
   }
 
-  public static boolean checkUnitCell(SymmetryInterface uc, P3 cell, P3 ptTemp) {
-    uc.toFractional(ptTemp, false);
-    // {1 1 1} here is the original cell
-    return (ptTemp.x >= cell.x - 1f - SLOP && ptTemp.x <= cell.x + SLOP
-        && ptTemp.y >= cell.y - 1f - SLOP && ptTemp.y <= cell.y + SLOP
-        && ptTemp.z >= cell.z - 1f - SLOP && ptTemp.z <= cell.z + SLOP);
+  public boolean isWithinUnitCell(double a, double b, double c, P3 pt) {
+    switch (dimension) {
+    case 3:
+      if (pt.z < c - 1d - SLOP || pt.z > c + SLOP)
+        return false;
+      //$FALL-THROUGH$
+    case 2:
+      if (pt.y < b - 1d - SLOP || pt.y > b + SLOP)
+        return false;
+      //$FALL-THROUGH$
+    case 1:
+    if (pt.x < a - 1d - SLOP || pt.x > a + SLOP)
+      return false;
+    }
+    return true;
   }
 
+  ////// lattice methods //////
+  
+  /**
+   * Expanded cell notation:
+   * 
+   * 111 - 1000 --> center 5,5,5; range 0 to 9 or -5 to +4
+   * 
+   * 1000000 - 1999999 --> center 50,50,50; range 0 to 99 or -50 to +49
+   * 1000000000 - 1999999999 --> center 500, 500, 500; range 0 to 999 or -500 to
+   * +499
+   * 
+   * @param nnn
+   * @param cell
+   * @param offset
+   *        0 or 1 typically; < 0 means "apply no offset"
+   * @param kcode
+   *        Generally the multiplier is just {ijk ijk scale}, but when we have
+   *        1iiijjjkkk 1iiijjjkkk scale, floats lose kkk due to Java float
+   *        precision issues so we use P4 {1iiijjjkkk 1iiijjjkkk scale,
+   *        1kkkkkk}. Here, our offset -- initially 0 or 1 from the uccage
+   *        renderer, but later -500 or -499 -- tells us which code we are
+   *        looking at, the first one or the second one.
+   * 
+   */
+  public static void ijkToPoint3f(int nnn, P3 cell, int offset, int kcode) {
+    int f = (nnn > 1000000000 ? 1000 : nnn > 1000000 ? 100 : 10);
+    int f2 = f * f;
+    offset -= (offset >= 0 ? 5 * f / 10 : offset);
+    cell.x = ((nnn / f2) % f) + offset;
+    cell.y = (nnn % f2) / f + offset;
+    cell.z = (kcode == 0 ? nnn % f 
+        : (offset == -500 ? kcode / f : kcode) % f) + offset;
+  }
+  
+
+  /**
+   * Convert user's {3 2 1} to {1500500500, 1503502501, 0 or 1, 1500501}
+   * @param pt
+   * @param scale 1 for block of unit cells; 0 for one large supercell
+   * @return converted P4
+   */
+  public static P4 ptToIJK(T3 pt, int scale) {
+    if (pt.x <= 5 && pt.y <= 5 && pt.z <= 5) {
+      return P4.new4(555, (pt.x + 4) * 100 + (pt.y + 4) * 10 + pt.z + 4, scale, 0);
+    } 
+    int i555 = 1500500500;
+    return P4.new4(i555, i555 + pt.x*1000000 + pt.y * 1000 + pt.z, scale, 1500500 + pt.z);
+  }
+
+  /**
+   * Generally the multiplier is just {ijk ijk scale}, but when we have
+   * 1iiijjjkkk 1iiijjjkkk scale, floats lose kkk due to Java float precision
+   * issues so we use P4 {1iiijjjkkk 1iiijjjkkk scale, 1kkkkkk}
+   * 
+   * @param pt
+   * @return String representation for state
+   */
+  public static String escapeMultiplier(T3 pt) {
+    if (pt instanceof P4) {
+      P4 pt4 = (P4) pt;
+      int x = (int) Math.floor(pt4.x / 1000)*1000 
+                  + (int) Math.floor(pt4.w / 1000) - 1000;
+      int y = (int) Math.floor(pt4.y / 1000)*1000 
+          + (int) Math.floor(pt4.w) % 1000;
+      return "{" + x + " " + y + " " + pt.z + "}"; 
+    }
+    return Escape.eP(pt);
+  }
+
+  /**
+   * 
+   * @param dimension
+   * @param minXYZ
+   * @param maxXYZ
+   * @param kcode
+   *        Generally the multiplier is just {ijk ijk scale}, but when we have
+   *        1iiijjjkkk 1iiijjjkkk scale, floats lose kkk due to Java float
+   *        precision issues so we use P4 {1iiijjjkkk 1iiijjjkkk scale,
+   *        1kkkkkk}. Here, our offset -- initially 0 or 1 from the uccage
+   *        renderer, but later -500 or -499 -- tells us which code we are
+   *        looking at, the first one or the second one.
+   */
+  public static void setMinMaxLatticeParameters(int dimension, P3i minXYZ, P3i maxXYZ, int kcode) {
+    
+    if (maxXYZ.x <= maxXYZ.y && maxXYZ.y >= 555) {
+      //alternative format for indicating a range of cells:
+      //{111 666}
+      //555 --> {0 0 0}
+      P3 pt = new P3();
+      ijkToPoint3f(maxXYZ.x, pt, 0, kcode);
+      minXYZ.x = (int) pt.x;
+      minXYZ.y = (int) pt.y;
+      minXYZ.z = (int) pt.z;
+      ijkToPoint3f(maxXYZ.y, pt, 1, kcode);
+      //555 --> {1 1 1}
+      maxXYZ.x = (int) pt.x;
+      maxXYZ.y = (int) pt.y;
+      maxXYZ.z = (int) pt.z;
+    }
+    switch (dimension) {
+    case 1: // polymer
+      minXYZ.y = 0;
+      maxXYZ.y = 1;
+      //$FALL-THROUGH$
+    case 2: // slab
+      minXYZ.z = 0;
+      maxXYZ.z = 1;
+    }
+  }
+  
+  
+  @Override
+  public String toString() {
+    return "[" + a + " " + b + " " + c + " " + alpha + " " + beta + " " + gamma + "]";
+  }
+  
 }
