@@ -81,7 +81,18 @@ public class ActionManager implements EventManager {
     dragGesture = new Gesture(20, vwr);
   }
 
-  protected Thread hoverWatcherThread;
+  /**
+   * This value is set if a mouse move has been detected.
+   * 
+   */
+
+  private boolean hoverable;
+  
+  public boolean isHoverable() {
+    return hoverable;
+  }
+
+    protected Thread hoverWatcherThread;
 
   public void checkHover() {
     if (zoomTrigger) {
@@ -498,10 +509,12 @@ public class ActionManager implements EventManager {
       vwr.setStringProperty("pickingStyle", "toggle");
       vwr.setBooleanProperty("bondPicking", false);
       break;
-    case PICKING_IDENTIFY_BOND:
     case PICKING_ROTATE_BOND:
     case PICKING_ASSIGN_BOND:
     case PICKING_DELETE_BOND:
+      vwr.getModelkit(false);
+      //$FALL-THROUGH$
+    case PICKING_IDENTIFY_BOND:
       vwr.setBooleanProperty("bondPicking", true);
       bondPickingMode = pickingMode;
 //      return;
@@ -533,12 +546,12 @@ public class ActionManager implements EventManager {
     String script = ";set modelkitMode " + vwr.getBoolean(T.modelkitmode)
         + ";set picking " + getPickingModeName(apm);
     if (apm == PICKING_ASSIGN_ATOM)
-      script += "_" + vwr.getModelkitProperty("atomType");
+      script += "_" + vwr.getModelkitPropertySafely("atomType");
     script += ";";
     if (bondPickingMode != PICKING_OFF)
       script += "set picking " + getPickingModeName(bondPickingMode);
     if (bondPickingMode == PICKING_ASSIGN_BOND)
-      script += "_" + vwr.getModelkitProperty("bondType");
+      script += "_" + vwr.getModelkitPropertySafely("bondType");
     script += ";";
     return script;
   }
@@ -617,9 +630,6 @@ public class ActionManager implements EventManager {
   private final MouseState pressed = new MouseState("pressed");
   private final MouseState dragged = new MouseState("dragged");
 
-  boolean isDraggedIsShiftDown() {
-    return (dragged.modifiers & Binding.SHIFT) != 0;
-  }
   protected void setCurrent(long time, int x, int y, int mods) {
     vwr.hoverOff();
     current.set(time, x, y, mods);
@@ -730,7 +740,6 @@ public class ActionManager implements EventManager {
     startHoverWatcher(false);
     if (predragBinding != null)
       b = predragBinding;
-    vwr.setPickingMode(null, PICKING_IDENTIFY);
     vwr.setPickingStyle(null, rootPickingStyle);
     isAltKeyReleased = true;
   }
@@ -790,6 +799,7 @@ public class ActionManager implements EventManager {
       moved.modifiers |= Binding.ALT;
       break;
     case Event.VK_SHIFT:
+      moved.keybuf = 0;
       dragged.modifiers |= Binding.SHIFT;
       moved.modifiers |= Binding.SHIFT;
       break;
@@ -839,19 +849,28 @@ public class ActionManager implements EventManager {
       moved.modifiers &= ~Binding.ALT;
       if (dragSelectedMode)
         vwr.moveSelected(Integer.MAX_VALUE, 0, Integer.MIN_VALUE,
-            Integer.MIN_VALUE, Integer.MIN_VALUE, null, false, false, moved.modifiers);
+            Integer.MIN_VALUE, Integer.MIN_VALUE, null, false, false,
+            moved.modifiers);
       isAltKeyReleased = true;
       break;
     case Event.VK_SHIFT:
       moved.modifiers &= ~Binding.SHIFT;
+      if (moved.keybuf > 0 && vwr.isModelKitOpen())
+        checkKeyBuf(0);
       break;
     case Event.VK_CONTROL:
       moved.modifiers &= ~Binding.CTRL;
     }
     if (moved.modifiers == 0)
       vwr.setCursor(GenericPlatform.CURSOR_DEFAULT);
-    if (!vwr.getBoolean(T.navigationmode))
+    if (key >= 65 && vwr.isModelKitOpen()) {
+      dragAtomIndex = vwr.findNearestAtomIndex(current.x, current.y);
+      if (dragAtomIndex >= 0) {
+        checkKeyBuf(key);
       return;
+      }
+    }
+    if (vwr.getBoolean(T.navigationmode)) {
     //if (vwr.getBooleanProperty("showKeyStrokes", false))
     //vwr.evalStringQuiet("!set echo bottom left;echo;");
     switch (key) {
@@ -863,6 +882,27 @@ public class ActionManager implements EventManager {
       break;
     }
   }
+    moved.keybuf = 0;
+  }
+
+  private void checkKeyBuf(int key) {
+    boolean shiftDown = ((moved.modifiers & Binding.SHIFT) != 0);
+    if (key != 0) {
+      if (moved.keybuf == 0) {
+        // N (continue) or n (assign)
+        moved.keybuf = key;
+        if (shiftDown)
+          return;
+      } else {
+        // NI as <I><N>
+        moved.keybuf += (key << 8);
+      }
+    }
+    if (moved.keybuf > 0) {
+      assignNew(moved.keybuf);
+      moved.keybuf = 0;
+    }
+  }
 
   @Override
   public void mouseEnterExit(long time, int x, int y, boolean isExit) {
@@ -906,8 +946,13 @@ public class ActionManager implements EventManager {
       x = x << 1;
     switch (mode) {
     case Event.MOVED:
+      if (!hoverable) {
+        Logger.info("ActionManager: mouse move detected");
+        hoverable = true;
+      }
       setCurrent(time, x, y, buttonMods);
       moved.setCurrent(current, 0);
+      moved.keybuf = 0;
       if (mp != null || hoverActive) {
         clickAction = Binding.getMouseAction(clickedCount, buttonMods,
             Event.MOVED);
@@ -1028,20 +1073,23 @@ public class ActionManager implements EventManager {
     case PICKING_DRAG_MINIMIZE_MOLECULE:
       isBound = bnd(dragAction, ACTION_dragMinimize, ACTION_dragZ, ACTION_rotateSelected);
       break;
+    default:
+      isBound = (bondPickingMode == PICKING_ROTATE_BOND);
+      break;
     }
     if (isBound) {
       dragAtomIndex = vwr.findNearestAtomIndexMovable(x, y, true);
-      if (dragAtomIndex >= 0
-          && (apm == PICKING_ASSIGN_ATOM || apm == PICKING_INVERT_STEREO)
-//          && vwr.ms.isAtomInLastModel(dragAtomIndex)
-          ) {
-        if (bondPickingMode == PICKING_ROTATE_BOND) {          
-          vwr.setModelkitProperty("bondAtomIndex", Integer.valueOf(dragAtomIndex));
-        }
+      int bi = (bondPickingMode == PICKING_ROTATE_BOND ? vwr.getModelkit(false).getRotateBondIndex()
+          : -1);
+     if (dragAtomIndex >= 0
+          && (bi >= 0 || apm == PICKING_ASSIGN_ATOM || apm == PICKING_INVERT_STEREO)) {
         enterMeasurementMode(dragAtomIndex);
         mp.addPoint(dragAtomIndex, null, false);
+        if (bi >= 0) {
+          updateModelkitBranch(bi, true);
+        }
       }
-      int[] xy = (int[]) vwr.getModelkitProperty("screenXY");
+      int[] xy = (int[]) vwr.getModelkitPropertySafely("screenXY");
         mkBondPressed = (xy != null && pressed.inRange(10, xy[0], xy[1]));
         
       return;
@@ -1084,18 +1132,13 @@ public class ActionManager implements EventManager {
 
     if (checkUserAction(dragWheelAction, x, y, deltaX, deltaY, time, mode))
       return;
-    int bi = (vwr.g.modelKitMode ? vwr.getModelkit(false).getRotateBondIndex()
+    int bi = (bondPickingMode == PICKING_ROTATE_BOND ? vwr.getModelkit(false).getRotateBondIndex()
         : -1);
     if (bi >= 0) {
       if (dragAtomIndex >= 0 || mkBondPressed
           || bnd(dragWheelAction, ACTION_rotateBranch)) {
         if (dragAtomIndex >= 0) {
-          if (measurementQueued == null || measurementQueued.numSet == 0) {
-            vwr.setPendingMeasurement(vwr.getModelkit(false).setBondMeasure(bi,
-                measurementQueued = mp = getMP()));
-          } else {
-            measurementQueued.refresh(null);
-          }
+          updateModelkitBranch(bi, false);
         }
         vwr.moveSelected(deltaX, deltaY, Integer.MIN_VALUE, x, y, null, false,
             false, dragAtomIndex >= 0 ? 0 : Event.VK_SHIFT);
@@ -1255,6 +1298,16 @@ public class ActionManager implements EventManager {
     }
   }
 
+  private void updateModelkitBranch(int bondIndex, boolean isClick) {
+    vwr.setModelkitPropertySafely(isClick? "branchAtomClicked" : "branchAtomDragged", Integer.valueOf(dragAtomIndex));
+    if (measurementQueued == null || measurementQueued.numSet == 0 || mp == null) {
+      vwr.setPendingMeasurement(vwr.getModelkit(false).setBondMeasure(bondIndex,
+          measurementQueued = mp = getMP()));
+    } else {
+      measurementQueued.refresh(null);
+    }
+  }
+
   /**
    * change actual coordinates of selected atoms from set dragSeleted TRUE or
    * set PICKING DRAGSELECTED
@@ -1312,7 +1365,7 @@ public class ActionManager implements EventManager {
     // necessary for reactivating
 //    if (dragRelease)
 //      vwr.setModelKitRotateBondIndex(Integer.MIN_VALUE);
-    if (dragAtomIndex >= 0) {
+    if (dragAtomIndex >= 0 && !vwr.isModelkitPickingRotateBond()) {
       if (apm == PICKING_DRAG_MINIMIZE
           || apm == PICKING_DRAG_MINIMIZE_MOLECULE)
         minimize(true);
@@ -1323,11 +1376,11 @@ public class ActionManager implements EventManager {
         exitMeasurementMode(null);
         return;
       } else if (bondPickingMode == PICKING_ROTATE_BOND) {
-        vwr.setModelkitProperty("bondAtomIndex", Integer.valueOf(dragAtomIndex));
+        vwr.setModelkitPropertySafely("bondAtomIndex", Integer.valueOf(dragAtomIndex));
         exitMeasurementMode(null);
         return;
       }
-      assignNew();
+      assignNew(-1);
       return;
     }
     dragAtomIndex = -1;
@@ -1405,6 +1458,9 @@ public class ActionManager implements EventManager {
         isBond = "bond".equals(map.get("type"));
         isIsosurface = "isosurface".equals(map.get("type"));
         nearestPoint = getPoint(map);
+        if (isBond && vwr.isModelkitPickingRotateBond()) {
+          vwr.highlightBond(((Integer) map.get("index")).intValue(), -1, x, y);          
+        }
       }
     }
     if (isBond)
@@ -1418,13 +1474,19 @@ public class ActionManager implements EventManager {
       doPopup(x, y);
       return;
     }
-    if (clickedCount == 0 && apm != PICKING_ASSIGN_ATOM) {
+    if (clickedCount == 0 && apm != PICKING_ASSIGN_ATOM && !vwr.isModelkitPickingRotateBond()) {
       // mouse move
       if (mp == null)
         return;
       if (nearestPoint != null
-          || mp.getIndexOf(nearestAtomIndex) == 0)
-        mp.addPoint(nearestAtomIndex, nearestPoint, false);
+          || mp.getIndexOf(nearestAtomIndex) == 0) {
+        try {
+          mp.addPoint(nearestAtomIndex, nearestPoint, false);
+        } catch (Exception e) {
+          exitMeasurementMode(null);
+          return;
+        }
+      }
       if (mp.haveModified)
         vwr.setPendingMeasurement(mp);
       vwr.refresh(Viewer.REFRESH_SYNC_MASK, "measurementPending");
@@ -1452,6 +1514,7 @@ public class ActionManager implements EventManager {
           || bondPickingMode == PICKING_ASSIGN_BOND ? ACTION_assignNew
           : ACTION_deleteBond)) {
         bondPicked(((Integer) map.get("index")).intValue());
+        vwr.refresh(Viewer.REFRESH_REPAINT, "bondpicked");
         return;
       }
     } else if (isIsosurface) {
@@ -1712,7 +1775,7 @@ public class ActionManager implements EventManager {
     measurementQueued = getMP();
   }
 
-  void exitMeasurementMode(String refreshWhy) {
+  public void exitMeasurementMode(String refreshWhy) {
     if (mp == null)
       return;
     vwr.setPendingMeasurement(mp = null);
@@ -1949,21 +2012,24 @@ public class ActionManager implements EventManager {
     vwr.setStatusAtomPicked(atomIndex, null, null, false);
   }
 
-  private void assignNew() {
-    if (!vwr.getModelkit(false).handleAssignNew(pressed, dragged, mp, dragAtomIndex)) {
+  private void assignNew(int key) {
+    if (key < 0) {
+      if (!vwr.getModelkit(false).handleAssignNew(pressed, dragged, mp,
+          dragAtomIndex, key)) {
       exitMeasurementMode("bond dropped");      
     }
+    } else {
+      vwr.getModelkit(false).handleAssignNew(current, current, null, dragAtomIndex,
+          key);
+    }
     exitMeasurementMode(null);
   }
 
   private void bondPicked(int index) {    
-    if (bondPickingMode == PICKING_ASSIGN_BOND) {
-      vwr.undoMoveActionClear(-1, T.save, true);
-    }
-    
     switch (bondPickingMode) {
     case PICKING_ASSIGN_BOND:
-      vwr.setModelkitProperty("scriptAssignBond", Integer.valueOf(index));
+      vwr.undoMoveActionClear(-1, T.save, true);
+      vwr.setModelkitPropertySafely("scriptAssignBond", Integer.valueOf(index));
       break;
     case PICKING_ROTATE_BOND:
       // done separately
