@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-04-21 15:54:36 -0500 (Thu, 21 Apr 2022) $
- * $Revision: 22404 $
+ * $Date: 2023-01-05 08:42:06 -0600 (Thu, 05 Jan 2023) $
+ * $Revision: 22500 $
  *
  * Copyright (C) 2003-2005  Miguel, Jmol Development Team
  *  
@@ -410,6 +410,7 @@ public class FileManager implements BytePoster {
     BufferedInputStream bis = null;
     Object ret = null;
     String errorMessage = null;
+    allowCached = allowCached || name.startsWith("cache://");
     byte[] cacheBytes = (allowCached && outputBytes == null ? cacheBytes = getPngjOrDroppedBytes(
         fullName, name) : null);
     try {
@@ -658,13 +659,7 @@ public class FileManager implements BytePoster {
       // if we have a subFileList, we don't want to return the stream for the zip file itself
       else if (Rdr.isBZip2S(bis))
         bis = Rdr.getUnzippedInputStreamBZip2(vwr.getJzt(), bis);
-      // if we have a subFileList, we don't want to return the stream for the zip file itself
-      if (Rdr.isTar(bis)) {
-        Object o = vwr.getJzt().getZipFileDirectory(bis, subFileList, 1,
-            forceInputStream);
-        return (o instanceof String ? Rdr.getBR((String) o) : o);
-      }
-      
+      // if we have a subFileList, we don't want to return the stream for the zip file itself      
       if (forceInputStream && subFileList == null)
         return bis;
       if (Rdr.isCompoundDocumentS(bis)) {
@@ -679,12 +674,22 @@ public class FileManager implements BytePoster {
       if (Rdr.isMessagePackS(bis) || Rdr.isPickleS(bis))
         return bis;
       bis = Rdr.getPngZipStream(bis, true);
+      Object o = null;
       if (Rdr.isZipS(bis)) {
         if (allowZipStream)
           return vwr.getJzt().newZipInputStream(bis);
-        Object o = vwr.getJzt().getZipFileDirectory(bis, subFileList, 1,
+        o = vwr.getJzt().getZipFileDirectory(bis, subFileList, 1,
             forceInputStream);
-        return (o instanceof String ? Rdr.getBR((String) o) : o);
+      } else if (Rdr.isTar(bis)) {
+         o = vwr.getJzt().getZipFileDirectory(bis, subFileList, 1,
+                  forceInputStream);
+      } else if (Rdr.isBinary(bis, 16)) {
+        return bis;
+      }
+      if (o != null) {
+        if (!(o instanceof BufferedInputStream))
+          return (o instanceof String ? Rdr.getBR((String) o) : o);
+        bis = Rdr.getUnzippedInputStream(vwr.getJzt(), (BufferedInputStream) o);
       }
       return (forceInputStream ? bis : Rdr.getBufferedReader(bis, null));
     } catch (Exception ioe) {
@@ -746,35 +751,54 @@ public class FileManager implements BytePoster {
     return ((byte[]) bytes).length + " bytes";
   }
 
-  public Map<String, Object> getFileAsMap(String name, String type) {
-    Map<String, Object> bdata = new Hashtable<String, Object>();
+  /**
+   * create a PNG or ZIP file and return it as a map or, optionally, as a byte[]
+   * @param name
+   * @param type
+   * @param asBytes true to return byte[] instead of a map
+   * @return Map or byte[]
+   */
+  public Object getFileAsMap(String name, String type, boolean asBytes) {
+    Map<String, Object> bdata = (asBytes ? null : new Hashtable<String, Object>());
     Object t;
     if (name == null) {
-      // return the current state as a PNGJ or ZIPDATA
+      // return the current state as a PNGJ or ZIPDATA from write() command
       String[] errMsg = new String[1];
       byte[] bytes = vwr.getImageAsBytes(type, -1, -1, -1, errMsg);
       if (errMsg[0] != null) {
+        if (asBytes)
+          return new byte[0];
         bdata.put("_ERROR_", errMsg[0]);
         return bdata;
       }
+      if (bdata == null)
+        return bytes;
       t = Rdr.getBIS(bytes);
     } else {
       String[] data = new String[2];
       t = getFullPathNameOrError(name, true, data);
       if (t instanceof String) {
+        if (asBytes)
+          return new byte[0];
         bdata.put("_ERROR_", t);
         return bdata;
       }
       if (!checkSecurity(data[0])) {
+        if (asBytes)
+          return new byte[0];
         bdata.put("_ERROR_", "java.io. Security exception: cannot read file "
             + data[0]);
         return bdata;
       }
     }
     try {
-      vwr.getJzt().readFileAsMap((BufferedInputStream) t, bdata, name);
-      
+      if (asBytes) {
+        return Rdr.streamToBytes((BufferedInputStream) t);
+      }
+      vwr.getJzt().readFileAsMap((BufferedInputStream) t, bdata, name);      
     } catch (Exception e) {
+      if (asBytes)
+        return new byte[0];
       bdata.clear();
       bdata.put("_ERROR_", "" + e);
     }
@@ -1259,7 +1283,8 @@ public class FileManager implements BytePoster {
       return "Obj";
     if (line.indexOf("# object with") == 0)
       return "Nff";
-    if (line.indexOf("BEGIN_DATAGRID_3D") >= 0
+    if (line.indexOf("PRIMVEC") >= 0 // only problem here is that the file may not actually have any 3D data
+        || line.indexOf("BEGIN_DATAGRID_3D") >= 0
         || line.indexOf("BEGIN_BANDGRID_3D") >= 0)
       return "Xsf";
     if (line.indexOf("tiles in x, y") >= 0)
