@@ -983,7 +983,7 @@ public class GlobalSettings {
       //    more settable Jmol variables    
       + ";ambient;bonds;colorrasmol;diffuse;fractionalrelative;frank;hetero;hidenotselected"
       + ";hoverlabel;hydrogen;languagetranslation;measurementunits;navigationdepth;navigationslab"
-      + ";picking;pickingstyle;propertycolorschemeoverload;radius;rgbblue;rgbgreen;rgbred"
+      + ";picking;pickingstyle;propertycolorscheme;radius;rgbblue;rgbgreen;rgbred"
       + ";scaleangstromsperinch;selectionhalos;showscript;showselections;solvent;strandcount"
       + ";spinx;spiny;spinz;spinfps;navx;navy;navz;navfps;"
       + CBK.getNameList()
@@ -993,7 +993,9 @@ public class GlobalSettings {
       + ";dodrop;hovered;historylevel;imagestate;iskiosk;useminimizationthread"
       + ";checkcir;resolverresolver;showkeystrokes;saveproteinstructurestate;testflag1;testflag2;testflag3;testflag4"
       // removed in Jmol 14.29.18
-      + ";selecthetero;selecthydrogen;"
+      + ";selecthetero;selecthydrogen"
+      // removed in Jmol 14.32.68
+      + ";pointgrouplineartolerance;pointgroupdistancetolerance"//;pointgroupmmaxatoms"
       
       + ";")
       .toLowerCase();
