@@ -32,7 +32,7 @@ public abstract class JmolStateCreator {
   abstract void getAtomicPropertyStateBuffer(SB commands, int type,
                                     BS bs, String name, float[] data);
 
-  abstract void undoMoveAction(int action, int n);
+  abstract int undoMoveAction(int action, int n);
 
   abstract void undoMoveActionClear(int taintedAtom, int type, boolean clearRedo);
 
