@@ -377,8 +377,7 @@ abstract class OutputManager {
       {
         pixels = new int[width * height];
       }
-      pixels = vwr.apiPlatform.grabPixels(objImage, width, height, pixels, 0,
-          height);
+      pixels = vwr.apiPlatform.grabPixels(objImage, width, height, pixels);
     }
     return pixels;
   }
