@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2022-04-26 15:39:07 -0500 (Tue, 26 Apr 2022) $
- * $Revision: 22406 $
+ * $Date: 2023-01-05 08:42:06 -0600 (Thu, 05 Jan 2023) $
+ * $Revision: 22500 $
  *
  * Copyright (C) 2003-2005  The Jmol Development Team
  *
@@ -24,7 +24,6 @@
 package org.jmol.viewer;
 
 import java.util.Arrays;
-import java.util.Calendar;
 import java.util.Enumeration;
 import java.util.Hashtable;
 import java.util.Map;
@@ -566,8 +565,55 @@ public class PropertyManager implements JmolPropertyManager {
             for (int i = tokens.length; --i >= 0;)
               getMapSubset(h, tokens[i], mapNew, asArray ? v2 : null);
           } else {
-            for (int i = 0; i < keys.size(); i++)
-              getMapSubset(h, keys.get(i), mapNew, asArray ? v2 : null);
+            //ignore ignore use select("[x,y]"...)
+            //boolean doGroup = (wasV2 && asArray && keys.size() > 1);
+            //int v2len00 = (asArray ? v2.size() : 0);
+            for (int i = 0; i < keys.size(); i++) {
+              key = keys.get(i);
+              String index = null;
+              int pta = key.indexOf('[');
+              if (pta > 0 && key.endsWith("]")) {
+                index = key.substring(pta + 1, key.length() - 1);
+                key = key.substring(0, pta);
+                index = PT.trim(index,  "'\"");
+              } else if ((pta = key.indexOf(".")) >= 0) {
+                index = key.substring(pta + 1);
+                key = key.substring(0, pta);                
+              }
+              int v2len0 = v2.size();
+              getMapSubset(h, key, mapNew, asArray ? v2 : null);
+              if (index != null) {
+                for (int j = v2.size(); --j >= v2len0;) {
+                  Object v = v2.get(j);
+                  if (v instanceof SV) {
+                    SV sv = (SV) v;
+                    Map<String, SV> m = sv.getMap();
+                    if (m != null) {
+                      v = m.get(index);
+                    } else {
+                      int p = PT.parseInt(index);
+                      Lst<SV> l = sv.getList();
+                      if (p >= 0 && p < l.size())
+                        v = l.get(p);
+                      else
+                        v = null;
+                    }
+                    if (v == null)
+                      v2.remove(j);
+                    else
+                      v2.set(j, v);
+                  }
+                }
+              }
+            }
+// this is what select("[x,y]...") is for
+//            int n = v2.size();
+//            if (doGroup && n > v2len00) {
+//              Lst<Object> v2a = new Lst<Object>();
+//              for (int p = n - v2len00; --p >= 0;)
+//                v2a.addLast(v2.remove(v2len00));
+//              v2.addLast(SV.getVariableList(v2a));
+//            }
           }
           if (asMap && !wasV2)
             return mapNew;
@@ -674,8 +720,9 @@ public class PropertyManager implements JmolPropertyManager {
           } else {
             // allow for (A*,B) to be same as A*;B
             select += ext;
-            Object[] o = new Object[] { getKeys(select),
-                vwr.compileExpr(key.substring(pt + 6 + ext.length()).trim()) };
+            String exp = key.substring(pt + 6 + ext.length()).trim();
+            T[] list = vwr.compileExpr(exp);
+            Object[] o = new Object[] { getKeys(select), list };
             argsNew[i] = SV.newV(T.select, o);
 
             argsNew[i].index = index;
@@ -787,7 +834,7 @@ public class PropertyManager implements JmolPropertyManager {
     case PROP_UNITCELL_INFO :
       return getUnitCellInfo();
     case PROP_MODELKIT_INFO:
-      return vwr.getModelkitProperty(myParam.toString());
+      return vwr.getModelkitPropertySafely(myParam.toString());
     case PROP_APPLET_INFO:
       return getAppletInfo();
     case PROP_ANIMATION_INFO:
@@ -795,7 +842,7 @@ public class PropertyManager implements JmolPropertyManager {
     case PROP_ATOM_INFO:
       return getAllAtomInfo(vwr.getAtomBitSet(myParam));
     case PROP_AUXILIARY_INFO:
-      return vwr.getAuxiliaryInfoForAtoms(myParam);
+      return vwr.getModelSetAuxiliaryInfoForAtoms(myParam);
     case PROP_BOND_INFO:
       return getAllBondInfo(myParam);
     case PROP_BOUNDBOX_INFO:
@@ -1187,7 +1234,7 @@ public class PropertyManager implements JmolPropertyManager {
 
   /**
    * 
-   * V3000, SDF, MOL, JSON, CD, XYZ, XYZVIB, XYZRN, CML, PDB, PQR, QCJSON, PWMAT, PWSLAB, XSF
+   * V3000, SDF, MOL, JSON, CD (ChemDoodle), XYZ, XYZVIB, XYZRN, CML, PDB, PQR, QCJSON, PWMAT, XSF
    * 
    * MOL67 is MOL with bonds of type 6 or 7 (aromatic single/double)
    * 
@@ -1217,125 +1264,98 @@ public class PropertyManager implements JmolPropertyManager {
     boolean asJSON = uc.equals("JSON") || uc.equals("CD");
     SB mol = new SB();
     ModelSet ms = vwr.ms;
-    BS bsAtoms = BSUtil.copy(bs);
-    BS bsModels = vwr.ms.getModelBS(bsAtoms, true);
-    if (!isXYZ && !asJSON) {
-      String title = vwr.ms.getFrameTitle(bsModels.nextSetBit(0));      
-      title = (title != null ? title.replace('\n',' ') : isModelKit ? "Jmol Model Kit" : FileManager.fixDOSName(vwr.fm.getFullPathName(false)));
-      if (title.length() > 80)
-        title = title.substring(0, 77) + "...";
-      mol.append(title);
-      String version = Viewer.getJmolVersion();
-      mol.append("\n__Jmol-").append(version.substring(0, 2));
-      int cMM, cDD, cYYYY, cHH, cmm;
-      /**
-       * @j2sNative
-       * 
-       *            var c = new Date(); cMM = c.getMonth(); cDD = c.getDate();
-       *            cYYYY = c.getFullYear(); cHH = c.getHours(); cmm =
-       *            c.getMinutes();
-       */
-      {
-        Calendar c = Calendar.getInstance();
-        cMM = c.get(Calendar.MONTH);
-        cDD = c.get(Calendar.DAY_OF_MONTH);
-        cYYYY = c.get(Calendar.YEAR);
-        cHH = c.get(Calendar.HOUR_OF_DAY);
-        cmm = c.get(Calendar.MINUTE);
-      }
-      PT.rightJustify(mol, "_00", "" + (1 + cMM));
-      PT.rightJustify(mol, "00", "" + cDD);
-      mol.append(("" + cYYYY).substring(2, 4));
-      PT.rightJustify(mol, "00", "" + cHH);
-      PT.rightJustify(mol, "00", "" + cmm);
-      mol.append("3D 1   1.00000     0.00000     0");
-      //       This line has the format:
-      //  IIPPPPPPPPMMDDYYHHmmddSSssssssssssEEEEEEEEEEEERRRRRR
-      //  A2<--A8--><---A10-->A2I2<--F10.5-><---F12.5--><-I6->
-      mol.append("\nJmol version ").append(Viewer.getJmolVersion())
-          .append(" EXTRACT: ").append(Escape.eBS(bs)).append("\n");
-    }
+    BS bsModels = vwr.ms.getModelBS(bs, true);
+    int modelIndex = bsModels.nextSetBit(0);
+    boolean is2D = "2D".equals(vwr.ms.am[modelIndex].auxiliaryInfo.get("dimension"));
     Atom[] atoms = ms.at;
+    BS bsAtoms = BSUtil.copy(bs);
     for (int i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1))
       if (doTransform && atoms[i].isDeleted())
         bsAtoms.clear(i);
-    BS bsBonds = getCovalentBondsForAtoms(ms.bo, ms.bondCount, bsAtoms);
     if (!asXYZVIB && bsAtoms.isEmpty())
       return "";
+    BS bsBonds = getCovalentBondsForAtoms(ms.bo, ms.bondCount, bsAtoms);
     boolean isOK = true;
     if (ms.trajectory != null && !allTrajectories)
       ms.trajectory.selectDisplayed(bsModels);
     Quat q = (doTransform ? vwr.tm.getRotationQ() : null);
     if (isXYZ) {
-      LabelToken[] tokensXYZ = LabelToken.compile(vwr,
-          (asXYZRN ? "%-2e _XYZ_ %4.2[vdw] 1 [%n]%r.%a#%i\n" : "%-2e _XYZ_\n"),
-          '\0', null);
-      LabelToken[] tokensVib = (asXYZVIB ? LabelToken.compile(vwr,
-          "%-2e _XYZ_ %12.5vx %12.5vy %12.5vz\n", '\0', null) : null);
-      P3 ptTemp = new P3();
-      for (int i = bsModels.nextSetBit(0); i >= 0; i = bsModels
-          .nextSetBit(i + 1)) {
-        BS bsTemp = BSUtil.copy(bsAtoms);
-        bsTemp.and(ms.getModelAtomBitSetIncludingDeleted(i, false));
-        if (bsTemp.isEmpty())
-          continue;
-        mol.appendI(bsTemp.cardinality()).appendC('\n');
-        Properties props = ms.am[i].properties;
-        mol.append("Model[" + (i + 1) + "]: ");
-        if (ms.frameTitles[i] != null && ms.frameTitles[i].length() > 0) {
-          mol.append(ms.frameTitles[i].replace('\n', ' '));
-        } else if (props == null) {
-          mol.append("Jmol " + Viewer.getJmolVersion());
-        } else {
-          SB sb = new SB();
-          Enumeration<?> e = props.propertyNames();
-          String path = null;
-          while (e.hasMoreElements()) {
-            String propertyName = (String) e.nextElement();
-            if (propertyName.equals(".PATH"))
-              path = props.getProperty(propertyName);
-            else
-              sb.append(";").append(propertyName).append("=")
-                  .append(props.getProperty(propertyName));
-          }
-          if (path != null)
-            sb.append(";PATH=").append(path);
-          path = sb.substring(sb.length() > 0 ? 1 : 0);
-          mol.append(path.replace('\n', ' '));
-        }
-        mol.appendC('\n');
-        Object[] o = new Object[] { ptTemp };
-        for (int j = bsTemp.nextSetBit(0); j >= 0; j = bsTemp.nextSetBit(j + 1)) {
-          String s = LabelToken.formatLabelAtomArray(vwr, atoms[j], (asXYZVIB
-              && ms.getVibration(j, false) != null ? tokensVib : tokensXYZ),
-              '\0', null, ptTemp);
-          ms.getPointTransf(i, atoms[j], q, ptTemp);
-          s = PT.rep(s, "_XYZ_", PT.sprintf("%12.5p %12.5p %12.5p", "p", o));
-          mol.append(s);
-        }
-      }
+      writeXYZ(mol, bsAtoms, bsModels, q, asXYZVIB, asXYZRN);
     } else {
+      String title = vwr.ms.getFrameTitle(bsModels.nextSetBit(0));      
+      title = (title != null ? title.replace('\n',' ') : isModelKit ? "Jmol Model Kit" : FileManager.fixDOSName(vwr.fm.getFullPathName(false)));
       MOLWriter mw = ((MOLWriter) Interface.getInterface("org.jmol.adapter.writers.MOLWriter", vwr, "write")).setViewer(vwr);
       if (asSDF) {
-        String header = mol.toString();
         mol = new SB();
         for (int i = bsModels.nextSetBit(0); i >= 0; i = bsModels
             .nextSetBit(i + 1)) {
-          mol.append(header);
           BS bsTemp = BSUtil.copy(bsAtoms);
           bsTemp.and(ms.getModelAtomBitSetIncludingDeleted(i, false));
           bsBonds = getCovalentBondsForAtoms(ms.bo, ms.bondCount, bsTemp);
-          if (!(isOK = mw.addMolFile(i, mol, bsTemp, bsBonds, false, false, noAromatic, q)))
+          if (!(isOK = mw.addMolFile(title, i, mol, bsTemp, bsBonds, false, false, noAromatic, q, is2D)))
             break;
         }
       } else {
-        isOK = mw.addMolFile(-1, mol, bsAtoms, bsBonds, asV3000, asJSON, noAromatic, q);
+        isOK = mw.addMolFile(title, -1, mol, bsAtoms, bsBonds, asV3000, asJSON, noAromatic, q, is2D);
       }
     } 
     return (isOK ? mol.toString()
         : "ERROR: Too many atoms or bonds -- use V3000 format.");
   }
 
+  private void writeXYZ(SB mol, BS bsAtoms, BS bsModels, Quat q,
+                        boolean asXYZVIB, boolean asXYZRN) {
+    ModelSet ms = vwr.ms;
+    Atom[] atoms = ms.at;
+    LabelToken[] tokensXYZ = LabelToken.compile(vwr,
+        (asXYZRN ? "%-2e _XYZ_ %4.2[vdw] 1 [%n]%r.%a#%i\n" : "%-2e _XYZ_\n"),
+        '\0', null);
+    LabelToken[] tokensVib = (asXYZVIB ? LabelToken.compile(vwr,
+        "%-2e _XYZ_ %12.5vx %12.5vy %12.5vz\n", '\0', null) : null);
+    P3 ptTemp = new P3();
+    for (int i = bsModels.nextSetBit(0); i >= 0; i = bsModels
+        .nextSetBit(i + 1)) {
+      BS bsTemp = BSUtil.copy(bsAtoms);
+      bsTemp.and(ms.getModelAtomBitSetIncludingDeleted(i, false));
+      if (bsTemp.isEmpty())
+        continue;
+      mol.appendI(bsTemp.cardinality()).appendC('\n');
+      Properties props = ms.am[i].properties;
+      mol.append("Model[" + (i + 1) + "]: ");
+      if (ms.frameTitles[i] != null && ms.frameTitles[i].length() > 0) {
+        mol.append(ms.frameTitles[i].replace('\n', ' '));
+      } else if (props == null) {
+        mol.append("Jmol " + Viewer.getJmolVersion());
+      } else {
+        SB sb = new SB();
+        Enumeration<?> e = props.propertyNames();
+        String path = null;
+        while (e.hasMoreElements()) {
+          String propertyName = (String) e.nextElement();
+          if (propertyName.equals(".PATH"))
+            path = props.getProperty(propertyName);
+          else
+            sb.append(";").append(propertyName).append("=")
+                .append(props.getProperty(propertyName));
+        }
+        if (path != null)
+          sb.append(";PATH=").append(path);
+        path = sb.substring(sb.length() > 0 ? 1 : 0);
+        mol.append(path.replace('\n', ' '));
+      }
+      mol.appendC('\n');
+      Object[] o = new Object[] { ptTemp };
+      for (int j = bsTemp.nextSetBit(0); j >= 0; j = bsTemp.nextSetBit(j + 1)) {
+        String s = LabelToken.formatLabelAtomArray(vwr, atoms[j], (asXYZVIB
+            && ms.getVibration(j, false) != null ? tokensVib : tokensXYZ),
+            '\0', null, ptTemp);
+        ms.getPointTransf(i, atoms[j], q, ptTemp);
+        s = PT.rep(s, "_XYZ_", PT.sprintf("%12.5p %12.5p %12.5p", "p", o));
+        mol.append(s);
+      }
+    }
+  }
+
   /**
    * 
    * EXPERIMENTAL
@@ -1345,7 +1365,7 @@ public class PropertyManager implements JmolPropertyManager {
    * @param type 
    * @param bs 
    * @param data to pass to reader
-   * @param out
+   * @param out currently only for PDB case, in which return is ignored
    * @return file data
    */
   private String getModel(String type, BS bs, Object[] data, OC out) {
@@ -1614,6 +1634,7 @@ public class PropertyManager implements JmolPropertyManager {
     info.put("atom1", infoA);
     info.put("atom2", infoB);
     info.put("jmol_order", "0x" + Integer.toHexString(bond.getBondType()));
+    info.put("edge_type", Integer.valueOf(bond.getBondType()));
     info.put("order", Float.valueOf(Edge
         .getBondOrderNumberFromOrder(bond.getBondType())));
     info.put("type", Edge.getBondOrderNameFromOrder(bond.getBondType()));
