@@ -26,33 +26,32 @@ package org.jmol.viewer;
 
 import java.util.Map;
 
-
 import org.jmol.api.Interface;
 import org.jmol.atomdata.RadiusData;
 import org.jmol.c.PAL;
 import org.jmol.c.VDW;
-import javajs.util.BS;
 import org.jmol.modelset.Atom;
 import org.jmol.modelset.Group;
 import org.jmol.modelset.ModelSet;
 import org.jmol.script.T;
 import org.jmol.shape.Shape;
 import org.jmol.util.BSUtil;
-import org.jmol.util.GData;
 import org.jmol.util.Edge;
-
+import org.jmol.util.GData;
 import org.jmol.util.JmolMolecule;
+import org.jmol.util.Vibration;
 
+import javajs.util.BS;
 import javajs.util.M4;
 import javajs.util.P3;
 import javajs.util.P3i;
-import org.jmol.util.Vibration;
 
 public class ShapeManager {
 
   private ModelSet ms;
   public Shape[] shapes;
   public Viewer vwr;
+  private Object scaleText;
 
   public ShapeManager(Viewer vwr) {
     this.vwr = vwr;
@@ -65,7 +64,7 @@ public class ShapeManager {
    * 
    */
   public void setParallel() {
-    resetShapes();
+    resetShapes(false);
     loadDefaultShapes(vwr.ms);
   }
   
@@ -156,9 +155,21 @@ public class ShapeManager {
       shapes[shapeID] = null;  
   }
   
-  public void resetShapes() {
-//    if (!vwr.noGraphicsAllowed)  ?? Why this?? We need shapes!
-      shapes = new Shape[JC.SHAPE_MAX];
+  public void setScale() {
+    if (scaleText != null) {
+      loadShape(JC.SHAPE_ECHO);
+      setShapePropertyBs(JC.SHAPE_ECHO, "%SCALE", scaleText, null);
+      scaleText = null;
+    }
+  }
+
+  public void resetShapes(boolean cacheScale) {
+    if (cacheScale) {
+      Object[] data = new Object[1];
+      getShapePropertyData(JC.SHAPE_ECHO, "%SCALE", data);
+      scaleText = data[0];
+    }
+    shapes = new Shape[JC.SHAPE_MAX];
   }
   
   /**
@@ -383,7 +394,7 @@ public class ShapeManager {
       for (int i = ms.ac; --i >= 0;) {
         Atom atom = atoms[i];
         if (atom != null)
-        atom.shapeVisibilityFlags &= Atom.ATOM_NOFLAGS;
+          atom.shapeVisibilityFlags &= Atom.ATOM_NOFLAGS;
         if (bsDeleted != null && bsDeleted.get(i))
           continue;
         if (bs.get(atom.mi)) {
@@ -432,7 +443,7 @@ public class ShapeManager {
     BS bsOK = bsRenderableAtoms;
     ms.getAtomsInFrame(bsOK);
     Vibration[] vibrationVectors = ms.vibrations;
-    boolean vibs = (vibrationVectors != null && tm.vibrationOn);
+    boolean vibsOn = (vibrationVectors != null && tm.vibrationOn);
     boolean checkOccupancy = (ms.bsModulated != null && ms.occupancies != null);
     Atom[] atoms = ms.at;
     int occ;
@@ -444,7 +455,7 @@ public class ShapeManager {
       // PDB objects such as cartoons and traces, which 
       // use Cartesian coordinates, not screen coordinates
       Atom atom = atoms[i];
-      P3i screen = (vibs && atom.hasVibration() ? tm.transformPtVib(atom,
+      P3i screen = (vibsOn && atom.hasVibration() ? tm.transformPtVib(atom,
           vibrationVectors[i]) : tm.transformPt(atom));
       if (screen.z == 1 && tm.internalSlab && tm.xyzIsSlabbedInternal(atom)) {
         bsSlabbed.set(i);
@@ -458,7 +469,7 @@ public class ShapeManager {
       atom.sD = (short) vwr.tm.scaleToScreen(screen.z, d);
       if (checkOccupancy
           && vibrationVectors[i] != null
-          && (occ = vibrationVectors[i].getOccupancy100(vibs)) != Integer.MIN_VALUE) {
+          && (occ = vibrationVectors[i].getOccupancy100(vibsOn)) != Integer.MIN_VALUE) {
         //System.out.println(atom + " " + occ);
         haveMods = true;
         atom.setShapeVisibility(Atom.ATOM_VISSET, false);
@@ -540,7 +551,7 @@ public class ShapeManager {
   }
 
   public void setModelSet(ModelSet modelSet) {
-    ms = vwr.ms = modelSet;
+    ms = modelSet;
   }
 
   /**
@@ -562,7 +573,7 @@ public class ShapeManager {
       if (bsSubset != null) {
         bsSelected = vwr.slm.getSelectedAtomsNoSubset();
         bsSelected.and(bsSubset);
-        vwr.select(bsSelected, false, 0, true);
+        vwr.selectStatus(bsSelected, false, 0, true, false);
         BSUtil.invertInPlace(bsSelected, vwr.ms.ac);
         bsSelected.and(bsSubset);
       }
@@ -590,7 +601,7 @@ public class ShapeManager {
     setLabel(null, bs);
     if (!isBond)
       vwr.setBooleanProperty("bondModeOr", bondmode);
-    vwr.select(bsSelected, false, 0, true);
+    vwr.selectStatus(bsSelected, false, 0, true, false);
   }
 
 }
