@@ -281,7 +281,7 @@ public class StateCreator extends JmolStateCreator {
             if (bond.atom1.group.isAdded(index))
               index = -1 - index;
             sb.appendI(index).appendC('\t').appendI(bond.atom2.i).appendC('\t')
-                .appendI(bond.order & ~Edge.BOND_NEW).appendC('\t')
+                .appendI(bond.order & Edge.BOND_RENDER_MASK).appendC('\t')
                 .appendF(bond.mad / 1000f).appendC('\t')
                 .appendF(bond.getEnergy()).appendC('\t')
                 .append(Edge.getBondOrderNameFromOrder(bond.order))
@@ -559,7 +559,7 @@ public class StateCreator extends JmolStateCreator {
     int n = 0;
     for (Map.Entry<String, int[]> entry : p.schemes.entrySet()) {
       String name = entry.getKey();
-      if (name.length() > 0 & n++ >= 0)
+      if (name.length() > 0 && !name.startsWith("=") && n++ >= 0)
         s.append("color \"" + name + "="
             + ColorEncoder.getColorSchemeList(entry.getValue()) + "\";\n");
     }
@@ -996,10 +996,14 @@ public class StateCreator extends JmolStateCreator {
         addTickInfo(sb, tickInfo, true);
       for (int j = 1; j <= count; j++)
         sb.append(" ").append(m.getLabel(j, true, true));
-      if (isProperty)
-        sb.append(" " + m.property + " value " + (Float.isNaN(m.value) ? 0f : m.value))
-        .append(" " + PT.esc(m.getString()));
-      //sb.append("; # " + shape.getInfoAsString(i));
+      if (isProperty) {
+        sb.append(" " + m.property + " value " + (Double.isNaN(m.value) ? 0d : m.value))
+         .append(" " + PT.esc(m.getString()));
+      } else if (count == 2) {
+        String s = m.getStrFormatForState();
+        if (s != null)
+          sb.append(" ").append(PT.esc(s));
+      }
       app(commands, sb.toString());
     }
     app(commands, Shape.getFontCommand("measures", font3d));
@@ -1370,44 +1374,43 @@ public class StateCreator extends JmolStateCreator {
         strOff = Escape.eP(t.xyz);
       sb.append("  ").append(echoCmd).append(" ").append(strOff);
       if (t.align != JC.TEXT_ALIGN_LEFT)
-        sb.append(";  ").append(echoCmd).append(" ").append(
-            JC.getHorizAlignmentName(t.align));
+        sb.append(";  ").append(echoCmd).append(" ")
+            .append(JC.getHorizAlignmentName(t.align));
       break;
     default:
       sb.append("  set echo ").append(JC.getEchoName(t.valign)).append(" ")
           .append(JC.getHorizAlignmentName(t.align));
     }
     if (t.movableZPercent != Integer.MAX_VALUE)
-      sb.append(";  ").append(echoCmd).append(" depth ").appendI(
-          t.movableZPercent);
-    if (isImage)
+      sb.append(";  ").append(echoCmd).append(" depth ")
+          .appendI(t.movableZPercent);
+    if (isImage) {
       sb.append("; ").append(echoCmd).append(" IMAGE /*file*/");
-    else
+    } else {
       sb.append("; echo ");
+    }
     sb.append(PT.esc(text)); // was textUnformatted, but that is not really the STATE
     sb.append(";\n");
     if (isImage && t.imageScale != 1)
       sb.append("  ").append(echoCmd).append(" scale ").appendF(t.imageScale)
           .append(";\n");
     if (t.script != null)
-      sb.append("  ").append(echoCmd).append(" script ").append(
-          PT.esc(t.script)).append(";\n");
+      sb.append("  ").append(echoCmd).append(" script ")
+          .append(PT.esc(t.script)).append(";\n");
     if (t.modelIndex >= 0)
-      sb.append("  ").append(echoCmd).append(" model ").append(
-          vwr.getModelNumberDotted(t.modelIndex)).append(";\n");
+      sb.append("  ").append(echoCmd).append(" model ")
+          .append(vwr.getModelNumberDotted(t.modelIndex)).append(";\n");
     if (t.pointerPt != null) {
-      sb.append("  ").append(echoCmd).append(" point ").append(
-          t.pointerPt instanceof Atom ? "({" + ((Atom) t.pointerPt).i
-              + "})" : Escape.eP(t.pointerPt)).append(";\n");
+      sb.append("  ").append(echoCmd).append(" point ")
+          .append(
+              t.pointerPt instanceof Atom ? "({" + ((Atom) t.pointerPt).i + "})"
+                  : Escape.eP(t.pointerPt))
+          .append(";\n");
     }
     if (t.pymolOffset != null) {
-      sb.append("  ").append(echoCmd).append(" offset ").append(
-          Escape.escapeFloatA(t.pymolOffset, true)).append(";\n");
+      sb.append("  ").append(echoCmd).append(" offset ")
+          .append(Escape.escapeFloatA(t.pymolOffset, true)).append(";\n");
     }
-    if ("%SCALE".equals(text)) {
-      sb.append("  set measurementUnits " + vwr.getDistanceUnits("")).append(";\n");
-    }
-    //    }
     //isDefine and target==top: do all
     //isDefine and target!=top: just start
     //!isDefine and target==top: do nothing
@@ -1429,10 +1432,13 @@ public class StateCreator extends JmolStateCreator {
       sb.append(C.getHexCode(t.bgcolix));
     }
     sb.append(";\n");
-    if (t.hidden)
+    if (t.hidden) {
+      if (isScale)
+        sb.append("  set echo \"%SCALE\" hidden;\n");
+      else
       sb.append("  set echo ID ").append(PT.esc(t.target))
           .append(" hidden;\n");
-    return;
+    }
   }
 
   @Override
