@@ -1,7 +1,7 @@
 /* $RCSfile$
  * $Author: hansonr $
- * $Date: 2019-11-23 22:17:53 -0600 (Sat, 23 Nov 2019) $
- * $Revision: 22005 $
+ * $Date: 2022-03-29 20:48:47 -0500 (Tue, 29 Mar 2022) $
+ * $Revision: 22388 $
  *
  * Copyright (C) 2002-2005  The Jmol Development Team
  *
@@ -50,7 +50,7 @@ import org.jmol.console.KeyJCheckBox;
 import org.jmol.console.KeyJCheckBoxMenuItem;
 import org.jmol.console.KeyJRadioButtonMenuItem;
 import org.jmol.i18n.GT;
-import org.jmol.viewer.JC;
+import org.jmol.viewer.Viewer;
 
 public class GuiMap {
 
@@ -77,11 +77,11 @@ public class GuiMap {
     labels.put("openmol", GT.$("Get &MOL"));
     labels.put("reloadScript", GT.$("&Reload"));
 
-    labels.put("spectrumMenu", "&Spectra");
+    labels.put("spectrumMenu", GT.$("&Spectra"));
 
     labels.put("openJSpecViewScript", "JSpecView");
-    labels.put("simulate1HSpectrumScript", "Simulated 1H Spectrum");
-    labels.put("simulate13CSpectrumScript", "Simulated 13C Spectrum");
+    labels.put("simulate1HSpectrumScript", GT.$("Simulated 1H Spectrum"));
+    labels.put("simulate13CSpectrumScript", GT.$("Simulated 13C Spectrum"));
 
     labels.put("editor", GT.$("Scrip&t Editor...")); // new %t 11.7.45
     labels.put("console", GT.$("Conso&le..."));
@@ -229,6 +229,8 @@ public class GuiMap {
     labels.put("Prefs.perspectiveDepth", GT.$("Perspective Depth"));
     labels.put("Prefs.showAxes", GT.$("Axes"));
     labels.put("Prefs.showBoundingBox", GT.$("Bounding Box"));
+    labels.put("Prefs.measureAngstroms", GT.$("Measurements") + " Angstroms");
+    labels.put("Prefs.antialiasDisplay", "set antialiasDisplay");
     labels.put("Prefs.axesOrientationRasmol",
         GT.$("RasMol/Chime compatible axes orientation/rotations"));
     labels.put("Prefs.openFilePreview",
@@ -308,11 +310,15 @@ public class GuiMap {
   }
 
   public void setSelected(String key, boolean b) {
-    ((AbstractButton) get(key)).setSelected(b);
+    AbstractButton btn = ((AbstractButton) get(key));
+    if (btn != null)
+      btn.setSelected(b);
   }
 
   public void setEnabled(String key, boolean b) {
-    ((AbstractButton) get(key)).setEnabled(b);
+    AbstractButton btn = ((AbstractButton) get(key));
+    if (btn != null)
+      btn.setEnabled(b);
   }
 
   public void updateLabels() {
@@ -455,7 +461,7 @@ public class GuiMap {
         "GT_script_btn_template2.html_MORE",
         GT.escapeHTML(GT.o(GT.$("Insert more information for {0} here."),
             "@NAME@")), "About.html#version",
-        "<p><b>Jmol " + JC.version + " (" + JC.date + ")</b></p>",
+        "<p><b>Jmol " + Viewer.getJmolVersion() + "</b></p>",
         "About.html#splash", "see Jmol-resources.properties",
         "About.html#weblinks", "see Jmol-resources.properties",
         "About.html#libraries", "see Jmol-resources.properties" };
