@@ -108,7 +108,6 @@ import org.openscience.jmol.app.surfacetool.SurfaceTool;
 import org.openscience.jmol.app.webexport.WebExport;
 
 import javajs.util.JSJSONParser;
-import javajs.util.P3;
 import javajs.util.PT;
 
 public class JmolPanel extends JPanel
@@ -361,6 +360,10 @@ public class JmolPanel extends JPanel
     display = new DisplayPanel(this);
     vwrOptions.put("display", display);
     JmolStatusListener userStatusListener = (JmolStatusListener) vwrOptions.get("statusListener");
+    if (userStatusListener != null && userStatusListener.getClass() == StatusListener.class) {
+      // don't pass on Jmol's standard listener as user's
+      userStatusListener = null;
+    }
     myStatusListener = new StatusListener(this, display);
     myStatusListener.userStatusListener = userStatusListener;
     vwrOptions.put("statusListener", myStatusListener);
@@ -1950,10 +1953,6 @@ public class JmolPanel extends JPanel
 
   }
 
-  public void syncScript(String script) {
-    vwr.syncScript(script, "~", 0);
-  }
-
   public void updateConsoleFont() {
     AppConsole console = getConsole();
     if (console != null)
@@ -2026,17 +2025,6 @@ public class JmolPanel extends JPanel
 
   }
 
-  final private String TYPES = "reply....." + // 0
-      "quit......" + // 10
-      "command..." + // 20
-      "move......" + // 30
-      "rotate...." + // 40
-      "translate." + // 50
-      "zoom......" + // 60
-      "sync......" + // 70
-      "touch....." + // 80
-      "";
-
   @Override
   public synchronized void processNioMessage(byte[] packet) throws Exception {
     String msg = new String(packet);
@@ -2067,7 +2055,7 @@ public class JmolPanel extends JPanel
     case 80://"touch":
       if (touchHandler == null)
         touchHandler = new TouchHandler();
-      nioSync(json, touchHandler);
+      touchHandler.nioSync(vwr, json);
       break;
     }
   }
@@ -2083,95 +2071,4 @@ public class JmolPanel extends JPanel
     return serverService != null;
   }
 
-  /**
-   * process touch or gesture commands driven by hardware. From
-   * MolecularPlayground.
-   * 
-   * @param json
-   * @param handler
-   * @throws Exception
-   */
-  public void nioSync(Map<String, Object> json, TouchHandler handler)
-      throws Exception {
-    //    "reply....." +  // 0
-    //        "quit......" +  // 10
-    //        "command..." +  // 20
-    //        "move......" +  // 30
-    //        "rotate...." +  // 40
-    //        "translate." +  // 50
-    //        "zoom......" +  // 60
-    //        "sync......" +  // 70
-    //        "touch....." +  // 80
-
-    switch (TYPES.indexOf(JsonNioService.getString(json, "type"))) {
-    case 30://"move":
-      long now = handler.latestMoveTime = System.currentTimeMillis();
-      switch (TYPES.indexOf(JsonNioService.getString(json, "style"))) {
-      case 40://"rotate":
-        float dx = (float) JsonNioService.getDouble(json, "x");
-        float dy = (float) JsonNioService.getDouble(json, "y");
-        float dxdy = dx * dx + dy * dy;
-        boolean isFast = (dxdy > TouchHandler.swipeCutoff);
-        boolean disallowSpinGesture = vwr.getBooleanProperty("isNavigating")
-            || !vwr.getBooleanProperty("allowGestures");
-        if (disallowSpinGesture || isFast
-            || now - handler.swipeStartTime > TouchHandler.swipeDelayMs) {
-          // it's been a while since the last swipe....
-          // ... send rotation in all cases
-          String msg = null;
-          if (disallowSpinGesture) {
-            // just rotate
-          } else if (isFast) {
-            if (++handler.nFast > TouchHandler.swipeCount) {
-              // critical number of fast motions reached
-              // start spinning
-              handler.swipeStartTime = now;
-              msg = "Mouse: spinXYBy " + (int) dx + " " + (int) dy + " "
-                  + (Math.sqrt(dxdy) * TouchHandler.swipeFactor
-                      / (now - handler.previousMoveTime));
-            }
-          } else if (handler.nFast > 0) {
-            // slow movement detected -- turn off spinning
-            // and reset the number of fast actions
-            handler.nFast = 0;
-            msg = "Mouse: spinXYBy 0 0 0";
-          }
-          if (msg == null)
-            msg = "Mouse: rotateXYBy " + dx + " " + dy;
-          syncScript(msg);
-        }
-        handler.previousMoveTime = now;
-        break;
-      case 50://"translate":
-        if (!handler.isPaused)
-          handler.pauseScript(vwr, true);
-        syncScript("Mouse: translateXYBy " + JsonNioService.getString(json, "x")
-            + " " + JsonNioService.getString(json, "y"));
-        break;
-      case 60://"zoom":
-        if (!handler.isPaused)
-          handler.pauseScript(vwr, true);
-        float zoomFactor = (float) (JsonNioService.getDouble(json, "scale")
-            / (vwr.tm.zmPct / 100.0f));
-        syncScript("Mouse: zoomByFactor " + zoomFactor);
-        break;
-      }
-      break;
-    case 70://"sync":
-      //sync -3000;sync slave;sync 3000 '{"type":"sync","sync":"rotateZBy 30"}'
-      syncScript("Mouse: " + JsonNioService.getString(json, "sync"));
-      break;
-    case 80://"touch":
-      // raw touch event
-      vwr.acm.processMultitouchEvent(0,
-          JsonNioService.getInt(json, "eventType"),
-          JsonNioService.getInt(json, "touchID"),
-          JsonNioService.getInt(json, "iData"),
-          P3.new3((float) JsonNioService.getDouble(json, "x"),
-              (float) JsonNioService.getDouble(json, "y"),
-              (float) JsonNioService.getDouble(json, "z")),
-          JsonNioService.getLong(json, "time"));
-      break;
-    }
-  }
 }
