@@ -67,7 +67,9 @@ import org.jmol.api.JmolViewer;
 import org.jmol.awt.FileDropper;
 import org.jmol.awt.Platform;
 import org.jmol.console.JmolConsole;
+import org.jmol.console.ScriptEditor;
 import org.jmol.i18n.GT;
+import org.jmol.script.T;
 import org.jmol.util.CommandHistory;
 import org.jmol.util.Logger;
 import org.jmol.viewer.JC;
@@ -79,6 +81,24 @@ import javajs.util.PT;
 public class AppConsole extends JmolConsole
     implements EnterListener, JmolDropEditor {
 
+  public static final String ALL_BUTTONS = "Editor Variables Clear History State UndoRedo Close Font Help";
+
+  public JDialog jcd;
+  protected ConsoleTextPane console;
+  protected ConsoleDocument consoleDoc;
+
+  private JmolAbstractButton varButton, haltButton, closeButton, clearButton,
+      stepButton;
+  private JmolAbstractButton helpButton, undoButton, redoButton, checkButton,
+      topButton, fontButton;
+  private JPanel buttonPanel = new JPanel();
+
+  protected JScrollBar vBar, hBar;
+
+  private int fontSize;
+  private boolean noPrefs;
+
+
   @Override
   public void loadContent(String script) {
     getScriptEditor().setVisible(true);
@@ -87,14 +107,14 @@ public class AppConsole extends JmolConsole
 
   @Override
   public void loadFile(String fileName) {
+    ScriptEditor se = (ScriptEditor) getScriptEditor();
+    boolean isVisible = se.isVisible();
     getScriptEditor().loadFile(fileName);
-    vwr.openFileAsyncSpecial(fileName, JmolScriptManager.NO_AUTOPLAY | JmolScriptManager.NO_SCRIPT | JmolScriptManager.PDB_CARTOONS);
+    if (!isVisible)
+      se.setVisible(false);    
+    vwr.openFileAsyncSpecial(fileName, JmolScriptManager.NO_AUTOPLAY | JmolScriptManager.SCRIPT_ONLY | JmolScriptManager.PDB_CARTOONS);
   }
 
-  public static final String ALL_BUTTONS = "Editor Variables Clear History State UndoRedo Close Font Help";
-
-  private int fontSize;
-
   // note:  "Check" "Top" "Step" not included in 12.1
 
   public AppConsole() {
@@ -163,26 +183,16 @@ public class AppConsole extends JmolConsole
 
   @Override
   public void updateFontSize() {
-    int scale = (Viewer.isJS ? vwr.getConsoleFontScale()
+    int scale = (Viewer.isJS || noPrefs ? vwr.getConsoleFontScale()
         : PT.parseInt("" + (String) vwr.getProperty("DATA_API", "getPreference",
             "consoleFontScale")));
     scale = (scale < 0 ? 1 : scale) % 5;
     fontSize = scale * 4 + 12;
     if (console != null)
       console.setFont(new Font("dialog", Font.PLAIN, fontSize));
+    vwr.notifyScriptEditor(Integer.MAX_VALUE, new Object[] { Integer.valueOf(fontSize)});
   }
 
-  public JDialog jcd;
-
-  protected ConsoleTextPane console;
-  private JmolAbstractButton varButton, haltButton, closeButton, clearButton,
-      stepButton;
-  private JmolAbstractButton helpButton, undoButton, redoButton, checkButton,
-      topButton, fontButton;
-  private JPanel buttonPanel = new JPanel();
-
-  protected JScrollBar vBar, hBar;
-
   /*
    * methods sendConsoleEcho and sendConsoleMessage(strStatus)
    * are public in case developers want to use appConsole separate from the Jmol application.
@@ -387,16 +397,12 @@ public class AppConsole extends JmolConsole
   void executeCommandAsThread(String strCommand) {
     if (strCommand == null)
       strCommand = console.getCommandString().trim();
-    if (strCommand.equalsIgnoreCase("undo")) {
-      undoRedo(false);
-      console.appendNewline();
-      console.setPrompt();
-      return;
-    } else if (strCommand.equalsIgnoreCase("redo")) {
-      undoRedo(true);
-      console.appendNewline();
-      console.setPrompt();
-      return;
+    boolean isUndo = strCommand.equalsIgnoreCase("undo");
+    if ((isUndo || strCommand.equalsIgnoreCase("redo")) && checkUndoEnabled() != UNDO_USER) {
+        undoRedo(isUndo);
+        console.appendNewline();
+        console.setPrompt();
+        return;
     } else if (strCommand.equalsIgnoreCase("exitJmol")) {
       System.exit(0);
     } else if (strCommand.startsWith("font console")) {
@@ -407,7 +413,7 @@ public class AppConsole extends JmolConsole
       strCommand = " ";
     } else if (strCommand.length() == 0) {
       strCommand = "!resume";
-      undoSetEnabled();
+      checkUndoEnabled();
     }
 
     if (strCommand.length() > 0) {
@@ -435,25 +441,40 @@ public class AppConsole extends JmolConsole
     redoButton.setEnabled(false);
   }
 
-  private boolean undoSetEnabled() {
-    if (undoButton == null)
-      return false;
-    boolean undoAllowed = (vwr.getBooleanProperty("undo")
-        && vwr.getBooleanProperty("preserveState"));
-    undoButton.setEnabled(
-        undoAllowed && undoPointer > 0 && undoStack[undoPointer - 1] != null);
-    redoButton.setEnabled(undoAllowed && undoPointer < MAXUNDO
-        && undoStack[undoPointer + 1] != null);
-    return undoAllowed;
+  final static int UNDO_NONE = 0;
+  final static int UNDO_CONSOLE = 1;
+  final static int UNDO_USER = 2;
+  
+  public int checkUndoEnabled() {
+    boolean undoAllowed = vwr.getBooleanProperty("undoAuto");
+    if (undoAllowed) {
+      if (undoButton == null)
+        return UNDO_NONE;
+      undoAllowed = vwr.getBoolean(T.preservestate);
+      undoButton.setEnabled(
+          undoAllowed && undoPointer > 0 && undoStack[undoPointer - 1] != null);
+      redoButton.setEnabled(undoAllowed && undoPointer < MAXUNDO
+          && undoStack[undoPointer + 1] != null);
+      return UNDO_CONSOLE;
+    }
+    // user has turned the console undo off
+    if (undoButton != null && vwr.stm.getUndoMax() > 0) {
+      undoButton.setEnabled(vwr.stm.canDo(T.undo));
+      redoButton.setEnabled(vwr.stm.canDo(T.redo));
+    }
+    return UNDO_USER;
   }
 
   private void undoRedo(boolean isRedo) {
-    if (undoButton == null)
-      return;
     // pointer is always left at the undo slot when a command is given
     // redo at CURRENT pointer position
-    if (!undoSetEnabled())
+    switch (checkUndoEnabled()) {
+    case UNDO_NONE:
       return;
+    case UNDO_USER:
+      executeCommand(isRedo ? "redo" : "undo");
+      return;
+    }
     //dumpUndo("undoRedo1");
     int ptr = undoPointer + (isRedo ? 1 : -1);
     if (!undoSaved) {
@@ -469,7 +490,7 @@ public class AppConsole extends JmolConsole
       vwr.evalStringQuiet(state);
       undoPointer = ptr;
     }
-    undoSetEnabled();
+    checkUndoEnabled();
     //dumpUndo("undoRedo DONE");
   }
 
@@ -480,8 +501,8 @@ public class AppConsole extends JmolConsole
   private void undoSave(boolean incrementPtr) {
     if (undoButton == null)
       return;
-    if (!vwr.getBooleanProperty("undo")
-        || !vwr.getBooleanProperty("preserveState"))
+    if (!vwr.getBooleanProperty("undoAuto")
+        || !vwr.getBoolean(T.preservestate))
       return;
     //delete redo items, since they will no longer be valid
     for (int i = undoPointer + 1; i <= MAXUNDO; i++)
@@ -501,11 +522,11 @@ public class AppConsole extends JmolConsole
       dontsave = true;
     }
     if (dontsave || Logger.checkTimer("(console", false) > 2000) {
-      vwr.setBooleanProperty("undo", false);
+      vwr.setBooleanProperty("undoAuto", false);
       undoClear();
       Logger.info("command processing slow; undo disabled");
     } else {
-      undoSetEnabled();
+      checkUndoEnabled();
     }
     undoSaved = true;
     //dumpUndo("undoSave DONE");
@@ -541,6 +562,7 @@ public class AppConsole extends JmolConsole
 
     String strErrorMessage = null;
     doWait = (strCommand.indexOf("WAITTEST ") == 0);
+    boolean hasExtension = false;
     if (doWait) { //for testing, mainly
       // demonstrates using the statusManager system; probably hangs application.
       Object o = vwr.scriptWaitStatus(strCommand.substring(5),
@@ -568,6 +590,7 @@ public class AppConsole extends JmolConsole
       strErrorMessage = "";
       String str = strCommand;
       boolean isInterrupt = (str.charAt(0) == '!');
+      hasExtension = (strCommand.indexOf(JC.SCRIPT_EXT) >= 0);
       if (isInterrupt)
         str = str.substring(1);
       if (vwr.checkHalt(str, isInterrupt))
@@ -576,13 +599,14 @@ public class AppConsole extends JmolConsole
             : "no script was executing - use exitJmol to exit Jmol");
       //the problem is that scriptCheck is synchronized, so these might get backed up. 
       if (strErrorMessage.length() > 0) {
-        console.outputError(strErrorMessage);
+        if (!hasExtension)
+          console.outputError(strErrorMessage);
       } else {
-        vwr.script(strCommand
-            + (strCommand.indexOf("\1##") >= 0 ? "" : JC.SCRIPT_EDITOR_IGNORE));
+        vwr.script(strCommand + JC.SCRIPT_GUI
+            + (strCommand.indexOf(JC.SCRIPT_EXT) >= 0 ? "" : JC.SCRIPT_EDITOR_IGNORE));
       }
     }
-    if (strCommand.indexOf("\1##") < 0)
+    if (!hasExtension)
       console.grabFocus();
   }
 
@@ -603,7 +627,7 @@ public class AppConsole extends JmolConsole
     }
     if (source == checkButton) {
       if (scriptEditor != null)
-        scriptEditor.checkScript();
+        scriptEditor.checkScript(0);
     }
     if (source == stepButton) {
       if (scriptEditor != null)
@@ -636,15 +660,12 @@ public class AppConsole extends JmolConsole
       return;
     }
     if (source == fontButton) {
-      if (Viewer.isJS) {
-        vwr.setConsoleFontScale((vwr.getConsoleFontScale() + 1) % 5);
-        updateFontSize();
-      } else {
-        PreferencesDialog d = (PreferencesDialog) vwr.getProperty("DATA_API",
-            "getPreference", null);
-        if (d != null)
-          d.setFontScale(-1);
+      if (!Viewer.isJS && !noPrefs) {
+        if (updateFont())
+          return;
       }
+      vwr.setConsoleFontScale((vwr.getConsoleFontScale() + 1) % 5);
+      updateFontSize();
       return;
     }
     if (source == helpButton) {
@@ -660,13 +681,68 @@ public class AppConsole extends JmolConsole
     super.actionPerformed(e);
   }
 
+  private boolean updateFont() {
+    PreferencesDialog d = null;
+    try {
+      d = (PreferencesDialog) vwr.getProperty("DATA_API",
+          "getPreference", null);
+      if (d != null)
+        d.setFontScale(-1);
+      return true;
+    } catch (Exception ee) {
+      noPrefs = true;
+    }
+    return false;
+  }
+  
+  /**
+   * Recall command history.
+   * 
+   * @param up
+   *        - history up or down
+   * @param pageup
+   *        TODO
+   */
+  @Override
+  protected void recallCommand(boolean up, boolean pageup) {
+    String cmd = (pageup ? vwr.historyFind(
+        console.pageUpBuffer == null ? (console.pageUpBuffer = consoleDoc.getCommandString())
+            : console.pageUpBuffer,
+        up ? -1 : 1) : vwr.getSetHistory(up ? -1 : 1));
+    if (cmd == null) {
+      EventQueue.invokeLater(new Runnable() {
+        @Override
+        public void run() {
+          try {
+            hBar.setValue(0);
+          } catch (Throwable e) {
+            //
+          }
+        }
+      });
+      return;
+    }
+    boolean isError = false;
+    try {
+      if (cmd.endsWith(CommandHistory.ERROR_FLAG)) {
+        isError = true;
+        cmd = cmd.substring(0, cmd.indexOf(CommandHistory.ERROR_FLAG));
+      }
+      cmd = trimGUI(cmd);
+      consoleDoc.replaceCommand(cmd, isError);
+    } catch (BadLocationException e) {
+      e.printStackTrace();
+    }
+  }
+
+
+
   class ConsoleTextPane extends JTextPane implements KeyListener {
 
-    private ConsoleDocument consoleDoc;
     private EnterListener enterListener;
 
     boolean checking = false;
-    private String pageUpBuffer;
+    String pageUpBuffer;
     boolean checkingCommand;
     private Timer checkTimer;
 
@@ -720,12 +796,6 @@ public class AppConsole extends JmolConsole
       setPrompt();
     }
 
-    //    /*
-    //    * (non-Javadoc)
-    //    * 
-    //    * @see java.awt.Component#processKeyEvent(java.awt.event.KeyEvent)
-    //    */
-    //
     /**
      * Custom key event processing for command 0 implementation.
      * 
@@ -846,60 +916,21 @@ public class AppConsole extends JmolConsole
       }
     }
 
-  /**
-   * Recall command history.
-   * 
-   * @param up
-   *        - history up or down
-   * @param pageup
-   *        TODO
-   */
-  void recallCommand(boolean up, boolean pageup) {
-    String cmd = (pageup ? vwr.historyFind(
-        pageUpBuffer == null ? (pageUpBuffer = consoleDoc.getCommandString())
-            : pageUpBuffer,
-        up ? -1 : 1) : vwr.getSetHistory(up ? -1 : 1));
-    if (cmd == null) {
-      EventQueue.invokeLater(new Runnable() {
-        @Override
-        public void run() {
-          try {
-            hBar.setValue(0);
-          } catch (Throwable e) {
-            //
-          }
-        }
-      });
-      return;
-    }
-    boolean isError = false;
-    try {
-      if (cmd.endsWith(CommandHistory.ERROR_FLAG)) {
-        isError = true;
-        cmd = cmd.substring(0, cmd.indexOf(CommandHistory.ERROR_FLAG));
-      }
-      cmd = PT.trim(cmd, ";");
-      consoleDoc.replaceCommand(cmd, isError);
-    } catch (BadLocationException e) {
-      e.printStackTrace();
-    }
-  }
-
-  synchronized void checkCommand() {
-    String strCommand = consoleDoc.getCommandString();
-    //System.out.println("checkCommand " + strCommand);
-    if (strCommand.length() == 0 || strCommand.charAt(0) == '!'
+    synchronized void checkCommand() {
+      String strCommand = consoleDoc.getCommandString();
+      //System.out.println("checkCommand " + strCommand);
+      if (strCommand.length() == 0 || strCommand.charAt(0) == '!'
           || vwr.isScriptExecuting()
           || vwr.getBooleanProperty("executionPaused"))
-      return;
-    checking = true;
-    Object res = vwr.scriptCheck(strCommand);
+        return;
+      checking = true;
+      Object res = vwr.scriptCheck(strCommand);
 
-    //System.out.println( res);
+      //System.out.println( res);
       consoleDoc.colorCommand(res instanceof String ? consoleDoc.attError
           : consoleDoc.attUserInput);
-    checking = false;
-  }
+      checking = false;
+    }
 
   }
 
@@ -1160,7 +1191,6 @@ public class AppConsole extends JmolConsole
     }
   }
 
-
 }
 
 interface EnterListener {
